@@ -136,6 +136,15 @@ const char *af_identify_name(const char *filename)
     return 0;
 }
 
+#include <stdarg.h>
+void aff_warnx(const char *fmt,...)
+{
+  va_list ap;
+  va_start(ap,fmt);
+  vfprintf(stderr,fmt,ap);
+  va_end(ap);
+}
+
 AFFILE *af_open_with(const char *filename,int flags,int mode, struct af_vnode *v)
 {
     /* Alloate the space for the AFFILE structure */
@@ -149,7 +158,7 @@ AFFILE *af_open_with(const char *filename,int flags,int mode, struct af_vnode *v
     af->pagenum   = -1;
     af->image_sectorsize = 512;		// default size
     af->badflag   = (unsigned char *)malloc(af->image_sectorsize);
-    af->error_reporter = warnx;
+    af->error_reporter = aff_warnx;
 
     /* Try opening it! */
     if((*af->v->open)(af)){		
@@ -407,17 +416,6 @@ int af_has_pages(AFFILE *af)
 }
 
 
-#ifdef NO_WARNX
-#include <stdarg.h>
-void warnx(const char *fmt,...)
-{
-  va_list ap;
-  va_start(ap,fmt);
-  vfprintf(stderr,fmt,ap);
-  va_end(ap);
-}
-#endif
-
 #ifdef NO_ERR
 #include <stdarg.h>
 void err(int eval,const char *fmt,...)
