@@ -114,11 +114,21 @@ int	af_figure_media(int fd,struct af_figure_media_buf *afb)
     /* With Linux, we figure out how many bytes there are and get sector size
      * from a #define
      */
-    uint64 total_bytes=0;
+
     afb->sector_size = BLOCK_SIZE;	
+#ifdef BLKGETSIZE64
+    uint64 total_bytes=0;
     if(ioctl(fd,BLKGETSIZE64,&total_bytes)){
 	total_bytes = 0;
     }
+#else
+    int total_bytes=0;
+    if(ioctl(fd,BLKGETSIZE,&total_bytes)){
+	total_bytes = 0;
+    }
+#endif
+
+
     afb->total_sectors = total_bytes / afb->sector_size;
     afb->max_read_blocks = 0;
 #endif
