@@ -77,7 +77,8 @@ int af_page_size(AFFILE *af)
 }
 
 /* af_set_sectorsize:
- * Sets the sectorsize. Fails with -1 if imagesize >=0 unless these changes permitted
+ * Sets the sectorsize.
+ * Fails with -1 if imagesize >=0 unless these changes permitted
  */
 int af_set_sectorsize(AFFILE *af,int sectorsize)
 {
@@ -165,7 +166,8 @@ const unsigned char *af_badflag(AFFILE *af)
  *** page-level interface
  ****************************************************************/
 
-int af_get_page_raw(AFFILE *af,int64 pagenum,unsigned long *arg,unsigned char *data,size_t *bytes)
+int af_get_page_raw(AFFILE *af,int64 pagenum,unsigned long *arg,
+		    unsigned char *data,size_t *bytes)
 {
     char segname[AF_MAX_NAME_LEN];
     
@@ -281,6 +283,14 @@ int af_get_page(AFFILE *af,int64 pagenum,unsigned char *data,size_t *bytes)
 /* Write a actual data segment to the disk */
 int af_update_page(AFFILE *af,int64 pagenum,unsigned char *data,int datalen)
 {
+    char segname_buf[32];
+
+    /* Write out the hash of the page */
+    unsigned char md5_buf[16];
+    MD5(data,datalen,md5_buf);
+    snprintf(segname_buf,sizeof(segname_buf),AF_PAGE_MD5,pagenum);
+    af_update_seg(af,segname_buf,0,md5_buf,sizeof(md5_buf),1); // ignore failure
+
     /* Check for bypass */
     if(af->v->write){
 	int r = (*af->v->write)(af,data,af->image_pagesize * pagenum,datalen);
@@ -301,17 +311,15 @@ int af_update_page(AFFILE *af,int64 pagenum,unsigned char *data,int datalen)
     acbi.bytes_to_write = datalen;
     if(af->compression_type != AF_COMPRESSION_NONE){ // it will be compressedn
 	acbi.compressed = 1;		// it was compressed
-	acbi.compression_alg = AF_PAGE_COMP_ALG_ZLIB; // only one that we support
+	acbi.compression_alg   = AF_PAGE_COMP_ALG_ZLIB; // only one that we support
 	acbi.compression_level = af->compression_level;
     }
 
     /* Set up the segnment */
-    char vbuf[32];
-    sprintf(vbuf,AF_PAGE,pagenum);
+    snprintf(segname_buf,sizeof(segname_buf),AF_PAGE,pagenum);
     uLongf destLen = af->image_pagesize;	// it could be this big.
     if(af->compression_type != AF_COMPRESSION_NONE){
 	/* Try to compress the data */
-	
 	unsigned char *cdata = (unsigned char *)malloc(destLen); 
 	if(cdata!=0){		// If data could be allocated
 	    
@@ -334,7 +342,7 @@ int af_update_page(AFFILE *af,int64 pagenum,unsigned char *data,int datalen)
 		}
 
 		if(af->w_callback) {acbi.phase = 3;(*af->w_callback)(&acbi);}
-		ret = af_update_seg(af,vbuf,flag,cdata,destLen,1);
+		ret = af_update_seg(af,segname_buf,flag,cdata,destLen,1);
 		acbi.bytes_written = destLen;
 		if(af->w_callback) {acbi.phase = 4;(*af->w_callback)(&acbi);}
 		if(ret==0){
@@ -350,7 +358,7 @@ int af_update_page(AFFILE *af,int64 pagenum,unsigned char *data,int datalen)
     /* If a compressed segment was not written, write it uncompressed */
     if(af->csegs_written == starting_csegs_written){ 
 	if(af->w_callback) {acbi.phase = 3;(*af->w_callback)(&acbi);}
-	ret = af_update_seg(af,vbuf,0,data,datalen,1);
+	ret = af_update_seg(af,segname_buf,0,data,datalen,1);
 	acbi.bytes_written = datalen;
 	if(af->w_callback) {acbi.phase = 4;(*af->w_callback)(&acbi);} 
 	if(ret==0){
