@@ -53,6 +53,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include "aux_tools.h"
 #if defined (HAVE_UNISTD)
 #include <unistd.h>
 #endif
@@ -62,10 +63,6 @@
 #include <string.h>
 #include <errno.h>
 
-#include "tsk_os.h"
-#include "tsk_types.h"
-#include "tsk_error.h"
-
 
 /* mymalloc - allocate memory and set error values on error
  */
