@@ -1,14 +1,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "tsk_os.h"
+#include "aux_tools.h"
 
 #if defined (HAVE_UNISTD)
 #include <unistd.h>
 #endif
 
-#include "tsk_types.h"
-#include "tsk_error.h"
 
 /* Global variables that fit here as well as anywhere */
 char *progname = "unknown";
@@ -82,7 +80,7 @@ const char *tsk_err_fs_str[TSK_ERR_FS_MAX] = {
     "Invalid magic value",
     "Error extracting file from image",
     "Error writing data",
-    "Error converting Unicode", 
+    "Error converting Unicode",
     "Error recovering deleted file",
     "General file system error"
 };
@@ -98,55 +96,55 @@ tsk_error_print(FILE * hFile)
 
     if (tsk_errno & TSK_ERR_AUX) {
 	if ((TSK_ERR_MASK & tsk_errno) < TSK_ERR_AUX_MAX)
-	    fprintf(hFile, "%s",
+	    tsk_fprintf(hFile, "%s",
 		tsk_err_aux_str[tsk_errno & TSK_ERR_MASK]);
 	else
-	    fprintf(hFile, "auxtools error: %" PRIu32,
+	    tsk_fprintf(hFile, "auxtools error: %" PRIu32,
 		TSK_ERR_MASK & tsk_errno);
     }
     else if (tsk_errno & TSK_ERR_IMG) {
 	if ((TSK_ERR_MASK & tsk_errno) < TSK_ERR_IMG_MAX)
-	    fprintf(hFile, "%s",
+	    tsk_fprintf(hFile, "%s",
 		tsk_err_img_str[tsk_errno & TSK_ERR_MASK]);
 	else
-	    fprintf(hFile, "imgtools error: %" PRIu32,
+	    tsk_fprintf(hFile, "imgtools error: %" PRIu32,
 		TSK_ERR_MASK & tsk_errno);
     }
     else if (tsk_errno & TSK_ERR_MM) {
 	if ((TSK_ERR_MASK & tsk_errno) < TSK_ERR_MM_MAX)
-	    fprintf(hFile, "%s", tsk_err_mm_str[tsk_errno & TSK_ERR_MASK]);
+	    tsk_fprintf(hFile, "%s",
+		tsk_err_mm_str[tsk_errno & TSK_ERR_MASK]);
 	else
-	    fprintf(hFile, "mmtools error: %" PRIu32,
+	    tsk_fprintf(hFile, "mmtools error: %" PRIu32,
 		TSK_ERR_MASK & tsk_errno);
     }
     else if (tsk_errno & TSK_ERR_FS) {
 	if ((TSK_ERR_MASK & tsk_errno) < TSK_ERR_FS_MAX)
-	    fprintf(hFile, "%s", tsk_err_fs_str[tsk_errno & TSK_ERR_MASK]);
+	    tsk_fprintf(hFile, "%s",
+		tsk_err_fs_str[tsk_errno & TSK_ERR_MASK]);
 	else
-	    fprintf(hFile, "fstools error: %" PRIu32,
+	    tsk_fprintf(hFile, "fstools error: %" PRIu32,
 		TSK_ERR_MASK & tsk_errno);
     }
     else {
-	fprintf(hFile, "Error: %" PRIu32, tsk_errno);
+	tsk_fprintf(hFile, "Error: %" PRIu32, tsk_errno);
     }
 
     /* Print the unique string, if it exists */
     if (tsk_errstr[0] != '\0')
-	fprintf(hFile, " (%s)", tsk_errstr);
+	tsk_fprintf(hFile, " (%s)", tsk_errstr);
 
     if (tsk_errstr2[0] != '\0')
-	fprintf(hFile, " (%s)", tsk_errstr2);
-
-    fprintf(hFile, "\n");
+	tsk_fprintf(hFile, " (%s)", tsk_errstr2);
 
+    tsk_fprintf(hFile, "\n");
 }
 
 /* Clear the error number and error message */
 void
 tsk_error_reset()
 {
-	tsk_errno = 0;
-	tsk_errstr[0] = '\0';
-	tsk_errstr2[0] = '\0';
+    tsk_errno = 0;
+    tsk_errstr[0] = '\0';
+    tsk_errstr2[0] = '\0';
 }
-
