@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2006/06/20 22:35:37 $
+** $Date: 2006/09/01 15:23:03 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2004-2005 Brian Carrier.  All rights reserved
@@ -139,8 +139,15 @@ extern "C" {
 #if defined(_WIN32) || defined (__WIN32__)
 #define SUPPORTED
 #define TSK_WIN32
+#ifndef UNICODE
+#define UNICODE
+#endif
+#ifndef _UNICODE
+#define _UNICODE
+#endif
 #define WIN32_LEAN_AND_MEAN	/* somewhat limit Win32 pollution */
 #include <windows.h>
+#include <tchar.h>
 #include <io.h>
 
 #define _CRT_SECURE_NO_DEPRECATE	1
@@ -159,10 +166,10 @@ extern "C" {
     typedef uint16_t uid_t;
 
 #define strtoull	strtoul
-#define open(filename, oflag)	_open(filename, oflag|_O_BINARY, 0)
-#define lseek	_lseek
-#define read	_read
-#define close	_close
+//#define open(filename, oflag) _open(filename, oflag|_O_BINARY, 0)
+//#define lseek _lseek
+//#define read  _read
+//#define close _close
 #define snprintf   _snprintf
 #define strcasecmp(string1, string2)	_strnicmp(string1, string2, sizeof(string1))
 
@@ -178,6 +185,53 @@ extern "C" {
 #endif
 
 #endif
+
+
+
+#ifdef TSK_WIN32
+#define MAIN _tmain
+#define TSTAT _tstat
+#define STAT_STR    _stat64i32
+//#define TSTRNCPY(d, s, l)    _tcscpy_s(d, l, s)
+#define TSTRTOK	_tcstok
+#define TSTRLEN	_tcslen
+#define TSTRCMP	_tcscmp
+#define TSTRNCPY _tcsncpy
+#define TSTRNCAT _tcsncat
+#define TSTRCHR	_tcschr
+#define TSTRTOUL _tcstoul
+#define TSTRTOULL _tcstoui64
+#define TATOI	_tstoi
+#define TFPRINTF fwprintf
+#define TSNPRINTF _snwprintf
+#define PUTENV	_wputenv
+#define TZSET	_tzset
+
+#else
+
+#define MAIN main
+#define _T(x)	x
+    typedef char TCHAR;
+#define TSTAT stat
+#define STAT_STR    stat
+//#define TSTRNCPY(d,s,l)    strncpy(d,s,l)
+#define TSTRTOK	strtok
+#define TSTRLEN	strlen
+#define TSTRCMP	strcmp
+#define TSTRNCPY strncpy
+#define TSTRNCAT strncat
+#define TSTRCHR	strchr
+#define TSTRTOUL strtoul
+#define TSTRTOULL strtoull
+#define TATOI	atoi
+#define TFPRINTF fprintf
+#define TSNPRINTF snprintf
+
+#define PUTENV	putenv
+#define TZSET	tzset
+
+#endif
+
     /*
      * Catch-all.
      */
