@@ -1,19 +1,20 @@
 /*
  * The Sleuth Kit
  * 
- * $Date: 2005/09/02 19:53:26 $
+ * $Date: 2006/08/25 18:28:05 $
  */
 #include <stdlib.h>
 #include <stdio.h>
+#include "aux_tools.h"
 
 void
 print_version(FILE * hFile)
 {
     char *str = "The Sleuth Kit";
 #ifdef VER
-    fprintf(hFile, "%s ver %s\n", str, VER);
+    tsk_fprintf(hFile, "%s ver %s\n", str, VER);
 #else
-    fprintf(hFile, "%s\n", str);
+    tsk_fprintf(hFile, "%s\n", str);
 #endif
     return;
 }
