@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2005/09/02 23:34:02 $
+ * $Date: 2006/08/17 17:13:03 $
  * 
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2005 Brian Carrier.  All rights reserved 
@@ -20,8 +20,8 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include "tsk_os.h"
-#include "tsk_types.h"
+
+#include "aux_tools.h"
 
 #if defined(LINUX2)
 
@@ -32,7 +32,6 @@
 #include <linux/hdreg.h>
 #include <string.h>
 
-#include "aux_lib.h"
 #include "disk_ide.h"
 
 DISK_INFO *
