@@ -2,7 +2,7 @@
 ** dcalc
 ** The Sleuth Kit 
 **
-** $Date: 2006/07/10 13:26:20 $
+** $Date: 2006/08/30 21:09:11 $
 **
 ** Calculates the corresponding block number between 'dls' and 'dd' images
 ** when given an 'dls' block number, it determines the block number it
@@ -23,29 +23,34 @@
 ** This software is distributed under the Common Public License 1.0
 **
 */
-#include "libfstools.h"
+#include <locale.h>
+#include "fs_tools.h"
+
+static TCHAR *progname;
 
 static void
 usage()
 {
-    fprintf(stderr,
-	"usage: %s [-dsu unit_addr] [-vV] [-f fstype] [-i imgtype] [-o imgoffset] image [images]\n",
+    TFPRINTF(stderr,
+	_T
+	("usage: %s [-dsu unit_addr] [-vV] [-f fstype] [-i imgtype] [-o imgoffset] image [images]\n"),
 	progname);
-    fprintf(stderr, "Slowly calculates the opposite block number\n");
-    fprintf(stderr, "\tOne of the following must be given:\n");
-    fprintf(stderr, "\t  -d: The given address is from a 'dd' image \n");
-    fprintf(stderr,
+    tsk_fprintf(stderr, "Slowly calculates the opposite block number\n");
+    tsk_fprintf(stderr, "\tOne of the following must be given:\n");
+    tsk_fprintf(stderr,
+	"\t  -d: The given address is from a 'dd' image \n");
+    tsk_fprintf(stderr,
 	"\t  -s: The given address is from a 'dls -s' (slack) image\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t  -u: The given address is from a 'dls' (unallocated) image\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-f fstype: The file system type (use '-f list' for supported types)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-i imgtype: The format of the image file (use '-i list' for supported types)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-o imgoffset: The offset of the file system in the image (in sectors)\n");
-    fprintf(stderr, "\t-v: verbose output to stderr\n");
-    fprintf(stderr, "\t-V: Print version\n");
+    tsk_fprintf(stderr, "\t-v: verbose output to stderr\n");
+    tsk_fprintf(stderr, "\t-V: Print version\n");
 
     exit(1);
 }
@@ -53,90 +58,87 @@ usage()
 
 
 int
-main(int argc, char **argv)
+MAIN(int argc, TCHAR ** argv)
 {
-    char *fstype = NULL;
+    TCHAR *fstype = NULL;
+    TCHAR *imgtype = NULL;
     int ch;
-    char *cp, type = 0;
+    TCHAR *cp;
+    uint8_t type = 0;
     FS_INFO *fs;
     IMG_INFO *img;
     int set = 0;
-    char *imgtype = NULL;
     SSIZE_T imgoff = 0;
     DADDR_T count = 0;
 
     progname = argv[0];
     setlocale(LC_ALL, "");
 
-    while ((ch = getopt(argc, argv, "d:f:i:o:s:u:vV")) > 0) {
+    while ((ch = getopt(argc, argv, _T("d:f:i:o:s:u:vV"))) > 0) {
 	switch (ch) {
-	case '?':
+	case _T('?'):
 	default:
-	    fprintf(stderr, "Invalid argument: %s\n", argv[optind]);
+	    TFPRINTF(stderr, _T("Invalid argument: %s\n"), argv[optind]);
 	    usage();
 
-	case 'd':
+	case _T('d'):
 	    type |= DCALC_DD;
-	    count = strtoull(optarg, &cp, 0);
+	    count = TSTRTOULL(optarg, &cp, 0);
 	    if (*cp || cp == optarg) {
-		fprintf(stderr, "Invalid address: %s\n", optarg);
+		TFPRINTF(stderr, _T("Invalid address: %s\n"), optarg);
 		usage();
 	    }
-
 	    set = 1;
 	    break;
 
-	case 'f':
+	case _T('f'):
 	    fstype = optarg;
-	    if (strcmp(fstype, "list") == 0) {
+	    if (TSTRCMP(fstype, _T("list")) == 0) {
 		fs_print_types(stderr);
 		exit(1);
 	    }
 	    break;
 
-	case 'i':
+	case _T('i'):
 	    imgtype = optarg;
-	    if (strcmp(imgtype, "list") == 0) {
+	    if (TSTRCMP(imgtype, _T("list")) == 0) {
 		img_print_types(stderr);
 		exit(1);
 	    }
-
 	    break;
 
-	case 'o':
+	case _T('o'):
 	    if ((imgoff = parse_offset(optarg)) == -1) {
 		tsk_error_print(stderr);
 		exit(1);
 	    }
 	    break;
 
-	case 's':
+	case _T('s'):
 	    type |= DCALC_SLACK;
-	    count = strtoull(optarg, &cp, 0);
+	    count = TSTRTOULL(optarg, &cp, 0);
 	    if (*cp || cp == optarg) {
-		fprintf(stderr, "Invalid address: %s\n", optarg);
+		TFPRINTF(stderr, _T("Invalid address: %s\n"), optarg);
 		usage();
 	    }
-
 	    set = 1;
 	    break;
 
-	case 'u':
+	case _T('u'):
 	    type |= DCALC_DLS;
-	    count = strtoull(optarg, &cp, 0);
+	    count = TSTRTOULL(optarg, &cp, 0);
 	    if (*cp || cp == optarg) {
-		fprintf(stderr, "Invalid address: %s\n", optarg);
+		TFPRINTF(stderr, _T("Invalid address: %s\n"), optarg);
 		usage();
 	    }
-
 	    set = 1;
 	    break;
 
-	case 'v':
+	case _T('v'):
 	    verbose++;
 	    break;
 
-	case 'V':
+	case _T('V'):
 	    print_version(stdout);
 	    exit(0);
 	}
@@ -144,24 +146,24 @@ main(int argc, char **argv)
 
     /* We need at least one more argument */
     if (optind == argc) {
-	fprintf(stderr, "Missing image name\n");
+	tsk_fprintf(stderr, "Missing image name\n");
 	usage();
     }
 
     if ((!type) || (set == 0)) {
-	fprintf(stderr, "Calculation type not given (-u, -d, -s)\n");
+	tsk_fprintf(stderr, "Calculation type not given (-u, -d, -s)\n");
 	usage();
     }
 
     if ((type & DCALC_DD) && (type & DCALC_DLS) && (type & DCALC_SLACK)) {
-	fprintf(stderr, "Only one block type can be given\n");
+	tsk_fprintf(stderr, "Only one block type can be given\n");
 	usage();
     }
 
 
     if ((img =
 	    img_open(imgtype, argc - optind,
-		(const char **) &argv[optind])) == NULL) {
+		(const TCHAR **) &argv[optind])) == NULL) {
 	tsk_error_print(stderr);
 	exit(1);
     }
@@ -174,7 +176,6 @@ main(int argc, char **argv)
 	exit(1);
     }
 
-
     if (-1 == fs_dcalc(fs, type, count)) {
 	tsk_error_print(stderr);
 	fs->close(fs);
