@@ -2,7 +2,7 @@
 ** ext2fs_dent
 ** The Sleuth Kit 
 **
-** $Date: 2006/07/05 18:24:09 $
+** $Date: 2006/08/30 21:09:11 $
 **
 ** File name layer support for an EXT2FS image
 **
@@ -22,11 +22,11 @@
 */
 
 #include <ctype.h>
-#include "fs_tools.h"
+#include "fs_tools_i.h"
 #include "ext2fs.h"
 
-#define MAX_DEPTH   64
-#define DIR_STRSZ  2048
+#define MAX_DEPTH   128
+#define DIR_STRSZ   4096
 
 typedef struct {
     /* Recursive path stuff */
@@ -52,32 +52,34 @@ ext2fs_dent_copy(EXT2FS_INFO * ext2fs, EXT2FS_DINFO * dinfo,
     char *ext2_dent, FS_DENT * fs_dent)
 {
     FS_INFO *fs = &(ext2fs->fs_info);
+    int i;
 
     if (ext2fs->deentry_type == EXT2_DE_V1) {
 	ext2fs_dentry1 *dir = (ext2fs_dentry1 *) ext2_dent;
 
-	fs_dent->inode = getu32(fs, dir->inode);
+	fs_dent->inode = getu32(fs->endian, dir->inode);
 
 	/* ext2 does not null terminate */
-	if (getu16(fs, dir->name_len) >= fs_dent->name_max) {
+	if (getu16(fs->endian, dir->name_len) >= fs_dent->name_max) {
 	    tsk_errno = TSK_ERR_FS_ARG;
 	    snprintf(tsk_errstr, TSK_ERRSTR_L,
 		"ext2fs_dent_copy: Name Space too Small %d %lu",
-		getu16(fs, dir->name_len), fs_dent->name_max);
+		getu16(fs->endian, dir->name_len), fs_dent->name_max);
 	    tsk_errstr2[0] = '\0';
 	    return 1;
 	}
 
 	/* Copy and Null Terminate */
-	strncpy(fs_dent->name, dir->name, getu16(fs, dir->name_len));
-	fs_dent->name[getu16(fs, dir->name_len)] = '\0';
+	strncpy(fs_dent->name, dir->name, getu16(fs->endian,
+		dir->name_len));
+	fs_dent->name[getu16(fs->endian, dir->name_len)] = '\0';
 
 	fs_dent->ent_type = FS_DENT_UNDEF;
     }
     else {
 	ext2fs_dentry2 *dir = (ext2fs_dentry2 *) ext2_dent;
 
-	fs_dent->inode = getu32(fs, dir->inode);
+	fs_dent->inode = getu32(fs->endian, dir->inode);
 
 	/* ext2 does not null terminate */
 	if (dir->name_len >= fs_dent->name_max) {
@@ -122,6 +124,14 @@ ext2fs_dent_copy(EXT2FS_INFO * ext2fs, EXT2FS_DINFO * dinfo,
 	}
     }
 
+    /* Clean up name */
+    i = 0;
+    while (fs_dent->name[i] != '\0') {
+	if (TSK_IS_CNTRL(fs_dent->name[i]))
+	    fs_dent->name[i] = '^';
+	i++;
+    }
+
     fs_dent->path = dinfo->dirs;
     fs_dent->pathdepth = dinfo->depth;
 
@@ -184,15 +194,15 @@ ext2fs_dent_parse_block(EXT2FS_INFO * ext2fs, EXT2FS_DINFO * dinfo,
 
 	if (ext2fs->deentry_type == EXT2_DE_V1) {
 	    ext2fs_dentry1 *dir = (ext2fs_dentry1 *) dirPtr;
-	    inode = getu32(fs, dir->inode);
-	    namelen = getu16(fs, dir->name_len);
-	    reclen = getu16(fs, dir->rec_len);
+	    inode = getu32(fs->endian, dir->inode);
+	    namelen = getu16(fs->endian, dir->name_len);
+	    reclen = getu16(fs->endian, dir->rec_len);
 	}
 	else {
 	    ext2fs_dentry2 *dir = (ext2fs_dentry2 *) dirPtr;
-	    inode = getu32(fs, dir->inode);
+	    inode = getu32(fs->endian, dir->inode);
 	    namelen = dir->name_len;
-	    reclen = getu16(fs, dir->rec_len);
+	    reclen = getu16(fs->endian, dir->rec_len);
 	}
 
 	minreclen = EXT2FS_DIRSIZ_lcl(namelen);
@@ -286,12 +296,17 @@ ext2fs_dent_parse_block(EXT2FS_INFO * ext2fs, EXT2FS_DINFO * dinfo,
 	    (!ISDOT(fs_dent->name)) &&
 	    ((fs_dent->fsi->mode & FS_INODE_FMT) == FS_INODE_DIR)) {
 
-	    if (dinfo->depth < MAX_DEPTH) {
+	    int depth_added = 0;
+
+	    if ((dinfo->depth < MAX_DEPTH) &&
+		(DIR_STRSZ >
+		    strlen(dinfo->dirs) + strlen(fs_dent->name))) {
 		dinfo->didx[dinfo->depth] =
 		    &dinfo->dirs[strlen(dinfo->dirs)];
 		strncpy(dinfo->didx[dinfo->depth], fs_dent->name,
 		    DIR_STRSZ - strlen(dinfo->dirs));
 		strncat(dinfo->dirs, "/", DIR_STRSZ);
+		depth_added = 1;
 	    }
 	    dinfo->depth++;
 	    if (ext2fs_dent_walk_lcl(&(ext2fs->fs_info), dinfo,
@@ -299,7 +314,7 @@ ext2fs_dent_parse_block(EXT2FS_INFO * ext2fs, EXT2FS_DINFO * dinfo,
 		/* If this fails because the directory could not be 
 		 * loaded, then we still continue */
 		if (verbose) {
-		    fprintf(stderr,
+		    tsk_fprintf(stderr,
 			"ffs_dent_parse_block: error reading directory: %"
 			PRIuINUM "\n", fs_dent->inode);
 		    tsk_error_print(stderr);
@@ -310,7 +325,7 @@ ext2fs_dent_parse_block(EXT2FS_INFO * ext2fs, EXT2FS_DINFO * dinfo,
 
 
 	    dinfo->depth--;
-	    if (dinfo->depth < MAX_DEPTH)
+	    if (depth_added)
 		*dinfo->didx[dinfo->depth] = '\0';
 	}
     }
@@ -364,7 +379,7 @@ ext2fs_dent_walk_lcl(FS_INFO * fs, EXT2FS_DINFO * dinfo, INUM_T inode,
     }
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "ext2fs_dent_walk_lcl: Processing directory %" PRIuINUM
 	    "\n", inode);
 
@@ -375,13 +390,13 @@ ext2fs_dent_walk_lcl(FS_INFO * fs, EXT2FS_DINFO * dinfo, INUM_T inode,
     }
 
     size = roundup(fs_inode->size, fs->block_size);
-    if ((dirbuf = mymalloc(size)) == NULL) {
+    if ((dirbuf = mymalloc((size_t) size)) == NULL) {
 	fs_inode_free(fs_inode);
 	return 1;
     }
 
     /* make a copy of the directory contents that we can process */
-    load_file.left = load_file.total = size;
+    load_file.left = load_file.total = (size_t) size;
     load_file.base = load_file.cur = dirbuf;
 
     if (fs->file_walk(fs, fs_inode, 0, 0,
@@ -409,7 +424,7 @@ ext2fs_dent_walk_lcl(FS_INFO * fs, EXT2FS_DINFO * dinfo, INUM_T inode,
     dirptr = dirbuf;
 
     while (size > 0) {
-	int len = (fs->block_size < size) ? fs->block_size : size;
+	int len = (fs->block_size < size) ? fs->block_size : (int) size;
 
 	retval =
 	    ext2fs_dent_parse_block(ext2fs, dinfo, dirptr, len, flags,
