@@ -2,7 +2,7 @@
 ** fatfs
 ** The Sleuth Kit 
 **
-** $Date: 2006/07/10 17:11:10 $
+** $Date: 2006/09/01 15:23:03 $
 **
 ** Content and meta data layer support for the FAT file system 
 **
@@ -20,11 +20,8 @@
 **
 */
 
-#include "fs_tools.h"
-#include "fs_types.h"
+#include "fs_tools_i.h"
 #include "fatfs.h"
-#include "fs_unicode.h"
-
 
 
 /*
@@ -134,7 +131,7 @@ getFAT(FATFS_INFO * fatfs, DADDR_T clust, DADDR_T * value)
 	/* get pointer to entry in current buffer */
 	ptr = (uint8_t *) fatfs->table->data + offs;
 
-	tmp16 = getu16(fs, ptr);
+	tmp16 = getu16(fs->endian, ptr);
 
 	/* slide it over if it is one of the odd clusters */
 	if (clust & 1)
@@ -146,7 +143,7 @@ getFAT(FATFS_INFO * fatfs, DADDR_T clust, DADDR_T * value)
 	if ((*value > (fatfs->lastclust)) &&
 	    (*value < (0x0ffffff7 & FATFS_12_MASK))) {
 	    if (verbose)
-		fprintf(stderr, "getFAT: FAT12 cluster (%" PRIuDADDR
+		tsk_fprintf(stderr, "getFAT: FAT12 cluster (%" PRIuDADDR
 		    ") too large (%" PRIuDADDR ") - resetting\n",
 		    clust, *value);
 	    *value = 0;
@@ -178,13 +175,13 @@ getFAT(FATFS_INFO * fatfs, DADDR_T clust, DADDR_T * value)
 	    (sect - fatfs->table->addr) * fatfs->ssize +
 	    (clust * 2) % fatfs->ssize;
 
-	*value = getu16(fs, ptr) & FATFS_16_MASK;
+	*value = getu16(fs->endian, ptr) & FATFS_16_MASK;
 
 	/* sanity check */
 	if ((*value > (fatfs->lastclust)) &&
 	    (*value < (0x0ffffff7 & FATFS_16_MASK))) {
 	    if (verbose)
-		fprintf(stderr,
+		tsk_fprintf(stderr,
 		    "getFAT: contents of FAT16 entry %" PRIuDADDR
 		    " too large - resetting\n", clust);
 	    *value = 0;
@@ -216,13 +213,13 @@ getFAT(FATFS_INFO * fatfs, DADDR_T clust, DADDR_T * value)
 	    (sect - fatfs->table->addr) * fatfs->ssize +
 	    (clust * 4) % fatfs->ssize;
 
-	*value = getu32(fs, ptr) & FATFS_32_MASK;
+	*value = getu32(fs->endian, ptr) & FATFS_32_MASK;
 
 	/* sanity check */
 	if ((*value > fatfs->lastclust) &&
 	    (*value < (0x0ffffff7 & FATFS_32_MASK))) {
 	    if (verbose)
-		fprintf(stderr,
+		tsk_fprintf(stderr,
 		    "getFAT: contents of entry %" PRIuDADDR
 		    " too large - resetting\n", clust);
 
@@ -361,7 +358,7 @@ fatfs_block_walk(FS_INFO * fs, DADDR_T start_blk, DADDR_T end_blk,
     }
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "fatfs_block_walk: Block Walking %" PRIuDADDR " to %"
 	    PRIuDADDR "\n", start_blk, end_blk);
 
@@ -373,7 +370,7 @@ fatfs_block_walk(FS_INFO * fs, DADDR_T start_blk, DADDR_T end_blk,
 	&& ((flags & FS_FLAG_DATA_ALLOC) == FS_FLAG_DATA_ALLOC)) {
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"fatfs_block_walk: Walking non-data area (pre %"
 		PRIuDADDR "\n", fatfs->firstclustsect);
 
@@ -457,7 +454,7 @@ fatfs_block_walk(FS_INFO * fs, DADDR_T start_blk, DADDR_T end_blk,
     }
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "fatfs_block_walk: Walking data area blocks (%" PRIuDADDR
 	    " to %" PRIuDADDR ")\n", addr, end_blk);
 
@@ -483,7 +480,7 @@ fatfs_block_walk(FS_INFO * fs, DADDR_T start_blk, DADDR_T end_blk,
 
 	/* We want this cluster */
 	if ((flags & myflags) == myflags) {
-	    int read_size;
+	    DADDR_T read_size;
 
 	    /* The final cluster may not be full */
 	    if (end_blk - addr + 1 < fatfs->csize)
@@ -539,15 +536,17 @@ fatfs_block_walk(FS_INFO * fs, DADDR_T start_blk, DADDR_T end_blk,
 ** FAT dates are the actual date with the year relative to 1980
 ** 
 */
-static int
+static time_t
 dos2unixtime(uint16_t date, uint16_t time)
 {
     struct tm tm1;
-    int ret;
+    time_t ret;
 
     if (date == 0)
 	return 0;
 
+    memset(&tm1, 0, sizeof(struct tm));
+
     tm1.tm_sec = ((time & FATFS_SEC_MASK) >> FATFS_SEC_SHIFT) * 2;
     if ((tm1.tm_sec < 0) || (tm1.tm_sec > 60))
 	tm1.tm_sec = 0;
@@ -582,9 +581,9 @@ dos2unixtime(uint16_t date, uint16_t time)
 
     ret = mktime(&tm1);
 
-    if (-1 == ret) {
+    if (ret < 0) {
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"dos2unixtime: Error running mktime(): %d:%d:%d %d/%d/%d",
 		((time & FATFS_HOUR_MASK) >> FATFS_HOUR_SHIFT),
 		((time & FATFS_MIN_MASK) >> FATFS_MIN_SHIFT),
@@ -644,6 +643,7 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
 {
     int dcnt;
     int retval;
+    int i;
     FS_INFO *fs = (FS_INFO *) & fatfs->fs_info;
 
     fs_inode->mode = dos2unixmode(in->attrib);
@@ -661,7 +661,7 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
     }
     else {
 	fs_inode->nlink = (in->name[0] == FATFS_SLOT_DELETED) ? 0 : 1;
-	fs_inode->size = (OFF_T) getu32(fs, in->size);
+	fs_inode->size = (OFF_T) getu32(fs->endian, in->size);
     }
 
 
@@ -674,14 +674,15 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
     }
     else {
 
-	if (FATFS_ISDATE(getu16(fs, in->wdate)))
-	    fs_inode->mtime = dos2unixtime(getu16(fs, in->wdate),
-		getu16(fs, in->wtime));
+	if (FATFS_ISDATE(getu16(fs->endian, in->wdate)))
+	    fs_inode->mtime = dos2unixtime(getu16(fs->endian, in->wdate),
+		getu16(fs->endian, in->wtime));
 	else
 	    fs_inode->mtime = 0;
 
-	if (FATFS_ISDATE(getu16(fs, in->adate)))
-	    fs_inode->atime = dos2unixtime(getu16(fs, in->adate), 0);
+	if (FATFS_ISDATE(getu16(fs->endian, in->adate)))
+	    fs_inode->atime =
+		dos2unixtime(getu16(fs->endian, in->adate), 0);
 	else
 	    fs_inode->atime = 0;
 
@@ -690,9 +691,10 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
 	 * so we just put in into change and set create to 0.  The other
 	 * front-end code knows how to handle it and display it
 	 */
-	if (FATFS_ISDATE(getu16(fs, in->cdate)))
+	if (FATFS_ISDATE(getu16(fs->endian, in->cdate)))
 	    fs_inode->ctime =
-		dos2unixtime(getu16(fs, in->cdate), getu16(fs, in->ctime));
+		dos2unixtime(getu16(fs->endian, in->cdate),
+		getu16(fs->endian, in->ctime));
 	else
 	    fs_inode->ctime = 0;
     }
@@ -719,7 +721,7 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
 	UTF8 *name8 = (UTF8 *) fs_inode->name->name;
 	UTF16 *name16 = (UTF16 *) lfn->part1;
 
-	int retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+	int retVal = tsk_UTF16toUTF8(fs->endian, (const UTF16 **) &name16,
 	    (UTF16 *) & lfn->part1[10],
 	    &name8,
 	    (UTF8 *) ((uintptr_t) fs_inode->name->name + 512),
@@ -734,14 +736,14 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
 	    *name8 = '\0';
 
 	    if (verbose)
-		fprintf(stderr,
+		tsk_fprintf(stderr,
 		    "fatfs_dinode_copy: Error converting FAT LFN (1) to UTF8: %d",
 		    retVal);
 	    return 1;
 	}
 
 	name16 = (UTF16 *) lfn->part2;
-	retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+	retVal = tsk_UTF16toUTF8(fs->endian, (const UTF16 **) &name16,
 	    (UTF16 *) & lfn->part2[12],
 	    &name8,
 	    (UTF8 *) ((uintptr_t) fs_inode->name->
@@ -756,14 +758,14 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
 	    *name8 = '\0';
 
 	    if (verbose)
-		fprintf(stderr,
+		tsk_fprintf(stderr,
 		    "fatfs_dinode_copy: Error converting FAT LFN (2) to UTF8: %d",
 		    retVal);
 	    return 1;
 	}
 
 	name16 = (UTF16 *) lfn->part3;
-	retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+	retVal = tsk_UTF16toUTF8(fs->endian, (const UTF16 **) &name16,
 	    (UTF16 *) & lfn->part3[4],
 	    &name8,
 	    (UTF8 *) ((uintptr_t) fs_inode->name->
@@ -778,7 +780,7 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
 	    *name8 = '\0';
 
 	    if (verbose)
-		fprintf(stderr,
+		tsk_fprintf(stderr,
 		    "fatfs_dinode_copy: Error converting FAT LFN (3) to UTF8: %d",
 		    retVal);
 	    return 1;
@@ -789,6 +791,15 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
 	    fs_inode->name->name[511] = '\0';
 	else
 	    *name8 = '\0';
+
+	/* Clean up name */
+	i = 0;
+	while (fs_inode->name->name[i] != '\0') {
+	    if (TSK_IS_CNTRL(fs_inode->name->name[i]))
+		fs_inode->name->name[i] = '^';
+	    i++;
+	}
+
     }
     else if ((in->attrib & FATFS_ATTR_VOLUME) == FATFS_ATTR_VOLUME) {
 	int a, i = 0;
@@ -855,12 +866,20 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
 	((in->attrib & FATFS_ATTR_LFN) != FATFS_ATTR_LFN)) {
 
 	/* count the total number of clusters in this file */
-	uint32_t clust = FATFS_DENTRY_CLUST(fs, in);
+	DADDR_T clust = FATFS_DENTRY_CLUST(fs, in);
 	int cnum = 0;
 
 	while ((clust) && (0 == FATFS_ISEOF(clust, fatfs->mask))) {
 	    DADDR_T nxt;
 	    cnum++;
+	    // we must have found a loop -- @@@ Need a better fix
+	    if (cnum > fs->block_count) {
+		if (verbose)
+		    tsk_fprintf(stderr,
+			"Loop found while determining directory size\n");
+		cnum = 1;
+		break;
+	    }
 	    if (getFAT(fatfs, clust, &nxt))
 		break;
 	    else
@@ -927,7 +946,7 @@ fatfs_make_root(FATFS_INFO * fatfs, FS_INODE * fs_inode)
      * we will have to fake it.
      */
     if (fatfs->fs_info.ftype != FAT32) {
-	int snum;
+	DADDR_T snum;
 
 	/* Other code will have to check this as a special condition 
 	 */
@@ -941,8 +960,8 @@ fatfs_make_root(FATFS_INFO * fatfs, FS_INODE * fs_inode)
     }
     else {
 	/* Get the number of allocated clusters */
-	int cnum;
-	uint32_t clust;
+	DADDR_T cnum;
+	DADDR_T clust;
 
 	/* base cluster */
 	clust = FATFS_SECT_2_CLUST(fatfs, fatfs->rootsect);
@@ -997,19 +1016,19 @@ fatfs_isdentry(FATFS_INFO * fatfs, fatfs_dentry * de)
 	/* The ctime, cdate, and adate fields are optional and 
 	 * therefore 0 is a valid value
 	 */
-	if ((getu16(fs, de->ctime) != 0) &&
-	    (FATFS_ISTIME(getu16(fs, de->ctime)) == 0))
+	if ((getu16(fs->endian, de->ctime) != 0) &&
+	    (FATFS_ISTIME(getu16(fs->endian, de->ctime)) == 0))
 	    return 0;
-	else if ((getu16(fs, de->wtime) != 0) &&
-	    (FATFS_ISTIME(getu16(fs, de->wtime)) == 0))
+	else if ((getu16(fs->endian, de->wtime) != 0) &&
+	    (FATFS_ISTIME(getu16(fs->endian, de->wtime)) == 0))
 	    return 0;
-	else if ((getu16(fs, de->cdate) != 0) &&
-	    (FATFS_ISDATE(getu16(fs, de->cdate)) == 0))
+	else if ((getu16(fs->endian, de->cdate) != 0) &&
+	    (FATFS_ISDATE(getu16(fs->endian, de->cdate)) == 0))
 	    return 0;
-	else if ((getu16(fs, de->adate) != 0) &&
-	    (FATFS_ISDATE(getu16(fs, de->adate)) == 0))
+	else if ((getu16(fs->endian, de->adate) != 0) &&
+	    (FATFS_ISDATE(getu16(fs->endian, de->adate)) == 0))
 	    return 0;
-	else if (FATFS_ISDATE(getu16(fs, de->wdate)) == 0)
+	else if (FATFS_ISDATE(getu16(fs->endian, de->wdate)) == 0)
 	    return 0;
 
 	/* verify the starting cluster is small enough */
@@ -1032,7 +1051,7 @@ fatfs_isdentry(FATFS_INFO * fatfs, fatfs_dentry * de)
 /* Mark the sector used in the bitmap */
 static uint8_t
 inode_walk_file_act(FS_INFO * fs, DADDR_T addr, char *buf,
-    unsigned int size, int flags, void *ptr)
+    size_t size, int flags, void *ptr)
 {
     setbit((uint8_t *) ptr, addr);
     return WALK_CONT;
@@ -1101,7 +1120,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
     }
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "fatfs_inode_walk: Inode Walking %" PRIuINUM " to %"
 	    PRIuINUM "\n", start_inum, end_inum);
 
@@ -1148,17 +1167,32 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
      * dentries.  First, run dent_walk to find all sectors that are 
      * from allocated directories.  We'll be make sure to print those */
     if ((sect_alloc =
-	    (uint8_t *) mymalloc((fs->block_count + 7) / 8)) == NULL) {
+	    (uint8_t *) mymalloc((size_t) ((fs->block_count + 7) / 8))) ==
+	NULL) {
 	fs_inode_free(fs_inode);
 	return 1;
     }
 
-    memset((char *) sect_alloc, 0, sizeof(*sect_alloc));
+    memset((char *) sect_alloc, 0, (size_t) ((fs->block_count + 7) / 8));
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "fatfs_inode_walk: Walking directories to collect sector info\n");
 
+    /* We need to make a special run of the Root directory to get its sectors */
+    if (fatfs_make_root(fatfs, fs_inode)) {
+	fs_inode_free(fs_inode);
+	return 1;
+    }
+
+    if (fs->file_walk(fs, fs_inode, 0, 0,
+	    FS_FLAG_FILE_SLACK | FS_FLAG_FILE_AONLY |
+	    FS_FLAG_FILE_RECOVER, inode_walk_file_act,
+	    (void *) sect_alloc)) {
+	fs_inode_free(fs_inode);
+	return 1;
+    }
+
     if (fatfs_dent_walk(fs, fs->root_inum,
 	    FS_FLAG_NAME_ALLOC | FS_FLAG_NAME_RECURSE,
 	    inode_walk_dent_act, (void *) sect_alloc)) {
@@ -1169,6 +1203,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
     }
 
 
+
     /* As FAT does not give numbers to the directory entries, we will make
      * them up.  Start from one larger then the root inode number (which we
      * made up) and number each entry in each cluster
@@ -1233,7 +1268,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 	    inum = FATFS_SECT_2_INODE(fatfs, sect);
 
 	    if (verbose)
-		fprintf(stderr,
+		tsk_fprintf(stderr,
 		    "fatfs_inode_walk: Processing sector %" PRIuDADDR
 		    " (pre data area) starting at inode %" PRIuINUM
 		    "\n", sect, inum);
@@ -1308,7 +1343,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 		fs_inode->flags = myflags;
 
 		if (verbose)
-		    fprintf(stderr,
+		    tsk_fprintf(stderr,
 			"fatfs_inode_walk: Directory Entry %" PRIuINUM
 			" (%u) at sector %" PRIuDADDR "\n", inum, didx,
 			sect);
@@ -1338,7 +1373,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
      * Read by cluster since they are bigger and more effecient
      */
     for (sect = base_read; sect <= lsect; sect += fatfs->csize) {
-	unsigned int read_size;
+	DADDR_T read_size;
 	int clustalloc;
 
 	/* if the cluster is not allocated, then do not go into it if we 
@@ -1402,7 +1437,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 	    inum = FATFS_SECT_2_INODE(fatfs, sect + i);
 
 	    if (verbose)
-		fprintf(stderr,
+		tsk_fprintf(stderr,
 		    "fatfs_inode_walk: Processing sector %" PRIuDADDR
 		    " starting at inode %" PRIuINUM "\n", sect + i, inum);
 
@@ -1482,7 +1517,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 		fs_inode->flags = myflags;
 
 		if (verbose)
-		    fprintf(stderr,
+		    tsk_fprintf(stderr,
 			"fatfs_inode_walk: Directory Entry %" PRIuINUM
 			" (%u) at sector %" PRIuDADDR "\n", inum, didx,
 			sect + i);
@@ -1556,7 +1591,7 @@ fatfs_inode_lookup(FS_INFO * fs, INUM_T inum)
 
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "fatfs_inode_lookup: reading sector %" PRIuDADDR
 	    " for inode %" PRIuINUM "\n", sect, inum);
 
@@ -1649,7 +1684,8 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 	DADDR_T snum = fatfs->firstclustsect - fatfs->firstdatasect;
 
 	if (verbose)
-	    fprintf(stderr, "fatfs_file_walk: Walking Root Directory\n");
+	    tsk_fprintf(stderr,
+		"fatfs_file_walk: Walking Root Directory\n");
 
 	for (i = 0; i < snum; i++) {
 	    int retval;
@@ -1699,7 +1735,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"fatfs_file_walk: Walking deleted file %" PRIuINUM
 		" in recovery mode\n", fs_inode->addr);
 
@@ -1737,7 +1773,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 		"Starting cluster of deleted file is allocated");
 	    tsk_errstr2[0] = '\0';
 	    if (verbose) {
-		fprintf(stderr,
+		tsk_fprintf(stderr,
 		    "Starting cluster of deleted file is allocated - aborting\n");
 	    }
 	    data_buf_free(data_buf);
@@ -1765,7 +1801,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 		    "Could not find enough unallocated sectors to recover with");
 		tsk_errstr2[0] = '\0';
 		if (verbose)
-		    fprintf(stderr,
+		    tsk_fprintf(stderr,
 			"Could not find enough unallocated sectors to recover with - aborting\n");
 
 		data_buf_free(data_buf);
@@ -1843,10 +1879,11 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 		if (flags & FS_FLAG_FILE_SLACK)
 		    len = fatfs->ssize;
 		else
-		    len = (size < fatfs->ssize) ? size : fatfs->ssize;
+		    len =
+			(size < fatfs->ssize) ? (int) size : fatfs->ssize;
 
 		if (verbose)
-		    fprintf(stderr,
+		    tsk_fprintf(stderr,
 			"fatfs_file_walk: Processing %" PRIu32
 			" bytes of sector %" PRIuDADDR " for recovery\n",
 			len, (sbase + i));
@@ -1872,7 +1909,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
     else {
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"fatfs_file_walk: Walking file %" PRIuINUM
 		" in normal mode\n", fs_inode->addr);
 
@@ -1930,10 +1967,11 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 		if (flags & FS_FLAG_FILE_SLACK)
 		    len = fatfs->ssize;
 		else
-		    len = (size < fatfs->ssize) ? size : fatfs->ssize;
+		    len =
+			(size < fatfs->ssize) ? (int) size : fatfs->ssize;
 
 		if (verbose)
-		    fprintf(stderr,
+		    tsk_fprintf(stderr,
 			"fatfs_file_walk: Processing %" PRIu32
 			" bytes of sector %" PRIuDADDR "\n", len,
 			(sbase + i));
@@ -2051,29 +2089,29 @@ fatfs_fsstat(FS_INFO * fs, FILE * hFile)
 
     /* Print the general file system information */
 
-    fprintf(hFile, "FILE SYSTEM INFORMATION\n");
-    fprintf(hFile, "--------------------------------------------\n");
+    tsk_fprintf(hFile, "FILE SYSTEM INFORMATION\n");
+    tsk_fprintf(hFile, "--------------------------------------------\n");
 
-    fprintf(hFile, "File System Type: FAT");
+    tsk_fprintf(hFile, "File System Type: FAT");
     if (fs->ftype == FAT12)
-	fprintf(hFile, "12\n");
+	tsk_fprintf(hFile, "12\n");
     else if (fs->ftype == FAT16)
-	fprintf(hFile, "16\n");
+	tsk_fprintf(hFile, "16\n");
     else if (fs->ftype == FAT32)
-	fprintf(hFile, "32\n");
+	tsk_fprintf(hFile, "32\n");
     else
-	fprintf(hFile, "\n");
+	tsk_fprintf(hFile, "\n");
 
-    fprintf(hFile, "\nOEM Name: %c%c%c%c%c%c%c%c\n", sb->oemname[0],
+    tsk_fprintf(hFile, "\nOEM Name: %c%c%c%c%c%c%c%c\n", sb->oemname[0],
 	sb->oemname[1], sb->oemname[2], sb->oemname[3], sb->oemname[4],
 	sb->oemname[5], sb->oemname[6], sb->oemname[7]);
 
 
     if (fatfs->fs_info.ftype != FAT32) {
-	fprintf(hFile, "Volume ID: 0x%" PRIx32 "\n",
-	    getu32(fs, sb->a.f16.vol_id));
+	tsk_fprintf(hFile, "Volume ID: 0x%" PRIx32 "\n",
+	    getu32(fs->endian, sb->a.f16.vol_id));
 
-	fprintf(hFile,
+	tsk_fprintf(hFile,
 	    "Volume Label (Boot Sector): %c%c%c%c%c%c%c%c%c%c%c\n",
 	    sb->a.f16.vol_lab[0], sb->a.f16.vol_lab[1],
 	    sb->a.f16.vol_lab[2], sb->a.f16.vol_lab[3],
@@ -2083,17 +2121,17 @@ fatfs_fsstat(FS_INFO * fs, FILE * hFile)
 	    sb->a.f16.vol_lab[10]);
 
 	if ((de) && (de->name)) {
-	    fprintf(hFile,
+	    tsk_fprintf(hFile,
 		"Volume Label (Root Directory): %c%c%c%c%c%c%c%c%c%c%c\n",
 		de->name[0], de->name[1], de->name[2], de->name[3],
 		de->name[4], de->name[5], de->name[6], de->name[7],
 		de->name[8], de->name[9], de->name[10]);
 	}
 	else {
-	    fprintf(hFile, "Volume Label (Root Directory):\n");
+	    tsk_fprintf(hFile, "Volume Label (Root Directory):\n");
 	}
 
-	fprintf(hFile, "File System Type Label: %c%c%c%c%c%c%c%c\n",
+	tsk_fprintf(hFile, "File System Type Label: %c%c%c%c%c%c%c%c\n",
 	    sb->a.f16.fs_type[0], sb->a.f16.fs_type[1],
 	    sb->a.f16.fs_type[2], sb->a.f16.fs_type[3],
 	    sb->a.f16.fs_type[4], sb->a.f16.fs_type[5],
@@ -2110,10 +2148,10 @@ fatfs_fsstat(FS_INFO * fs, FILE * hFile)
 	    return 1;
 	}
 
-	fprintf(hFile, "Volume ID: 0x%" PRIx32 "\n",
-	    getu32(fs, sb->a.f32.vol_id));
+	tsk_fprintf(hFile, "Volume ID: 0x%" PRIx32 "\n",
+	    getu32(fs->endian, sb->a.f32.vol_id));
 
-	fprintf(hFile,
+	tsk_fprintf(hFile,
 	    "Volume Label (Boot Sector): %c%c%c%c%c%c%c%c%c%c%c\n",
 	    sb->a.f32.vol_lab[0], sb->a.f32.vol_lab[1],
 	    sb->a.f32.vol_lab[2], sb->a.f32.vol_lab[3],
@@ -2123,17 +2161,17 @@ fatfs_fsstat(FS_INFO * fs, FILE * hFile)
 	    sb->a.f32.vol_lab[10]);
 
 	if ((de) && (de->name)) {
-	    fprintf(hFile,
+	    tsk_fprintf(hFile,
 		"Volume Label (Root Directory): %c%c%c%c%c%c%c%c%c%c%c\n",
 		de->name[0], de->name[1], de->name[2], de->name[3],
 		de->name[4], de->name[5], de->name[6], de->name[7],
 		de->name[8], de->name[9], de->name[10]);
 	}
 	else {
-	    fprintf(hFile, "Volume Label (Root Directory):\n");
+	    tsk_fprintf(hFile, "Volume Label (Root Directory):\n");
 	}
 
-	fprintf(hFile, "File System Type Label: %c%c%c%c%c%c%c%c\n",
+	tsk_fprintf(hFile, "File System Type Label: %c%c%c%c%c%c%c%c\n",
 	    sb->a.f32.fs_type[0], sb->a.f32.fs_type[1],
 	    sb->a.f32.fs_type[2], sb->a.f32.fs_type[3],
 	    sb->a.f32.fs_type[4], sb->a.f32.fs_type[5],
@@ -2141,9 +2179,9 @@ fatfs_fsstat(FS_INFO * fs, FILE * hFile)
 
 
 	/* Process the FS info */
-	if (getu16(fs, sb->a.f32.fsinfo)) {
+	if (getu16(fs->endian, sb->a.f32.fsinfo)) {
 	    cnt = fs_read_block(fs, fat_fsinfo_buf, sizeof(fatfs_fsinfo),
-		(DADDR_T) getu16(fs, sb->a.f32.fsinfo));
+		(DADDR_T) getu16(fs->endian, sb->a.f32.fsinfo));
 
 	    if (cnt != sizeof(fatfs_fsinfo)) {
 		if (cnt != -1) {
@@ -2152,7 +2190,8 @@ fatfs_fsstat(FS_INFO * fs, FILE * hFile)
 		}
 		snprintf(tsk_errstr2, TSK_ERRSTR_L,
 		    "fatfs_fsstat: FAT32 FSINFO block: %"
-		    PRIuDADDR, (DADDR_T) getu16(fs, sb->a.f32.fsinfo));
+		    PRIuDADDR, (DADDR_T) getu16(fs->endian,
+			sb->a.f32.fsinfo));
 		data_buf_free(data_buf);
 		data_buf_free(fat_fsinfo_buf);
 		return 1;
@@ -2160,11 +2199,14 @@ fatfs_fsstat(FS_INFO * fs, FILE * hFile)
 
 
 	    fat_info = (fatfs_fsinfo *) fat_fsinfo_buf->data;
-	    fprintf(hFile, "Next Free Sector (FS Info): %" PRIuDADDR "\n",
-		FATFS_CLUST_2_SECT(fatfs, getu32(fs, fat_info->nextfree)));
+	    tsk_fprintf(hFile,
+		"Next Free Sector (FS Info): %" PRIuDADDR "\n",
+		FATFS_CLUST_2_SECT(fatfs, getu32(fs->endian,
+			fat_info->nextfree)));
 
-	    fprintf(hFile, "Free Sector Count (FS Info): %" PRIu32 "\n",
-		(getu32(fs, fat_info->freecnt) * fatfs->csize));
+	    tsk_fprintf(hFile,
+		"Free Sector Count (FS Info): %" PRIu32 "\n",
+		(getu32(fs->endian, fat_info->freecnt) * fatfs->csize));
 
 	    data_buf_free(fat_fsinfo_buf);
 	}
@@ -2172,59 +2214,59 @@ fatfs_fsstat(FS_INFO * fs, FILE * hFile)
 
     data_buf_free(data_buf);
 
-    fprintf(hFile, "\nSectors before file system: %" PRIu32 "\n",
-	getu32(fs, sb->prevsect));
+    tsk_fprintf(hFile, "\nSectors before file system: %" PRIu32 "\n",
+	getu32(fs->endian, sb->prevsect));
 
-    fprintf(hFile, "\nFile System Layout (in sectors)\n");
+    tsk_fprintf(hFile, "\nFile System Layout (in sectors)\n");
 
-    fprintf(hFile, "Total Range: %" PRIuDADDR " - %" PRIuDADDR "\n",
+    tsk_fprintf(hFile, "Total Range: %" PRIuDADDR " - %" PRIuDADDR "\n",
 	fs->first_block, fs->last_block);
 
-    fprintf(hFile, "* Reserved: 0 - %" PRIuDADDR "\n",
+    tsk_fprintf(hFile, "* Reserved: 0 - %" PRIuDADDR "\n",
 	fatfs->firstfatsect - 1);
 
-    fprintf(hFile, "** Boot Sector: 0\n");
+    tsk_fprintf(hFile, "** Boot Sector: 0\n");
 
     if (fatfs->fs_info.ftype == FAT32) {
-	fprintf(hFile, "** FS Info Sector: %" PRIu16 "\n",
-	    getu16(fs, sb->a.f32.fsinfo));
+	tsk_fprintf(hFile, "** FS Info Sector: %" PRIu16 "\n",
+	    getu16(fs->endian, sb->a.f32.fsinfo));
 
-	fprintf(hFile, "** Backup Boot Sector: %" PRIu32 "\n",
-	    getu32(fs, sb->a.f32.bs_backup));
+	tsk_fprintf(hFile, "** Backup Boot Sector: %" PRIu32 "\n",
+	    getu32(fs->endian, sb->a.f32.bs_backup));
     }
 
     for (i = 0; i < fatfs->numfat; i++) {
 	DADDR_T base = fatfs->firstfatsect + i * (fatfs->sectperfat);
 
-	fprintf(hFile, "* FAT %d: %" PRIuDADDR " - %" PRIuDADDR "\n", i,
-	    base, (base + fatfs->sectperfat - 1));
+	tsk_fprintf(hFile, "* FAT %d: %" PRIuDADDR " - %" PRIuDADDR "\n",
+	    i, base, (base + fatfs->sectperfat - 1));
     }
 
-    fprintf(hFile, "* Data Area: %" PRIuDADDR " - %" PRIuDADDR "\n",
+    tsk_fprintf(hFile, "* Data Area: %" PRIuDADDR " - %" PRIuDADDR "\n",
 	fatfs->firstdatasect, fs->last_block);
 
     if (fatfs->fs_info.ftype != FAT32) {
-	uint32_t x = fatfs->csize * (fatfs->lastclust - 1);
+	DADDR_T x = fatfs->csize * (fatfs->lastclust - 1);
 
-	fprintf(hFile,
+	tsk_fprintf(hFile,
 	    "** Root Directory: %" PRIuDADDR " - %" PRIuDADDR "\n",
 	    fatfs->firstdatasect, fatfs->firstclustsect - 1);
 
-	fprintf(hFile,
+	tsk_fprintf(hFile,
 	    "** Cluster Area: %" PRIuDADDR " - %" PRIuDADDR "\n",
 	    fatfs->firstclustsect, (fatfs->firstclustsect + x - 1));
 
 	if ((fatfs->firstclustsect + x - 1) != fs->last_block) {
-	    fprintf(hFile,
+	    tsk_fprintf(hFile,
 		"** Non-clustered: %" PRIuDADDR " - %" PRIuDADDR "\n",
 		(fatfs->firstclustsect + x), fs->last_block);
 	}
     }
     else {
-	uint32_t x = fatfs->csize * (fatfs->lastclust - 1);
-	uint32_t clust, clust_p;
+	DADDR_T x = fatfs->csize * (fatfs->lastclust - 1);
+	DADDR_T clust, clust_p;
 
-	fprintf(hFile,
+	tsk_fprintf(hFile,
 	    "** Cluster Area: %" PRIuDADDR " - %" PRIuDADDR "\n",
 	    fatfs->firstclustsect, (fatfs->firstclustsect + x - 1));
 
@@ -2239,34 +2281,34 @@ fatfs_fsstat(FS_INFO * fs, FILE * hFile)
 	    clust = nxt;
 	}
 
-	fprintf(hFile,
+	tsk_fprintf(hFile,
 	    "*** Root Directory: %" PRIuDADDR " - %" PRIuDADDR "\n",
 	    fatfs->rootsect, (FATFS_CLUST_2_SECT(fatfs, clust_p + 1) - 1));
 
 
 	if ((fatfs->firstclustsect + x - 1) != fs->last_block) {
-	    fprintf(hFile,
+	    tsk_fprintf(hFile,
 		"** Non-clustered: %" PRIuDADDR " - %" PRIuDADDR "\n",
 		(fatfs->firstclustsect + x), fs->last_block);
 	}
     }
 
 
-    fprintf(hFile, "\nMETADATA INFORMATION\n");
-    fprintf(hFile, "--------------------------------------------\n");
+    tsk_fprintf(hFile, "\nMETADATA INFORMATION\n");
+    tsk_fprintf(hFile, "--------------------------------------------\n");
 
-    fprintf(hFile, "Range: %" PRIuINUM " - %" PRIuINUM "\n",
+    tsk_fprintf(hFile, "Range: %" PRIuINUM " - %" PRIuINUM "\n",
 	fs->first_inum, fs->last_inum);
-    fprintf(hFile, "Root Directory: %" PRIuINUM "\n", fs->root_inum);
+    tsk_fprintf(hFile, "Root Directory: %" PRIuINUM "\n", fs->root_inum);
 
 
-    fprintf(hFile, "\nCONTENT INFORMATION\n");
-    fprintf(hFile, "--------------------------------------------\n");
-    fprintf(hFile, "Sector Size: %" PRIu16 "\n", fatfs->ssize);
-    fprintf(hFile, "Cluster Size: %" PRIu32 "\n",
+    tsk_fprintf(hFile, "\nCONTENT INFORMATION\n");
+    tsk_fprintf(hFile, "--------------------------------------------\n");
+    tsk_fprintf(hFile, "Sector Size: %" PRIu16 "\n", fatfs->ssize);
+    tsk_fprintf(hFile, "Cluster Size: %" PRIu32 "\n",
 	(uint32_t) fatfs->csize * fatfs->ssize);
 
-    fprintf(hFile, "Total Cluster Range: 2 - %" PRIuDADDR "\n",
+    tsk_fprintf(hFile, "Total Cluster Range: 2 - %" PRIuDADDR "\n",
 	fatfs->lastclust);
 
 
@@ -2287,23 +2329,23 @@ fatfs_fsstat(FS_INFO * fs, FILE * hFile)
 	}
 
 	if (cnt == 0)
-	    fprintf(hFile, "Bad Sectors: ");
+	    tsk_fprintf(hFile, "Bad Sectors: ");
 
 	sect = FATFS_CLUST_2_SECT(fatfs, i);
 	for (a = 0; a < fatfs->csize; a++) {
-	    fprintf(hFile, "%" PRIuDADDR " ", sect + a);
+	    tsk_fprintf(hFile, "%" PRIuDADDR " ", sect + a);
 	    if ((++cnt % 8) == 0)
-		fprintf(hFile, "\n");
+		tsk_fprintf(hFile, "\n");
 	}
     }
     if ((cnt > 0) && ((cnt % 8) != 0))
-	fprintf(hFile, "\n");
+	tsk_fprintf(hFile, "\n");
 
 
 
     /* Display the FAT Table */
-    fprintf(hFile, "\nFAT CONTENTS (in sectors)\n");
-    fprintf(hFile, "--------------------------------------------\n");
+    tsk_fprintf(hFile, "\nFAT CONTENTS (in sectors)\n");
+    tsk_fprintf(hFile, "--------------------------------------------\n");
 
     /* 'sstart' marks the first sector of the current run to print */
     sstart = fatfs->firstclustsect;
@@ -2332,15 +2374,15 @@ fatfs_fsstat(FS_INFO * fs, FILE * hFile)
 	 */
 	else if ((next & fatfs->mask)) {
 	    if (FATFS_ISEOF(next, fatfs->mask))
-		fprintf(hFile,
+		tsk_fprintf(hFile,
 		    "%" PRIuDADDR "-%" PRIuDADDR " (%" PRIuDADDR
 		    ") -> EOF\n", sstart, send, send - sstart + 1);
 	    else if (FATFS_ISBAD(next, fatfs->mask))
-		fprintf(hFile,
+		tsk_fprintf(hFile,
 		    "%" PRIuDADDR "-%" PRIuDADDR " (%" PRIuDADDR
 		    ") -> BAD\n", sstart, send, send - sstart + 1);
 	    else
-		fprintf(hFile,
+		tsk_fprintf(hFile,
 		    "%" PRIuDADDR "-%" PRIuDADDR " (%" PRIuDADDR
 		    ") -> %" PRIuDADDR "\n", sstart, send,
 		    send - sstart + 1, snext);
@@ -2368,14 +2410,14 @@ typedef struct {
 
 static uint8_t
 print_addr_act(FS_INFO * fs, DADDR_T addr, char *buf,
-    unsigned int size, int flags, void *ptr)
+    size_t size, int flags, void *ptr)
 {
     FATFS_PRINT_ADDR *print = (FATFS_PRINT_ADDR *) ptr;
 
-    fprintf(print->hFile, "%" PRIuDADDR " ", addr);
+    tsk_fprintf(print->hFile, "%" PRIuDADDR " ", addr);
 
     if (++(print->idx) == 8) {
-	fprintf(print->hFile, "\n");
+	tsk_fprintf(print->hFile, "\n");
 	print->idx = 0;
     }
     print->istat_seen = 1;
@@ -2386,7 +2428,7 @@ print_addr_act(FS_INFO * fs, DADDR_T addr, char *buf,
 
 /* Return 1 on error  and 0 on success */
 static uint8_t
-fatfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
+fatfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, DADDR_T numblock,
     int32_t sec_skew)
 {
     FS_INODE *fs_inode;
@@ -2397,76 +2439,76 @@ fatfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
     if ((fs_inode = fatfs_inode_lookup(fs, inum)) == NULL) {
 	return 1;
     }
-    fprintf(hFile, "Directory Entry: %" PRIuINUM "\n", inum);
+    tsk_fprintf(hFile, "Directory Entry: %" PRIuINUM "\n", inum);
 
-    fprintf(hFile, "%sAllocated\n",
+    tsk_fprintf(hFile, "%sAllocated\n",
 	(fs_inode->flags & FS_FLAG_META_UNALLOC) ? "Not " : "");
 
-    fprintf(hFile, "File Attributes: ");
+    tsk_fprintf(hFile, "File Attributes: ");
 
     /* This should only be null if we have the root directory */
     if (fatfs->dep == NULL) {
 	if (inum == fs->root_inum)
-	    fprintf(hFile, "Directory\n");
+	    tsk_fprintf(hFile, "Directory\n");
 	else
-	    fprintf(hFile, "File\n");
+	    tsk_fprintf(hFile, "File\n");
     }
     else if ((fatfs->dep->attrib & FATFS_ATTR_LFN) == FATFS_ATTR_LFN) {
-	fprintf(hFile, "Long File Name\n");
+	tsk_fprintf(hFile, "Long File Name\n");
     }
     else {
 	if (fatfs->dep->attrib & FATFS_ATTR_DIRECTORY)
-	    fprintf(hFile, "Directory");
+	    tsk_fprintf(hFile, "Directory");
 	else if (fatfs->dep->attrib & FATFS_ATTR_VOLUME)
-	    fprintf(hFile, "Volume Label");
+	    tsk_fprintf(hFile, "Volume Label");
 	else
-	    fprintf(hFile, "File");
+	    tsk_fprintf(hFile, "File");
 
 	if (fatfs->dep->attrib & FATFS_ATTR_READONLY)
-	    fprintf(hFile, ", Read Only");
+	    tsk_fprintf(hFile, ", Read Only");
 	if (fatfs->dep->attrib & FATFS_ATTR_HIDDEN)
-	    fprintf(hFile, ", Hidden");
+	    tsk_fprintf(hFile, ", Hidden");
 	if (fatfs->dep->attrib & FATFS_ATTR_SYSTEM)
-	    fprintf(hFile, ", System");
+	    tsk_fprintf(hFile, ", System");
 	if (fatfs->dep->attrib & FATFS_ATTR_ARCHIVE)
-	    fprintf(hFile, ", Archive");
+	    tsk_fprintf(hFile, ", Archive");
 
-	fprintf(hFile, "\n");
+	tsk_fprintf(hFile, "\n");
     }
 
-    fprintf(hFile, "Size: %" PRIuOFF "\n", fs_inode->size);
+    tsk_fprintf(hFile, "Size: %" PRIuOFF "\n", fs_inode->size);
     /* This value is fake in FAT, so there is no point in printing it here */
-    //fprintf(hFile, "Num of links: %lu\n", (ULONG) fs_inode->nlink);
+    //tsk_fprintf(hFile, "Num of links: %lu\n", (ULONG) fs_inode->nlink);
 
     if (fs_inode->name) {
 	fs_name = fs_inode->name;
-	fprintf(hFile, "Name: %s\n", fs_name->name);
+	tsk_fprintf(hFile, "Name: %s\n", fs_name->name);
     }
 
     if (sec_skew != 0) {
-	fprintf(hFile, "\nAdjusted Directory Entry Times:\n");
+	tsk_fprintf(hFile, "\nAdjusted Directory Entry Times:\n");
 	fs_inode->mtime -= sec_skew;
 	fs_inode->atime -= sec_skew;
 	fs_inode->ctime -= sec_skew;
 
-	fprintf(hFile, "Written:\t%s", ctime(&fs_inode->mtime));
-	fprintf(hFile, "Accessed:\t%s", ctime(&fs_inode->atime));
-	fprintf(hFile, "Created:\t%s", ctime(&fs_inode->ctime));
+	tsk_fprintf(hFile, "Written:\t%s", ctime(&fs_inode->mtime));
+	tsk_fprintf(hFile, "Accessed:\t%s", ctime(&fs_inode->atime));
+	tsk_fprintf(hFile, "Created:\t%s", ctime(&fs_inode->ctime));
 
 	fs_inode->mtime += sec_skew;
 	fs_inode->atime += sec_skew;
 	fs_inode->ctime += sec_skew;
 
-	fprintf(hFile, "\nOriginal Directory Entry Times:\n");
+	tsk_fprintf(hFile, "\nOriginal Directory Entry Times:\n");
     }
     else
-	fprintf(hFile, "\nDirectory Entry Times:\n");
+	tsk_fprintf(hFile, "\nDirectory Entry Times:\n");
 
-    fprintf(hFile, "Written:\t%s", ctime(&fs_inode->mtime));
-    fprintf(hFile, "Accessed:\t%s", ctime(&fs_inode->atime));
-    fprintf(hFile, "Created:\t%s", ctime(&fs_inode->ctime));
+    tsk_fprintf(hFile, "Written:\t%s", ctime(&fs_inode->mtime));
+    tsk_fprintf(hFile, "Accessed:\t%s", ctime(&fs_inode->atime));
+    tsk_fprintf(hFile, "Created:\t%s", ctime(&fs_inode->ctime));
 
-    fprintf(hFile, "\nSectors:\n");
+    tsk_fprintf(hFile, "\nSectors:\n");
 
     /* A bad hack to force a specified number of blocks */
     if (numblock > 0)
@@ -2479,17 +2521,17 @@ fatfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
     if (fs->file_walk(fs, fs_inode, 0, 0,
 	    (FS_FLAG_FILE_AONLY | FS_FLAG_FILE_SLACK |
 		FS_FLAG_FILE_NOID), print_addr_act, (void *) &print)) {
-	fprintf(hFile, "\nError reading file\n");
+	tsk_fprintf(hFile, "\nError reading file\n");
 	tsk_error_print(hFile);
 	tsk_error_reset();
     }
     else if (print.idx != 0) {
-	fprintf(hFile, "\n");
+	tsk_fprintf(hFile, "\n");
     }
 
     /* Display the recovery information if we can */
     if (fs_inode->flags & FS_FLAG_META_UNALLOC) {
-	fprintf(hFile, "\nRecovery:\n");
+	tsk_fprintf(hFile, "\nRecovery:\n");
 
 
 	print.istat_seen = 0;
@@ -2499,14 +2541,14 @@ fatfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
 		    FS_FLAG_FILE_RECOVER | FS_FLAG_FILE_NOID),
 		print_addr_act, (void *) &print)) {
 	    if (tsk_errno != TSK_ERR_FS_RECOVER)
-		fprintf(hFile, "\nError reading file\n");
+		tsk_fprintf(hFile, "\nError reading file\n");
 	}
 
 	if (print.istat_seen == 0) {
-	    fprintf(hFile, "File recovery not possible\n");
+	    tsk_fprintf(hFile, "File recovery not possible\n");
 	}
 	else if (print.idx != 0)
-	    fprintf(hFile, "\n");
+	    tsk_fprintf(hFile, "\n");
 
     }
 
@@ -2574,7 +2616,7 @@ fatfs_open(IMG_INFO * img_info, SSIZE_T offset, uint8_t ftype,
     unsigned int len;
     FS_INFO *fs;
     fatfs_sb *fatsb;
-    uint32_t clustcnt, sectors;
+    DADDR_T clustcnt, sectors;
     SSIZE_T cnt;
 
 
@@ -2628,7 +2670,7 @@ fatfs_open(IMG_INFO * img_info, SSIZE_T offset, uint8_t ftype,
     }
 
     fs->dev_bsize = FATFS_DEV_BSIZE;
-    fatfs->ssize = getu16(fs, fatsb->ssize);
+    fatfs->ssize = getu16(fs->endian, fatsb->ssize);
 
     if ((fatfs->ssize % 512) ||
 	((fatfs->ssize != 512) && (fatfs->ssize != 1024) &&
@@ -2674,16 +2716,16 @@ fatfs_open(IMG_INFO * img_info, SSIZE_T offset, uint8_t ftype,
 
     /* We can't do a sanity check on this b.c. FAT32 has a value of 0 */
     /* num of root entries */
-    fatfs->numroot = getu16(fs, fatsb->numroot);
+    fatfs->numroot = getu16(fs->endian, fatsb->numroot);
 
 
     /* if sectors16 is 0, then the number of sectors is stored in sectors32 */
-    if (0 == (sectors = getu16(fs, fatsb->sectors16)))
-	sectors = getu32(fs, fatsb->sectors32);
+    if (0 == (sectors = getu16(fs->endian, fatsb->sectors16)))
+	sectors = getu32(fs->endian, fatsb->sectors32);
 
     /* if secperfat16 is 0, then read sectperfat32 */
-    if (0 == (fatfs->sectperfat = getu16(fs, fatsb->sectperfat16)))
-	fatfs->sectperfat = getu32(fs, fatsb->a.f32.sectperfat32);
+    if (0 == (fatfs->sectperfat = getu16(fs->endian, fatsb->sectperfat16)))
+	fatfs->sectperfat = getu32(fs->endian, fatsb->a.f32.sectperfat32);
 
     if (fatfs->sectperfat == 0) {
 	free(fatsb);
@@ -2695,7 +2737,7 @@ fatfs_open(IMG_INFO * img_info, SSIZE_T offset, uint8_t ftype,
 	return NULL;
     }
 
-    fatfs->firstfatsect = getu16(fs, fatsb->reserved);
+    fatfs->firstfatsect = getu16(fs->endian, fatsb->reserved);
     if ((fatfs->firstfatsect == 0) || (fatfs->firstfatsect > sectors)) {
 	free(fatsb);
 	free(fatfs);
@@ -2814,7 +2856,7 @@ fatfs_open(IMG_INFO * img_info, SSIZE_T offset, uint8_t ftype,
      */
     if (ftype == FAT32)
 	fatfs->rootsect = FATFS_CLUST_2_SECT(fatfs,
-	    getu32(fs, fatsb->a.f32.rootclust));
+	    getu32(fs->endian, fatsb->a.f32.rootclust));
     else
 	fatfs->rootsect = fatfs->firstdatasect;
 
