@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2006/03/27 03:33:19 $
+** $Date: 2006/08/29 17:13:10 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -82,7 +82,7 @@ extern "C" {
     (DADDR_T)((i - 3)/(fatfs->dentry_cnt_se) + fatfs->firstdatasect)
 
 #define FATFS_INODE_2_OFF(fatfs, i)     \
-    (((i - 3) % fatfs->dentry_cnt_se) * sizeof(fatfs_dentry))
+    (unsigned int)(((i - 3) % fatfs->dentry_cnt_se) * sizeof(fatfs_dentry))
 
 
 
@@ -174,7 +174,7 @@ extern "C" {
  * cluster 
  */
 #define FATFS_DENTRY_CLUST(fsi, de)	\
-	(DADDR_T)((getu16(fsi, de->startclust)) | (getu16(fsi, de->highclust)<<16))
+	(DADDR_T)((getu16(fsi->endian, de->startclust)) | (getu16(fsi->endian, de->highclust)<<16))
 
 /* constants for first byte of name[] */
 #define FATFS_SLOT_EMPTY	0x00
