@@ -2,7 +2,7 @@
 ** fatfs_dent
 ** The Sleuth Kit 
 **
-** $Date: 2006/07/05 18:24:09 $
+** $Date: 2006/08/30 21:09:11 $
 **
 ** Human interface Layer support for the FAT file system
 **
@@ -20,9 +20,8 @@
 **
 */
 
-#include "fs_tools.h"
+#include "fs_tools_i.h"
 #include "fatfs.h"
-#include "fs_unicode.h"
 
 /*
  * DESIGN NOTES
@@ -55,8 +54,8 @@ typedef struct {
     uint8_t seq;		/* seq of first entry in lfn */
 } FATFS_LFN;
 
-#define MAX_DEPTH   64
-#define DIR_STRSZ  2048
+#define MAX_DEPTH   	128
+#define DIR_STRSZ  	4096
 
 typedef struct {
     /* Recursive path stuff */
@@ -138,7 +137,7 @@ find_parent(FATFS_INFO * fatfs, FS_DENT * fs_dent)
     dinfo.find_clust = fs_dent->fsi->direct_addr[0];
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "fatfs_find_parent: Looking for directory in cluster %"
 	    PRIuDADDR "\n", dinfo.find_clust);
 
@@ -176,7 +175,7 @@ find_parent(FATFS_INFO * fatfs, FS_DENT * fs_dent)
 
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "fatfs_find_parent: Directory %" PRIuINUM
 	    " found for cluster %" PRIuDADDR "\n", dinfo.find_inode,
 	    dinfo.find_clust);
@@ -200,7 +199,7 @@ find_parent(FATFS_INFO * fatfs, FS_DENT * fs_dent)
 */
 static int8_t
 fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
-    char *buf, int len,
+    char *buf, OFF_T len,
     DADDR_T * addrs, int flags, FS_DENT_WALK_FN action, void *ptr)
 {
     unsigned int idx, sidx;
@@ -247,7 +246,7 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 	}
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"fatfs_dent_parse_buf: Parsing sector %" PRIuDADDR
 		"\n", addrs[sidx]);
 
@@ -260,6 +259,7 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 	for (idx = 0; idx < fatfs->dentry_cnt_se; idx++, dep++) {
 	    fatfs_dentry *dir;
 	    int myflags = 0;
+	    int i;
 
 	    /* is it a valid dentry? */
 	    if (0 == fatfs_isdentry(fatfs, dep))
@@ -320,14 +320,20 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 		a = 0;
 
 		for (b = 0; b < 8; b++) {
-		    if ((dir->name[b] != 0) && (dir->name[b] != 0xff)) {
+		    if ((dir->name[b] >= 0x20) && (dir->name[b] != 0xff)) {
 			fs_dent->name[a++] = dir->name[b];
 		    }
+		    else {
+			fs_dent->name[a++] = '^';
+		    }
 		}
 		for (b = 0; b < 3; b++) {
-		    if ((dir->ext[b] != 0) && (dir->ext[b] != 0xff)) {
+		    if ((dir->ext[b] >= 0x20) && (dir->ext[b] != 0xff)) {
 			fs_dent->name[a++] = dir->ext[b];
 		    }
+		    else {
+			fs_dent->name[a++] = '^';
+		    }
 		}
 
 		fs_dent->name[a] = '\0';
@@ -357,9 +363,10 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 			name[lfninfo.start + 1]);
 		    UTF8 *name8 = (UTF8 *) fs_dent->name;
 
-		    retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
-			(UTF16 *) & lfninfo.
-			name[FATFS_MAXNAMLEN_UTF8],
+		    retVal =
+			tsk_UTF16toUTF8(fs->endian,
+			(const UTF16 **) &name16,
+			(UTF16 *) & lfninfo.name[FATFS_MAXNAMLEN_UTF8],
 			&name8,
 			(UTF8 *) ((uintptr_t) name8 +
 			    FATFS_MAXNAMLEN_UTF8), lenientConversion);
@@ -379,6 +386,15 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 		    else
 			*name8 = '\0';
 
+		    /* Clean up name */
+		    i = 0;
+		    while (fs_dent->name[i] != '\0') {
+			if (TSK_IS_CNTRL(fs_dent->name[i]))
+			    fs_dent->name[i] = '^';
+			i++;
+		    }
+
+
 		    lfninfo.start = FATFS_MAXNAMLEN_UTF8 - 1;
 		    name_ptr = fs_dent->shrt_name;	// put 8.3 into shrt_name
 		}
@@ -424,6 +440,14 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 		name_ptr[a] = '\0';
 	    }
 
+	    /* Clean up name */
+	    i = 0;
+	    while (fs_dent->name[i] != '\0') {
+		if (TSK_IS_CNTRL(fs_dent->name[i]))
+		    fs_dent->name[i] = '^';
+		i++;
+	    }
+
 	    /* add the path data */
 	    fs_dent->path = dinfo->dirs;
 	    fs_dent->pathdepth = dinfo->depth;
@@ -441,7 +465,7 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 	    if (fatfs_dinode_copy(fatfs, fs_dent->fsi, dir, addrs[sidx],
 		    inode)) {
 		if (verbose)
-		    fprintf(stderr,
+		    tsk_fprintf(stderr,
 			"fatfs_dent_parse: could not copy inode -- ignoring\n");
 	    }
 
@@ -451,7 +475,12 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 	     * slot in the cluster, but it needs to refer to the original
 	     * slot 
 	     */
-	    if (dep->name[0] == '.') {
+	    if ((dep->name[0] == '.') &&
+		(dep->name[2] == ' ') && (dep->name[3] == ' ') &&
+		(dep->name[4] == ' ') && (dep->name[5] == ' ') &&
+		(dep->name[6] == ' ') && (dep->name[7] == ' ') &&
+		(dep->name[8] == ' ') && (dep->name[9] == ' ') &&
+		(dep->name[10] == ' ') && (dep->name[11] == '\0')) {
 
 		/* dinfo->curdir_inode is always set and we can copy it in */
 		if (dep->name[1] == ' ')
@@ -471,7 +500,7 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 		    if (inode == fs->root_inum) {
 			if (fatfs_make_root(fatfs, fs_dent->fsi)) {
 			    if (verbose)
-				fprintf(stderr,
+				tsk_fprintf(stderr,
 				    "fatfs_dent_parse: could not make root directory -- ignoring\n");
 			}
 		    }
@@ -512,15 +541,19 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 
 		INUM_T back_p = 0;
 		uint8_t back_recdel = 0;
+		int depth_added = 0;
 
 
 		/* append our name */
-		if (dinfo->depth < MAX_DEPTH) {
+		if ((dinfo->depth < MAX_DEPTH) &&
+		    (DIR_STRSZ >
+			strlen(dinfo->dirs) + strlen(fs_dent->name))) {
 		    dinfo->didx[dinfo->depth] =
 			&dinfo->dirs[strlen(dinfo->dirs)];
 		    strncpy(dinfo->didx[dinfo->depth], fs_dent->name,
 			DIR_STRSZ - strlen(dinfo->dirs));
 		    strncat(dinfo->dirs, "/", DIR_STRSZ);
+		    depth_added = 1;
 		}
 
 		/* save the .. inode value */
@@ -541,7 +574,7 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 		    /* If the directory could not be loaded,
 		     *                  * then move on */
 		    if (verbose) {
-			fprintf(stderr,
+			tsk_fprintf(stderr,
 			    "fatfs_dent_parse: error reading directory: %"
 			    PRIuINUM "\n", fs_dent->inode);
 			tsk_error_print(stderr);
@@ -553,7 +586,7 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 		dinfo->curdir_inode = dinfo->pardir_inode;
 		dinfo->pardir_inode = back_p;
 
-		if (dinfo->depth < MAX_DEPTH)
+		if (depth_added)
 		    *dinfo->didx[dinfo->depth] = '\0';
 
 		/* Restore the recursion setting */
@@ -603,12 +636,12 @@ typedef struct {
  */
 static uint8_t
 fatfs_dent_action(FS_INFO * fs, DADDR_T addr, char *buf,
-    unsigned int size, int flags, void *ptr)
+    size_t size, int flags, void *ptr)
 {
     FATFS_LOAD_DIR *load = (FATFS_LOAD_DIR *) ptr;
 
     /* how much of the buffer are we copying */
-    int len = (load->dirleft < size) ? load->dirleft : size;
+    size_t len = (load->dirleft < size) ? load->dirleft : size;
 
     /* Copy the sector into a buffer and increment the pointers */
     memcpy(load->curdirptr, buf, len);
@@ -620,7 +653,7 @@ fatfs_dent_action(FS_INFO * fs, DADDR_T addr, char *buf,
      * if we are at the last entry, then realloc more */
     if (load->addridx == load->addrsize) {
 	if (verbose)
-	    fprintf(stderr, "fatfs_dent_action: realloc curaddrbuf");
+	    tsk_fprintf(stderr, "fatfs_dent_action: realloc curaddrbuf");
 
 	load->addrsize += 512;
 	load->curaddrbuf = (DADDR_T *) myrealloc((char *) load->curaddrbuf,
@@ -692,7 +725,7 @@ fatfs_dent_walk_lcl(FS_INFO * fs, FATFS_DINFO * dinfo, INUM_T inode,
     len = roundup(size, 512);
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "fatfs_dent_walk: Processing directory %" PRIuINUM "\n",
 	    inode);
 
@@ -700,13 +733,13 @@ fatfs_dent_walk_lcl(FS_INFO * fs, FATFS_DINFO * dinfo, INUM_T inode,
     dinfo->curdir_inode = inode;
 
     /* Make a copy of the directory contents using file_walk */
-    if ((dirbuf = mymalloc(len)) == NULL) {
+    if ((dirbuf = mymalloc((size_t) len)) == NULL) {
 	fs_inode_free(fs_inode);
 	return 1;
     }
-    memset(dirbuf, 0, len);
+    memset(dirbuf, 0, (size_t) len);
     load.curdirptr = dirbuf;
-    load.dirleft = size;
+    load.dirleft = (size_t) size;
 
     /* We are going to save the address of each sector in the directory
      * in a stack - they are needed to determine the inode address */
