@@ -2,7 +2,7 @@
 ** ffind  (file find)
 ** The Sleuth Kit 
 **
-** $Date: 2006/07/10 13:26:20 $
+** $Date: 2006/08/30 21:09:11 $
 **
 ** Find the file that uses the specified inode (including deleted files)
 ** 
@@ -20,42 +20,46 @@
 ** This software is distributed under the Common Public License 1.0
 **
 */
-#include "libfstools.h"
+#include <locale.h>
+#include "fs_tools.h"
+
+static TCHAR *progname;
 
 void
 usage()
 {
-    fprintf(stderr,
-	"usage: %s [-aduvV] [-f fstype] [-i imgtype] [-o imgoffset] image [images] inode\n",
+    TFPRINTF(stderr,
+	_T
+	("usage: %s [-aduvV] [-f fstype] [-i imgtype] [-o imgoffset] image [images] inode\n"),
 	progname);
-    fprintf(stderr, "\t-a: Find all occurrences\n");
-    fprintf(stderr, "\t-d: Find deleted entries ONLY\n");
-    fprintf(stderr, "\t-u: Find undeleted entries ONLY\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr, "\t-a: Find all occurrences\n");
+    tsk_fprintf(stderr, "\t-d: Find deleted entries ONLY\n");
+    tsk_fprintf(stderr, "\t-u: Find undeleted entries ONLY\n");
+    tsk_fprintf(stderr,
 	"\t-f fstype: Image file system type (use '-f list' for supported types)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-i imgtype: The format of the image file (use '-i list' for supported types)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-o imgoffset: The offset of the file system in the image (in sectors)\n");
-    fprintf(stderr, "\t-v: Verbose output to stderr\n");
-    fprintf(stderr, "\t-V: Print version\n");
+    tsk_fprintf(stderr, "\t-v: Verbose output to stderr\n");
+    tsk_fprintf(stderr, "\t-V: Print version\n");
 
     exit(1);
 }
 
 
 int
-main(int argc, char **argv)
+MAIN(int argc, TCHAR ** argv)
 {
-    char *fstype = NULL;
+    TCHAR *fstype = NULL;
+    TCHAR *imgtype = NULL;
     int flags = FS_FLAG_NAME_RECURSE;
     int ch;
-    char *cp;
     FS_INFO *fs;
     extern int optind;
     uint32_t type;
     uint16_t id;
-    char *imgtype = NULL, *dash;
+    int id_used;
     IMG_INFO *img;
     uint8_t localflags = 0;
     INUM_T inode;
@@ -64,48 +68,46 @@ main(int argc, char **argv)
     progname = argv[0];
     setlocale(LC_ALL, "");
 
-    while ((ch = getopt(argc, argv, "adf:i:o:uvV")) > 0) {
+    while ((ch = getopt(argc, argv, _T("adf:i:o:uvV"))) > 0) {
 	switch (ch) {
-	case 'a':
+	case _T('a'):
 	    localflags |= FFIND_ALL;
 	    break;
-	case 'd':
+	case _T('d'):
 	    flags |= FS_FLAG_NAME_UNALLOC;
 	    break;
-	case 'f':
+	case _T('f'):
 	    fstype = optarg;
-	    if (strcmp(fstype, "list") == 0) {
+	    if (TSTRCMP(fstype, _T("list")) == 0) {
 		fs_print_types(stderr);
 		exit(1);
 	    }
-
 	    break;
-	case 'i':
+	case _T('i'):
 	    imgtype = optarg;
-	    if (strcmp(imgtype, "list") == 0) {
+	    if (TSTRCMP(imgtype, _T("list")) == 0) {
 		img_print_types(stderr);
 		exit(1);
 	    }
-
 	    break;
-	case 'o':
+	case _T('o'):
 	    if ((imgoff = parse_offset(optarg)) == -1) {
 		tsk_error_print(stderr);
 		exit(1);
 	    }
 	    break;
-	case 'u':
+	case _T('u'):
 	    flags |= FS_FLAG_NAME_ALLOC;
 	    break;
-	case 'v':
+	case _T('v'):
 	    verbose++;
 	    break;
-	case 'V':
+	case _T('V'):
 	    print_version(stdout);
 	    exit(0);
-	case '?':
+	case _T('?'):
 	default:
-	    fprintf(stderr, "Invalid argument: %s\n", argv[optind]);
+	    TFPRINTF(stderr, _T("Invalid argument: %s\n"), argv[optind]);
 	    usage();
 	}
     }
@@ -119,48 +121,23 @@ main(int argc, char **argv)
 
 
     if (optind + 1 >= argc) {
-	fprintf(stderr, "Missing image name and/or address\n");
+	tsk_fprintf(stderr, "Missing image name and/or address\n");
 	usage();
     }
 
 
-    /* we have the inum-type or inum-type-id format */
-    type = 0;
-    id = 0;
-    if ((dash = strchr(argv[argc - 1], '-')) != NULL) {
-	char *dash2;
-
-	*dash = '\0';
-	dash++;
-
-	/* We have an id */
-	if ((dash2 = strchr(dash, '-')) != NULL) {
-	    *dash2 = '\0';
-	    dash2++;
-
-	    id = (uint16_t) strtoul(dash2, &cp, 0);
-	    if (*cp || cp == dash2) {
-		fprintf(stderr, "Invalid id in inode: %s\n", dash2);
-		usage();
-	    }
-	}
-	type = strtoul(dash, &cp, 0);
-	if (*cp || cp == dash) {
-	    fprintf(stderr, "Invalid type in inode: %s\n", dash);
-	    usage();
-	}
-    }
-    inode = strtoull(argv[argc - 1], &cp, 0);
-    if (*cp || cp == argv[argc - 1]) {
-	fprintf(stderr, "Invalid inode address: %s\n", argv[argc - 1]);
+    /* Get the inode */
+    if (parse_inum(argv[argc - 1], &inode, &type, &id, &id_used)) {
+	TFPRINTF(stderr, _T("Invalid inode: %s\n"), argv[argc - 1]);
 	usage();
     }
-
+    if (id_used == 0)
+	flags |= FS_FLAG_FILE_NOID;
 
     /* open image */
     if ((img =
 	    img_open(imgtype, argc - optind - 1,
-		(const char **) &argv[optind])) == NULL) {
+		(const TCHAR **) &argv[optind])) == NULL) {
 	tsk_error_print(stderr);
 	exit(1);
     }
@@ -172,14 +149,15 @@ main(int argc, char **argv)
 	exit(1);
     }
 
-
     if (inode < fs->first_inum) {
-	fprintf(stderr, "Inode is too small for image (%" PRIuINUM ")\n",
+	tsk_fprintf(stderr,
+	    "Inode is too small for image (%" PRIuINUM ")\n",
 	    fs->first_inum);
 	exit(1);
     }
     if (inode > fs->last_inum) {
-	fprintf(stderr, "Inode is too large for image (%" PRIuINUM ")\n",
+	tsk_fprintf(stderr,
+	    "Inode is too large for image (%" PRIuINUM ")\n",
 	    fs->last_inum);
 	exit(1);
     }
@@ -193,6 +171,5 @@ main(int argc, char **argv)
 
     fs->close(fs);
     img->close(img);
-
     exit(0);
 }
