@@ -2,7 +2,7 @@
 ** ffs_dent
 ** The  Sleuth Kit 
 **
-** $Date: 2006/07/05 18:24:09 $
+** $Date: 2006/08/30 21:09:11 $
 **
 ** File name layer for a FFS/UFS image 
 **
@@ -22,12 +22,12 @@
 */
 
 #include <ctype.h>
-#include "fs_tools.h"
+#include "fs_tools_i.h"
 #include "ffs.h"
 
 
-#define MAX_DEPTH   64
-#define DIR_STRSZ  2048
+#define MAX_DEPTH   128
+#define DIR_STRSZ   4096
 
 typedef struct {
     /* Recursive path stuff */
@@ -57,12 +57,13 @@ ffs_dent_copy(FFS_INFO * ffs, FFS_DINFO * dinfo, char *ffs_dent,
     FS_DENT * fs_dent)
 {
     FS_INFO *fs = &(ffs->fs_info);
+    int i;
 
     /* this one has the type field */
     if ((fs->ftype == FFS_1) || (fs->ftype == FFS_2)) {
 	ffs_dentry1 *dir = (ffs_dentry1 *) ffs_dent;
 
-	fs_dent->inode = getu32(fs, dir->d_ino);
+	fs_dent->inode = getu32(fs->endian, dir->d_ino);
 
 	if (fs_dent->name_max != FFS_MAXNAMLEN) {
 	    if ((fs_dent =
@@ -80,7 +81,7 @@ ffs_dent_copy(FFS_INFO * ffs, FFS_DINFO * dinfo, char *ffs_dent,
     else if (fs->ftype == FFS_1B) {
 	ffs_dentry2 *dir = (ffs_dentry2 *) ffs_dent;
 
-	fs_dent->inode = getu32(fs, dir->d_ino);
+	fs_dent->inode = getu32(fs->endian, dir->d_ino);
 
 	if (fs_dent->name_max != FFS_MAXNAMLEN) {
 	    if ((fs_dent =
@@ -101,6 +102,14 @@ ffs_dent_copy(FFS_INFO * ffs, FFS_DINFO * dinfo, char *ffs_dent,
 	return 1;
     }
 
+    /* Clean up name */
+    i = 0;
+    while (fs_dent->name[i] != '\0') {
+	if (TSK_IS_CNTRL(fs_dent->name[i]))
+	    fs_dent->name[i] = '^';
+	i++;
+    }
+
     /* copy the path data */
     fs_dent->path = dinfo->dirs;
     fs_dent->pathdepth = dinfo->depth;
@@ -163,16 +172,16 @@ ffs_dent_parse_block(FFS_INFO * ffs, FFS_DINFO * dinfo, char *buf,
 	/* copy to local variables */
 	if ((fs->ftype == FFS_1) || (fs->ftype == FFS_2)) {
 	    ffs_dentry1 *dir = (ffs_dentry1 *) dirPtr;
-	    inode = getu32(fs, dir->d_ino);
+	    inode = getu32(fs->endian, dir->d_ino);
 	    namelen = dir->d_namlen;
-	    reclen = getu16(fs, dir->d_reclen);
+	    reclen = getu16(fs->endian, dir->d_reclen);
 	}
 	/* FFS_1B */
 	else if (fs->ftype == FFS_1B) {
 	    ffs_dentry2 *dir = (ffs_dentry2 *) dirPtr;
-	    inode = getu32(fs, dir->d_ino);
-	    namelen = getu16(fs, dir->d_namlen);
-	    reclen = getu16(fs, dir->d_reclen);
+	    inode = getu32(fs->endian, dir->d_ino);
+	    namelen = getu16(fs->endian, dir->d_namlen);
+	    reclen = getu16(fs->endian, dir->d_reclen);
 	}
 
 	/* what is the minimum size needed for this entry */
@@ -260,14 +269,18 @@ ffs_dent_parse_block(FFS_INFO * ffs, FFS_DINFO * dinfo, char *buf,
 	    (flags & FS_FLAG_NAME_RECURSE) &&
 	    (!ISDOT(fs_dent->name)) &&
 	    ((fs_dent->fsi->mode & FS_INODE_FMT) == FS_INODE_DIR)) {
+	    int depth_added = 0;
 
 	    /* save the path */
-	    if (dinfo->depth < MAX_DEPTH) {
+	    if ((dinfo->depth < MAX_DEPTH) &&
+		(DIR_STRSZ >
+		    strlen(dinfo->dirs) + strlen(fs_dent->name))) {
 		dinfo->didx[dinfo->depth] =
 		    &dinfo->dirs[strlen(dinfo->dirs)];
 		strncpy(dinfo->didx[dinfo->depth], fs_dent->name,
 		    DIR_STRSZ - strlen(dinfo->dirs));
 		strncat(dinfo->dirs, "/", DIR_STRSZ);
+		depth_added = 1;
 	    }
 	    dinfo->depth++;
 
@@ -277,7 +290,7 @@ ffs_dent_parse_block(FFS_INFO * ffs, FFS_DINFO * dinfo, char *buf,
 		/* If the directory could not be loaded, 
 		 * then move on */
 		if (verbose) {
-		    fprintf(stderr,
+		    tsk_fprintf(stderr,
 			"ffs_dent_parse_block: error reading directory: %"
 			PRIuINUM "\n", fs_dent->inode);
 		    tsk_error_print(stderr);
@@ -286,7 +299,7 @@ ffs_dent_parse_block(FFS_INFO * ffs, FFS_DINFO * dinfo, char *buf,
 	    }
 
 	    dinfo->depth--;
-	    if (dinfo->depth < MAX_DEPTH)
+	    if (depth_added)
 		*dinfo->didx[dinfo->depth] = '\0';
 	}
 
@@ -340,7 +353,7 @@ ffs_dent_walk_lcl(FS_INFO * fs, FFS_DINFO * dinfo, INUM_T inode, int flags,
     }
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "ffs_dent_walk: Processing directory %" PRIuINUM "\n", inode);
 
     if ((fs_inode = fs->inode_lookup(fs, inode)) == NULL) {
@@ -352,12 +365,12 @@ ffs_dent_walk_lcl(FS_INFO * fs, FFS_DINFO * dinfo, INUM_T inode, int flags,
     /* make a copy of the directory contents that we can process */
     /* round up cause we want the slack space too */
     size = roundup(fs_inode->size, FFS_DIRBLKSIZ);
-    if ((dirbuf = mymalloc(size)) == NULL) {
+    if ((dirbuf = mymalloc((size_t) size)) == NULL) {
 	fs_inode_free(fs_inode);
 	return 1;
     }
 
-    load_file.total = load_file.left = size;
+    load_file.total = load_file.left = (size_t) size;
     load_file.base = load_file.cur = dirbuf;
 
     if (fs->file_walk(fs, fs_inode, 0, 0,
@@ -387,10 +400,10 @@ ffs_dent_walk_lcl(FS_INFO * fs, FFS_DINFO * dinfo, INUM_T inode, int flags,
      **
      ** Entries do not cross over the DIRBLKSIZ boundary
      */
-    nchnk = (size) / (FFS_DIRBLKSIZ) + 1;
+    nchnk = (int) (size) / (FFS_DIRBLKSIZ) + 1;
 
     for (cidx = 0; cidx < nchnk && size > 0; cidx++) {
-	int len = (FFS_DIRBLKSIZ < size) ? FFS_DIRBLKSIZ : size;
+	int len = (FFS_DIRBLKSIZ < size) ? FFS_DIRBLKSIZ : (int) size;
 
 	retval =
 	    ffs_dent_parse_block(ffs, dinfo, dirbuf + cidx * FFS_DIRBLKSIZ,
