@@ -2,7 +2,7 @@
 ** fs_data
 ** The Sleuth Kit 
 **
-** $Date: 2006/07/10 15:09:56 $
+** $Date: 2006/08/29 17:13:15 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -27,7 +27,7 @@
  * a flag identifies it as a resident stream or a non-resident run
  * They form a linked list and are added to the FS_INODE structure
  */
-#include "fs_tools.h"
+#include "fs_tools_i.h"
 #include "ntfs.h"
 
 /* 
@@ -146,7 +146,7 @@ void
 fs_data_clear_list(FS_DATA * data)
 {
     while (data) {
-	data->flags = data->size = data->type = data->id = 0;
+	data->size = data->type = data->id = data->flags = 0;
 	if (data->run) {
 	    fs_data_run_free(data->run);
 	    data->run = NULL;
@@ -391,7 +391,7 @@ FS_DATA *
 fs_data_put_run(FS_DATA * data_head,
     DADDR_T start_vcn, OFF_T runlen, FS_DATA_RUN * run,
     char *name, uint32_t type, uint16_t id, OFF_T size, uint8_t flags,
-    uint64_t compsize)
+    uint32_t compsize)
 {
     FS_DATA *data;
     FS_DATA_RUN *data_run, *data_run_prev;
