@@ -2,7 +2,7 @@
 ** fs_open
 ** The Sleuth Kit 
 **
-** $Date: 2006/07/05 21:12:59 $
+** $Date: 2006/08/30 21:09:11 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -26,7 +26,7 @@
  *	Yorktown Heights, NY 10598, USA
  --*/
 
-#include "fs_tools.h"
+#include "fs_tools_i.h"
 
 /* 
  * fs_open - open a file system 
@@ -36,10 +36,9 @@
  */
 
 FS_INFO *
-fs_open(IMG_INFO * img_info, SSIZE_T offset, const char *type)
+fs_open(IMG_INFO * img_info, SSIZE_T offset, const TCHAR * type)
 {
 
-
     /* We will try different file systems ... 
      * We need to try all of them in case more than one matches
      */
@@ -48,8 +47,8 @@ fs_open(IMG_INFO * img_info, SSIZE_T offset, const char *type)
 	char *set = NULL;
 
 	if (verbose)
-	    fprintf(stderr,
-		"fsopen: Auto detection mode at offset %" PRIuOFF "\n",
+	    tsk_fprintf(stderr,
+		"fsopen: Auto detection mode at offset %" PRIuSSIZE "\n",
 		offset);
 
 	if ((fs_info = ntfs_open(img_info, offset, NTFS, 1)) != NULL) {
