@@ -1,4 +1,4 @@
-#include "fs_tools.h"
+#include "fs_tools_i.h"
 #include "hfs.h"
 
 void
