@@ -2,7 +2,7 @@
 ** ifind (inode find)
 ** The Sleuth Kit
 **
-** $Date: 2006/07/05 18:24:09 $
+** $Date: 2006/08/30 21:09:12 $
 **
 ** Given an image  and block number, identify which inode it is used by
 ** 
@@ -21,7 +21,7 @@
 **
 */
 
-#include "libfstools.h"
+#include "fs_tools_i.h"
 
 
 static uint8_t localflags;
@@ -57,7 +57,7 @@ ifind_par_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 	    else {
 		fs_dent_print(stdout, fs_dent, FS_FLAG_NAME_UNALLOC, fs,
 		    NULL);
-		printf("\n");
+		tsk_printf("\n");
 	    }
 	    fs_dent->fsi = NULL;
 	    found = 1;
@@ -128,7 +128,6 @@ ifind_path_act(FS_INFO * fs, FS_DENT * fs_dent, int flags, void *ptr)
      *
      * All non-matches will return from these checks
      */
-
     if (((fs->ftype & FSMASK) == EXTxFS_TYPE) ||
 	((fs->ftype & FSMASK) == FFS_TYPE)) {
 	if (strcmp(fs_dent->name, cur_dir) != 0) {
@@ -159,8 +158,8 @@ ifind_path_act(FS_INFO * fs, FS_DENT * fs_dent, int flags, void *ptr)
 		}
 	    }
 	    if (fail) {
-		printf("Attribute name (%s) not found in %s: %" PRIuINUM
-		    "\n", cur_attr, cur_dir, fs_dent->inode);
+		tsk_printf("Attribute name (%s) not found in %s: %"
+		    PRIuINUM "\n", cur_attr, cur_dir, fs_dent->inode);
 
 		return WALK_STOP;
 	    }
@@ -182,12 +181,12 @@ ifind_path_act(FS_INFO * fs, FS_DENT * fs_dent, int flags, void *ptr)
     cur_attr = NULL;
 
     if (verbose)
-	fprintf(stderr, "Found it (%s), now looking for %s\n",
+	tsk_fprintf(stderr, "Found it (%s), now looking for %s\n",
 	    fs_dent->name, cur_dir);
 
     /* That was the last one */
     if (cur_dir == NULL) {
-	printf("%" PRIuINUM "\n", fs_dent->inode);
+	tsk_printf("%" PRIuINUM "\n", fs_dent->inode);
 	found = 1;
 	return WALK_STOP;
     }
@@ -213,7 +212,7 @@ ifind_path_act(FS_INFO * fs, FS_DENT * fs_dent, int flags, void *ptr)
 
     /* The name was correct, but it was not a directory */
     else {
-	printf("Invalid path (%s is a file)\n", fs_dent->name);
+	tsk_printf("Invalid path (%s is a file)\n", fs_dent->name);
     }
 
     return WALK_STOP;
@@ -222,17 +221,55 @@ ifind_path_act(FS_INFO * fs, FS_DENT * fs_dent, int flags, void *ptr)
 
 /* Return 1 for error, 0 if no error */
 uint8_t
-fs_ifind_path(FS_INFO * fs, uint8_t lclflags, char *path)
+fs_ifind_path(FS_INFO * fs, uint8_t lclflags, TCHAR * tpath)
 {
+    char *cpath;
+
     found = 0;
     localflags = lclflags;
 
-    cur_dir = (char *) strtok(path, "/");
+#ifdef TSK_WIN32
+    {
+	size_t clen;
+	UTF8 *ptr8;
+	UTF16 *ptr16;
+	int retval;
+
+	clen = TSTRLEN(tpath) * 4;
+	cpath = (char *) mymalloc(clen);
+	if (cpath == NULL) {
+	    return 1;
+	}
+	ptr8 = (UTF8 *) cpath;
+	ptr16 = (UTF16 *) tpath;
+
+	retval =
+	    tsk_UTF16toUTF8(fs->endian, (const UTF16 **) &ptr16, (UTF16 *)
+	    & ptr16[TSTRLEN(tpath) + 1], &ptr8,
+	    (UTF8 *) ((uintptr_t) ptr8 + clen), lenientConversion);
+	if (retval != conversionOK) {
+	    tsk_errno = TSK_ERR_FS_UNICODE;
+	    snprintf(tsk_errstr, TSK_ERRSTR_L,
+		"fs_ifind_path: Error converting path to UTF-8: %d",
+		retval);
+	    tsk_errstr2[0] = '\0';
+	    free(cpath);
+	    return 1;
+	}
+    }
+#else
+    cpath = tpath;
+#endif
+
+    cur_dir = (char *) strtok(cpath, "/");
     cur_attr = NULL;
 
     /* If there is no token, then only a '/' was given */
     if (!cur_dir) {
-	printf("%lu\n", (ULONG) fs->root_inum);
+	tsk_printf("%lu\n", (ULONG) fs->root_inum);
+#ifdef TSK_WIN32
+	free(cpath);
+#endif
 	return 0;
     }
 
@@ -244,17 +281,24 @@ fs_ifind_path(FS_INFO * fs, uint8_t lclflags, char *path)
     }
 
     if (verbose)
-	fprintf(stderr, "Looking for %s\n", cur_dir);
+	tsk_fprintf(stderr, "Looking for %s\n", cur_dir);
 
     if (fs->dent_walk(fs, fs->root_inum,
 	    FS_FLAG_NAME_ALLOC | FS_FLAG_NAME_UNALLOC, ifind_path_act,
 	    NULL)) {
+#ifdef TSK_WIN32
+	free(cpath);
+#endif
 	return 1;
     }
 
     if (0 == found) {
-	printf("File not found: %s\n", cur_dir);
+	tsk_printf("File not found: %s\n", cur_dir);
     }
+
+#ifdef TSK_WIN32
+    free(cpath);
+#endif
     return 0;
 }
 
@@ -277,7 +321,7 @@ static uint16_t curid;
  */
 static uint8_t
 ifind_data_file_act(FS_INFO * fs, DADDR_T addr, char *buf,
-    unsigned int size, int flags, void *ptr)
+    size_t size, int flags, void *ptr)
 {
     /* Drop references to block zero (sparse)
      * This becomes an issue with fragments and looking for fragments
@@ -289,7 +333,7 @@ ifind_data_file_act(FS_INFO * fs, DADDR_T addr, char *buf,
 
     if ((block >= addr) &&
 	(block < (addr + (size + fs->block_size - 1) / fs->block_size))) {
-	printf("%" PRIuINUM "\n", curinode);
+	tsk_printf("%" PRIuINUM "\n", curinode);
 
 	if (!(localflags & IFIND_ALL)) {
 	    fs->close(fs);
@@ -307,10 +351,10 @@ ifind_data_file_act(FS_INFO * fs, DADDR_T addr, char *buf,
  */
 static uint8_t
 ifind_data_file_ntfs_act(FS_INFO * fs, DADDR_T addr, char *buf,
-    unsigned int size, int flags, void *ptr)
+    size_t size, int flags, void *ptr)
 {
     if (addr == block) {
-	printf("%" PRIuINUM "-%" PRIu32 "-%" PRIu16 "\n", curinode,
+	tsk_printf("%" PRIuINUM "-%" PRIu32 "-%" PRIu16 "\n", curinode,
 	    curtype, curid);
 
 	if (!(localflags & IFIND_ALL)) {
@@ -352,9 +396,11 @@ ifind_data_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 		if (fs->file_walk(fs, fs_inode, data->type, data->id,
 			file_flags, ifind_data_file_ntfs_act, ptr)) {
 		    if (verbose)
-			fprintf(stderr, "Error walking file %" PRIuINUM,
+			tsk_fprintf(stderr,
+			    "Error walking file %" PRIuINUM,
 			    fs_inode->addr);
-/* Ignore these errors */
+
+		    /* Ignore these errors */
 		    tsk_error_reset();
 		}
 	    }
@@ -367,9 +413,10 @@ ifind_data_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 	if (fs->file_walk(fs, fs_inode, 0, 0, file_flags,
 		ifind_data_file_act, ptr)) {
 	    if (verbose)
-		fprintf(stderr, "Error walking file %" PRIuINUM,
+		tsk_fprintf(stderr, "Error walking file %" PRIuINUM,
 		    fs_inode->addr);
-/* Ignore these errors */
+
+	    /* Ignore these errors */
 	    tsk_error_reset();
 	}
     }
@@ -384,9 +431,10 @@ ifind_data_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 	if (fs->file_walk(fs, fs_inode, 0, 0, file_flags,
 		ifind_data_file_act, ptr)) {
 	    if (verbose)
-		fprintf(stderr, "Error walking file %" PRIuINUM,
+		tsk_fprintf(stderr, "Error walking file %" PRIuINUM,
 		    fs_inode->addr);
-/* Ignore these errors */
+
+	    /* Ignore these errors */
 	    tsk_error_reset();
 	}
     }
@@ -404,7 +452,7 @@ ifind_data_block_act(FS_INFO * fs, DADDR_T addr, char *buf, int flags,
     void *ptr)
 {
     if (flags & FS_FLAG_DATA_META) {
-	printf("Meta Data\n");
+	tsk_printf("Meta Data\n");
 	found = 1;
     }
 
@@ -441,7 +489,7 @@ fs_ifind_data(FS_INFO * fs, uint8_t lclflags, DADDR_T blk)
 	}
     }
     if (0 == found) {
-	printf("Inode not found\n");
+	tsk_printf("Inode not found\n");
     }
     return 0;
 }
