@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2006/07/10 13:26:20 $
+** $Date: 2006/08/30 21:09:12 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -24,61 +24,41 @@
  *	P.O. Box 704
  *	Yorktown Heights, NY 10598, USA
  --*/
+#include <locale.h>
+#include "fs_tools.h"
 
-#include "libfstools.h"
-
-
-/* atoinum - convert string to inode number */
-
-INUM_T
-atoinum(const char *str)
-{
-    char *cp;
-    INUM_T inum;
-
-    if (*str == 0)
-	return (0);
-
-    inum = strtoull(str, &cp, 0);
-    if (*cp || cp == str) {
-	fprintf(stderr, "bad inode number: %s", str);
-	exit(1);
-    }
-
-    return (inum);
-}
+static TCHAR *progname;
 
 /* usage - explain and terminate */
-
 static void
 usage()
 {
-    fprintf(stderr,
-	"usage: %s [-eOmrvV] [-aAlLzZ] [-f fstype] [-i imgtype] [-o imgoffset] [-s seconds] image [images] [inum[-end]]\n",
+    TFPRINTF(stderr,
+	_T
+	("usage: %s [-eOmrvV] [-aAlLzZ] [-f fstype] [-i imgtype] [-o imgoffset] [-s seconds] image [images] [inum[-end]]\n"),
 	progname);
-
-    fprintf(stderr, "\t-e: Display all inodes\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr, "\t-e: Display all inodes\n");
+    tsk_fprintf(stderr,
 	"\t-O: Display inodes that are removed, but sill open (was -o)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-m: Display output in the mactime format (replaces ils2mac from TCT)\n");
-    fprintf(stderr, "\t-r: Display removed inodes (default)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr, "\t-r: Display removed inodes (default)\n");
+    tsk_fprintf(stderr,
 	"\t-s seconds: Time skew of original machine (in seconds)\n");
-    fprintf(stderr, "\t-a: Allocated files\n");
-    fprintf(stderr, "\t-A: Un-Allocated files\n");
-    fprintf(stderr, "\t-l: Linked files\n");
-    fprintf(stderr, "\t-L: Un-Linked files\n");
-    fprintf(stderr, "\t-z: Un-Used files (ctime is 0)\n");
-    fprintf(stderr, "\t-Z: Used files (ctime is not 0)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr, "\t-a: Allocated files\n");
+    tsk_fprintf(stderr, "\t-A: Un-Allocated files\n");
+    tsk_fprintf(stderr, "\t-l: Linked files\n");
+    tsk_fprintf(stderr, "\t-L: Un-Linked files\n");
+    tsk_fprintf(stderr, "\t-z: Un-Used files (ctime is 0)\n");
+    tsk_fprintf(stderr, "\t-Z: Used files (ctime is not 0)\n");
+    tsk_fprintf(stderr,
 	"\t-i imgtype: The format of the image file (use '-i list' for supported types)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-f fstype: File system type (use '-f list' for supported types)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-o imgoffset: The offset of the file system in the image (in sectors)\n");
-    fprintf(stderr, "\t-v: verbose output to stderr\n");
-    fprintf(stderr, "\t-V: Display version number\n");
+    tsk_fprintf(stderr, "\t-v: verbose output to stderr\n");
+    tsk_fprintf(stderr, "\t-V: Display version number\n");
     exit(1);
 }
 
@@ -87,20 +67,19 @@ usage()
 /* main - open file system, list inode info */
 
 int
-main(int argc, char **argv)
+MAIN(int argc, TCHAR ** argv)
 {
+    TCHAR *fstype = NULL;
+    TCHAR *imgtype = NULL, *cp, *dash;
+    IMG_INFO *img;
+    FS_INFO *fs;
     INUM_T istart = 0, ilast = 0;
     int ch;
     int flags = 0;
-
     int argflags = 0;
-    char *fstype = NULL;
-    FS_INFO *fs;
-    char *imgtype = NULL, *cp, *dash;
     SSIZE_T imgoff = 0;
-    IMG_INFO *img;
     int set_range = 1;
-    char *image = NULL;
+    TCHAR *image = NULL;
     int32_t sec_skew = 0;
 
     progname = argv[0];
@@ -110,81 +89,79 @@ main(int argc, char **argv)
      * Provide convenience options for the most commonly selected feature
      * combinations.
      */
-    while ((ch = getopt(argc, argv, "aAef:i:lLo:Omrs:vVzZ")) > 0) {
+    while ((ch = getopt(argc, argv, _T("aAef:i:lLo:Omrs:vVzZ"))) > 0) {
 	switch (ch) {
-	case '?':
+	case _T('?'):
 	default:
-	    fprintf(stderr, "Invalid argument: %s\n", argv[optind]);
+	    TFPRINTF(stderr, _T("Invalid argument: %s\n"), argv[optind]);
 	    usage();
-	case 'e':
+	case _T('e'):
 	    flags |= ~0;
 	    break;
-	case 'f':
+	case _T('f'):
 	    fstype = optarg;
-	    if (strcmp(fstype, "list") == 0) {
+	    if (TSTRCMP(fstype, _T("list")) == 0) {
 		fs_print_types(stderr);
 		exit(1);
 	    }
-
 	    break;
-	case 'i':
+	case _T('i'):
 	    imgtype = optarg;
-	    if (strcmp(imgtype, "list") == 0) {
+	    if (TSTRCMP(imgtype, _T("list")) == 0) {
 		img_print_types(stderr);
 		exit(1);
 	    }
-
 	    break;
-	case 'm':
+	case _T('m'):
 	    argflags |= ILS_MAC;
 	    break;
-	case 'o':
+	case _T('o'):
 	    if ((imgoff = parse_offset(optarg)) == -1) {
 		tsk_error_print(stderr);
 		exit(1);
 	    }
 	    break;
-	case 'O':
+	case _T('O'):
 	    flags |= (FS_FLAG_META_ALLOC | FS_FLAG_META_UNLINK);
 	    argflags |= ILS_OPEN;
 	    break;
-	case 'r':
+	case _T('r'):
 	    argflags |= ILS_REM;
 	    break;
-	case 's':
-	    sec_skew = atoi(optarg);
+	case _T('s'):
+	    sec_skew = TATOI(optarg);
 	    break;
-	case 'v':
+	case _T('v'):
 	    verbose++;
 	    break;
-	case 'V':
+	case _T('V'):
 	    print_version(stdout);
 	    exit(0);
 
 	    /*
 	     * Provide fine controls to tweak one feature at a time.
 	     */
-	case 'a':
+	case _T('a'):
 	    flags |= FS_FLAG_META_ALLOC;
 	    flags &= ~FS_FLAG_META_UNALLOC;
 	    break;
-	case 'A':
+	case _T('A'):
 	    flags |= FS_FLAG_META_UNALLOC;
 	    flags &= ~FS_FLAG_META_ALLOC;
 	    break;
-	case 'l':
+	case _T('l'):
 	    flags |= FS_FLAG_META_LINK;
 	    flags &= ~FS_FLAG_META_UNLINK;
 	    break;
-	case 'L':
+	case _T('L'):
 	    flags |= FS_FLAG_META_UNLINK;
 	    flags &= ~FS_FLAG_META_LINK;
 	    break;
-	case 'z':
+	case _T('z'):
 	    flags |= FS_FLAG_META_UNUSED;
 	    flags &= ~FS_FLAG_META_USED;
 	    break;
-	case 'Z':
+	case _T('Z'):
 	    flags |= FS_FLAG_META_USED;
 	    flags &= ~FS_FLAG_META_UNUSED;
 	    break;
@@ -192,25 +169,23 @@ main(int argc, char **argv)
     }
 
     if (optind >= argc) {
-	fprintf(stderr, "Missing image name\n");
+	tsk_fprintf(stderr, "Missing image name\n");
 	usage();
     }
 
-
     /* We need to determine if an inode or inode range was given */
-    if ((dash = strchr(argv[argc - 1], '-')) == NULL) {
+    if ((dash = TSTRCHR(argv[argc - 1], _T('-'))) == NULL) {
 	/* Check if is a single number */
-	istart = strtoull(argv[argc - 1], &cp, 0);
+	istart = TSTRTOULL(argv[argc - 1], &cp, 0);
 	if (*cp || cp == argv[argc - 1]) {
 	    /* Not a number - consider it a file name */
 	    image = argv[optind];
 	    if ((img =
 		    img_open(imgtype, argc - optind,
-			(const char **) &argv[optind])) == NULL) {
+			(const TCHAR **) &argv[optind])) == NULL) {
 		tsk_error_print(stderr);
 		exit(1);
 	    }
-
 	}
 	else {
 	    /* Single address set end addr to start */
@@ -219,33 +194,31 @@ main(int argc, char **argv)
 	    image = argv[optind];
 	    if ((img =
 		    img_open(imgtype, argc - optind - 1,
-			(const char **) &argv[optind])) == NULL) {
+			(const TCHAR **) &argv[optind])) == NULL) {
 		tsk_error_print(stderr);
 		exit(1);
 	    }
-
 	}
     }
     else {
 	/* We have a dash, but it could be part of the file name */
 	*dash = '\0';
 
-	istart = strtoull(argv[argc - 1], &cp, 0);
+	istart = TSTRTOULL(argv[argc - 1], &cp, 0);
 	if (*cp || cp == argv[argc - 1]) {
 	    /* Not a number - consider it a file name */
-	    *dash = '-';
+	    *dash = _T('-');
 	    image = argv[optind];
 	    if ((img =
 		    img_open(imgtype, argc - optind,
-			(const char **) &argv[optind])) == NULL) {
+			(const TCHAR **) &argv[optind])) == NULL) {
 		tsk_error_print(stderr);
 		exit(1);
 	    }
-
 	}
 	else {
 	    dash++;
-	    ilast = strtoull(dash, &cp, 0);
+	    ilast = TSTRTOULL(dash, &cp, 0);
 	    if (*cp || cp == dash) {
 		/* Not a number - consider it a file name */
 		dash--;
@@ -253,24 +226,21 @@ main(int argc, char **argv)
 		image = argv[optind];
 		if ((img =
 			img_open(imgtype, argc - optind,
-			    (const char **) &argv[optind])) == NULL) {
+			    (const TCHAR **) &argv[optind])) == NULL) {
 		    tsk_error_print(stderr);
 		    exit(1);
 		}
-
 	    }
 	    else {
-
 		set_range = 0;
 		/* It was a block range, so do not include it in the open */
 		image = argv[optind];
 		if ((img =
 			img_open(imgtype, argc - optind - 1,
-			    (const char **) &argv[optind])) == NULL) {
+			    (const TCHAR **) &argv[optind])) == NULL) {
 		    tsk_error_print(stderr);
 		    exit(1);
 		}
-
 	    }
 	}
     }
