@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2006/04/05 03:47:36 $
+** $Date: 2006/08/30 21:09:12 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -25,10 +25,13 @@
  *	Yorktown Heights, NY 10598, USA
  --*/
 
-#include "libfstools.h"
+#include "fs_tools_i.h"
 
+#ifdef TSK_WIN32
+#include <Winsock2.h>
+#endif
 
-static char *image;
+static TCHAR *image;
 
 /* number of seconds time skew of system 
  * if the system was 100 seconds fast, the value should be +100 
@@ -44,27 +47,31 @@ print_header(FS_INFO * fs)
     char hostnamebuf[BUFSIZ];
     time_t now;
 
+#ifndef TSK_WIN32
     if (gethostname(hostnamebuf, sizeof(hostnamebuf) - 1) < 0) {
 	if (verbose)
-	    fprintf(stderr, "error getting host by name\n");
+	    tsk_fprintf(stderr, "error getting host by name\n");
 
 	strcpy(hostnamebuf, "unknown");
     }
     hostnamebuf[sizeof(hostnamebuf) - 1] = 0;
+#else
+    strcpy(hostnamebuf, "unknown");
+#endif
     now = time((time_t *) 0);
 
     /*
      * Identify table type and table origin.
      */
-    printf("class|host|device|start_time\n");
-    printf("ils|%s||%lu\n", hostnamebuf, (ULONG) now);
+    tsk_printf("class|host|device|start_time\n");
+    tsk_printf("ils|%s||%lu\n", hostnamebuf, (ULONG) now);
 
     /*
      * Identify the fields in the data that follow.
      */
-    printf("st_ino|st_alloc|st_uid|st_gid|st_mtime|st_atime|st_ctime");
+    tsk_printf("st_ino|st_alloc|st_uid|st_gid|st_mtime|st_atime|st_ctime");
 
-    printf("|st_mode|st_nlink|st_size|st_block0|st_block1\n");
+    tsk_printf("|st_mode|st_nlink|st_size|st_block0|st_block1\n");
 }
 
 static void
@@ -73,24 +80,29 @@ print_header_mac()
     char hostnamebuf[BUFSIZ];
     time_t now;
 
+#ifndef TSK_WIN32
     if (gethostname(hostnamebuf, sizeof(hostnamebuf) - 1) < 0) {
 	if (verbose)
-	    fprintf(stderr, "Error getting host by name\n");
+	    tsk_fprintf(stderr, "Error getting host by name\n");
 	strcpy(hostnamebuf, "unknown");
     }
     hostnamebuf[sizeof(hostnamebuf) - 1] = 0;
+#else
+    strcpy(hostnamebuf, "unknown");
+#endif
     now = time((time_t *) 0);
 
     /*
      * Identify table type and table origin.
      */
-    printf("class|host|start_time\n");
-    printf("body|%s|%lu\n", hostnamebuf, (ULONG) now);
+    tsk_printf("class|host|start_time\n");
+    tsk_printf("body|%s|%lu\n", hostnamebuf, (ULONG) now);
 
     /*
      * Identify the fields in the data that follow.
      */
-    printf("md5|file|st_dev|st_ino|st_mode|st_ls|st_nlink|st_uid|st_gid|");
+    tsk_printf
+	("md5|file|st_dev|st_ino|st_mode|st_ls|st_nlink|st_uid|st_gid|");
     printf
 	("st_rdev|st_size|st_atime|st_mtime|st_ctime|st_blksize|st_blocks\n");
 
@@ -109,11 +121,11 @@ ils_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 	fs_inode->atime -= sec_skew;
 	fs_inode->ctime -= sec_skew;
     }
-    printf("%" PRIuINUM "|%c|%d|%d|%lu|%lu|%lu",
+    tsk_printf("%" PRIuINUM "|%c|%d|%d|%" PRIu32 "|%" PRIu32 "|%" PRIu32,
 	fs_inode->addr, (flags & FS_FLAG_META_ALLOC) ? 'a' : 'f',
 	(int) fs_inode->uid, (int) fs_inode->gid,
-	(ULONG) fs_inode->mtime, (ULONG) fs_inode->atime,
-	(ULONG) fs_inode->ctime);
+	(uint32_t) fs_inode->mtime, (uint32_t) fs_inode->atime,
+	(uint32_t) fs_inode->ctime);
 
     if (sec_skew != 0) {
 	fs_inode->mtime += sec_skew;
@@ -121,7 +133,7 @@ ils_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 	fs_inode->ctime += sec_skew;
     }
 
-    printf("|%lo|%d|%" PRIuOFF "|%" PRIuDADDR "|%" PRIuDADDR "\n",
+    tsk_printf("|%lo|%d|%" PRIuOFF "|%" PRIuDADDR "|%" PRIuDADDR "\n",
 	(ULONG) fs_inode->mode, (int) fs_inode->nlink,
 	fs_inode->size,
 	(fs_inode->direct_count > 0) ? fs_inode->direct_addr[0] : 0,
@@ -140,8 +152,9 @@ ils_mac_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 {
     char ls[12];
 
-    /* ADD NAME IF WE GOT IT */
-    printf("0|<%s-%s%s%s-%" PRIuINUM ">|0|%" PRIuINUM "|%d|", image,
+    /* ADD image and file name (if we have one) */
+    TFPRINTF(stdout, _T("0|<%s-"), image);
+    tsk_printf("%s%s%s-%" PRIuINUM ">|0|%" PRIuINUM "|%d|",
 	(fs_inode->name) ? fs_inode->name->name : "",
 	(fs_inode->name) ? "-" : "",
 	(flags & FS_FLAG_META_ALLOC) ? "alive" : "dead", fs_inode->addr,
@@ -156,11 +169,11 @@ ils_mac_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 	fs_inode->ctime -= sec_skew;
     }
 
-    printf("%s|%d|%d|%d|0|%" PRIuOFF "|%lu|%lu|%lu|%lu|0\n",
-	ls, (int) fs_inode->nlink, (int) fs_inode->uid,
-	(int) fs_inode->gid, fs_inode->size,
-	(ULONG) fs_inode->atime, (ULONG) fs_inode->mtime,
-	(ULONG) fs_inode->ctime, (ULONG) fs->block_size);
+    tsk_printf("%s|%d|%d|%d|0|%" PRIuOFF "|%lu|%" PRIu32 "|%" PRIu32 "|%"
+	PRIu32 "|0\n", ls, (int) fs_inode->nlink, (int) fs_inode->uid,
+	(int) fs_inode->gid, fs_inode->size, (uint32_t) fs_inode->atime,
+	(uint32_t) fs_inode->mtime, (uint32_t) fs_inode->ctime,
+	(ULONG) fs->block_size);
 
     if (sec_skew != 0) {
 	fs_inode->mtime -= sec_skew;
@@ -176,16 +189,21 @@ ils_mac_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 /* return 1 on error and 0 on success */
 uint8_t
 fs_ils(FS_INFO * fs, uint8_t lclflags, INUM_T istart, INUM_T ilast,
-    int flags, int32_t skew, char *img)
+    int flags, int32_t skew, TCHAR * img)
 {
     sec_skew = skew;
 
     /* Print the data */
     if (lclflags & ILS_MAC) {
-	char *tmpptr;
+	TCHAR *tmpptr;
 	image = img;
-	/* If this is ported to Windows this will have to be changed to \ */
+
+#ifdef TSK_WIN32
+	tmpptr = TSTRCHR(image, '\\');
+#else
 	tmpptr = strrchr(image, '/');
+#endif
+
 	if (tmpptr)
 	    image = ++tmpptr;
 
