@@ -57,15 +57,14 @@
 **        each copy of the program.
 */
 
-#include "fs_tools.h"
+#include "fs_tools_i.h"
 #include "iso9660.h"
-#include "mymalloc.h"
 
 static unsigned int depth = 0;
 
-#define DIR_STRSZ	2048
+#define DIR_STRSZ	4096
 static char dirs[DIR_STRSZ];
-#define MAX_DEPTH	64
+#define MAX_DEPTH	128
 static char *didx[MAX_DEPTH];
 
 /* iso9660_dent_walk - walk directory entries starting with inode 'inum'.
@@ -95,8 +94,8 @@ iso9660_dent_walk(FS_INFO * fs, INUM_T inum, int flags,
 
 
     if (verbose)
-	fprintf(stderr, "iso9660_dent_walk: Processing directory %lu\n",
-	    (ULONG) inum);
+	tsk_fprintf(stderr,
+	    "iso9660_dent_walk: Processing directory %lu\n", (ULONG) inum);
 
     if ((fs_dent = fs_dent_alloc(ISO9660_MAXNAMLEN, 0)) == NULL)
 	return 1;
@@ -190,6 +189,7 @@ iso9660_dent_walk(FS_INFO * fs, INUM_T inum, int flags,
 	while (length > sizeof(iso9660_dentry)) {
 	    if (dd->length) {
 		int retval;
+		int i;
 		/* print out info on what was in extent */
 		in = iso->in;
 		while (parseu32(fs, in->inode.dr.ext_loc) !=
@@ -199,6 +199,15 @@ iso9660_dent_walk(FS_INFO * fs, INUM_T inum, int flags,
 		fs_dent->inode = in->inum;
 		strcpy(fs_dent->name, in->inode.fn);
 
+		/* Clean up name */
+		i = 0;
+		while (fs_dent->name[i] != '\0') {
+		    if (TSK_IS_CNTRL(fs_dent->name[i]))
+			fs_dent->name[i] = '^';
+		    i++;
+		}
+
+
 		fs_dent->path = dirs;
 		fs_dent->pathdepth = depth;
 		fs_dent->fsi = fs->inode_lookup(fs, fs_dent->inode);
@@ -221,11 +230,16 @@ iso9660_dent_walk(FS_INFO * fs, INUM_T inum, int flags,
 
 		if ((dd->flags & ISO9660_FLAG_DIR)
 		    && (flags & FS_FLAG_NAME_RECURSE)) {
-		    if (depth < MAX_DEPTH) {
+		    int depth_added = 0;
+
+		    if ((depth < MAX_DEPTH) &&
+			(DIR_STRSZ >
+			    strlen(dirs) + strlen(fs_dent->name))) {
 			didx[depth] = &dirs[strlen(dirs)];
 			strncpy(didx[depth], fs_dent->name,
 			    DIR_STRSZ - strlen(dirs));
 			strncat(dirs, "/", DIR_STRSZ);
+			depth_added = 1;
 		    }
 		    depth++;
 		    if (iso9660_dent_walk(fs, in->inum, flags, action,
@@ -233,7 +247,7 @@ iso9660_dent_walk(FS_INFO * fs, INUM_T inum, int flags,
 			/* If the directory could not be loaded,
 			 * then move on */
 			if (verbose) {
-			    fprintf(stderr,
+			    tsk_fprintf(stderr,
 				"iso_dent_parse_block: error reading directory: %"
 				PRIuINUM "\n", in->inum);
 			    tsk_error_print(stderr);
@@ -242,7 +256,7 @@ iso9660_dent_walk(FS_INFO * fs, INUM_T inum, int flags,
 		    }
 
 		    depth--;
-		    if (depth < MAX_DEPTH)
+		    if (depth_added)
 			*didx[depth] = '\0';
 		}
 
