@@ -2,7 +2,7 @@
 ** jls
 ** The Sleuth Kit 
 **
-** $Date: 2006/07/10 13:26:20 $
+** $Date: 2006/08/30 21:09:12 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -12,114 +12,83 @@
 ** This software is distributed under the Common Public License 1.0
 **
 */
-
+#include <locale.h>
 #include "fs_tools.h"
 
-
-/* atoinum - convert string to inode number */
-INUM_T
-atoinum(const char *str)
-{
-    char *cp, *dash;
-    INUM_T inum;
-
-    if (*str == 0)
-	return (0);
-
-    /* if we are given the inode in the inode-type-id form, then ignore
-     * the other stuff w/out giving an error 
-     *
-     * This will make scripting easier
-     */
-    if ((dash = strchr(str, '-')) != NULL) {
-	*dash = '\0';
-    }
-    inum = strtoull(str, &cp, 0);
-    if (*cp || cp == str) {
-	fprintf(stderr, "bad inode number: %s", str);
-	exit(1);
-    }
-    return (inum);
-}
-
+static TCHAR *progname;
 
 /* usage - explain and terminate */
-
 static void
 usage()
 {
-    fprintf(stderr,
-	"usage: %s [-f fstype] [-i imgtype] [-o imgoffset] [-vV] image [inode]\n",
+    TFPRINTF(stderr,
+	_T
+	("usage: %s [-f fstype] [-i imgtype] [-o imgoffset] [-vV] image [inode]\n"),
 	progname);
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-i imgtype: The format of the image file (use '-i list' for supported types)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-f fstype: File system type (use '-f list' for supported types)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-o imgoffset: The offset of the file system in the image (in sectors)\n");
-    fprintf(stderr, "\t-v: verbose output to stderr\n");
-    fprintf(stderr, "\t-V: print version\n");
+    tsk_fprintf(stderr, "\t-v: verbose output to stderr\n");
+    tsk_fprintf(stderr, "\t-V: print version\n");
     exit(1);
 }
 
 
 int
-main(int argc, char **argv)
+MAIN(int argc, TCHAR ** argv)
 {
     INUM_T inum;
     int ch;
-    char *fstype = NULL;
+    TCHAR *fstype = NULL;
+    TCHAR *imgtype = NULL;
     FS_INFO *fs;
-    char *imgtype = NULL, *cp;
-    SSIZE_T imgoff = 0;
     IMG_INFO *img;
+    SSIZE_T imgoff = 0;
 
     progname = argv[0];
     setlocale(LC_ALL, "");
 
-    while ((ch = getopt(argc, argv, "f:i:o:vV")) > 0) {
+    while ((ch = getopt(argc, argv, _T("f:i:o:vV"))) > 0) {
 	switch (ch) {
-
-	case '?':
+	case _T('?'):
 	default:
-	    fprintf(stderr, "Invalid argument: %s\n", argv[optind]);
+	    TFPRINTF(stderr, _T("Invalid argument: %s\n"), argv[optind]);
 	    usage();
-	case 'f':
+	case _T('f'):
 	    fstype = optarg;
-	    if (strcmp(fstype, "list") == 0) {
+	    if (TSTRCMP(fstype, _T("list")) == 0) {
 		fs_print_types(stderr);
 		exit(1);
 	    }
-
 	    break;
-	case 'i':
+	case _T('i'):
 	    imgtype = optarg;
-	    if (strcmp(imgtype, "list") == 0) {
+	    if (TSTRCMP(imgtype, _T("list")) == 0) {
 		img_print_types(stderr);
 		exit(1);
 	    }
-
 	    break;
-
-	case 'o':
+	case _T('o'):
 	    if ((imgoff = parse_offset(optarg)) == -1) {
 		tsk_error_print(stderr);
 		exit(1);
 	    }
 	    break;
-	case 'v':
+	case _T('v'):
 	    verbose++;
 	    break;
-	case 'V':
+	case _T('V'):
 	    print_version(stdout);
 	    exit(0);
-
 	}
     }
 
     /* We need at least one more argument */
     if (optind >= argc) {
-	fprintf(stderr, "Missing image name and/or address\n");
+	tsk_fprintf(stderr, "Missing image name and/or address\n");
 	usage();
     }
 
@@ -128,12 +97,11 @@ main(int argc, char **argv)
      *
      * Check the final argument and see if it is a number
      */
-    inum = strtoull(argv[argc - 1], &cp, 0);
-    if (*cp || cp == argv[argc - 1]) {
+    if (parse_inum(argv[argc - 1], &inum, NULL, NULL, NULL)) {
 	/* Not an inode at the end */
 	if ((img =
 		img_open(imgtype, argc - optind,
-		    (const char **) &argv[optind])) == NULL) {
+		    (const TCHAR **) &argv[optind])) == NULL) {
 	    tsk_error_print(stderr);
 	    exit(1);
 	}
@@ -151,7 +119,7 @@ main(int argc, char **argv)
     else {
 	if ((img =
 		img_open(imgtype, argc - optind - 1,
-		    (const char **) &argv[optind])) == NULL) {
+		    (const TCHAR **) &argv[optind])) == NULL) {
 	    tsk_error_print(stderr);
 	    exit(1);
 	}
@@ -163,11 +131,10 @@ main(int argc, char **argv)
 	    img->close(img);
 	    exit(1);
 	}
-
     }
 
     if (fs->jopen == NULL) {
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "Journal support does not exist for this file system\n");
 	fs->close(fs);
 	img->close(img);
@@ -175,7 +142,7 @@ main(int argc, char **argv)
     }
 
     if (inum > fs->last_inum) {
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "Inode value is too large for image (%" PRIuINUM ")\n",
 	    fs->last_inum);
 	fs->close(fs);
@@ -184,7 +151,7 @@ main(int argc, char **argv)
     }
 
     if (inum < fs->first_inum) {
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "Inode value is too small for image (%" PRIuINUM ")\n",
 	    fs->first_inum);
 	fs->close(fs);
@@ -197,7 +164,6 @@ main(int argc, char **argv)
 	fs->close(fs);
 	img->close(img);
 	exit(1);
-
     }
     if (fs->jentry_walk(fs, 0, 0, NULL)) {
 	tsk_error_print(stderr);
