@@ -2,7 +2,7 @@
 ** ntfs_dent
 ** The Sleuth Kit
 **
-** $Date: 2006/07/05 18:24:09 $
+** $Date: 2006/08/30 21:09:12 $
 **
 ** name layer support for the NTFS file system
 **
@@ -19,14 +19,12 @@
 ** Unicode added with support from I.D.E.A.L. Technology Corp (Aug '05)
 **
 */
-#include "fs_tools.h"
-#include "fs_data.h"
+#include "fs_tools_i.h"
 #include "ntfs.h"
-#include "fs_unicode.h"
 
 
-#define MAX_DEPTH   64
-#define DIR_STRSZ  2048
+#define MAX_DEPTH   128
+#define DIR_STRSZ   4096
 
 typedef struct {
     /* Recursive path stuff */
@@ -62,13 +60,14 @@ ntfs_dent_copy(NTFS_INFO * ntfs, NTFS_DINFO * dinfo, ntfs_idxentry * idxe,
     UTF16 *name16;
     UTF8 *name8;
     int retVal;
+    int i;
 
-    fs_dent->inode = getu48(fs, idxe->file_ref);
+    fs_dent->inode = getu48(fs->endian, idxe->file_ref);
 
     name16 = (UTF16 *) & fname->name;
     name8 = (UTF8 *) fs_dent->name;
 
-    retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+    retVal = tsk_UTF16toUTF8(fs->endian, (const UTF16 **) &name16,
 	(UTF16 *) ((uintptr_t) name16 +
 	    fname->nlen * 2), &name8,
 	(UTF8 *) ((uintptr_t) name8 +
@@ -77,7 +76,7 @@ ntfs_dent_copy(NTFS_INFO * ntfs, NTFS_DINFO * dinfo, ntfs_idxentry * idxe,
     if (retVal != conversionOK) {
 	*name8 = '\0';
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"Error converting NTFS name to UTF8: %d %" PRIuINUM,
 		retVal, fs_dent->inode);
     }
@@ -88,6 +87,14 @@ ntfs_dent_copy(NTFS_INFO * ntfs, NTFS_DINFO * dinfo, ntfs_idxentry * idxe,
     else
 	*name8 = '\0';
 
+    /* Clean up name */
+    i = 0;
+    while (fs_dent->name[i] != '\0') {
+	if (TSK_IS_CNTRL(fs_dent->name[i]))
+	    fs_dent->name[i] = '^';
+	i++;
+    }
+
     /* copy the path data */
     fs_dent->path = dinfo->dirs;
     fs_dent->pathdepth = dinfo->depth;
@@ -98,11 +105,11 @@ ntfs_dent_copy(NTFS_INFO * ntfs, NTFS_DINFO * dinfo, ntfs_idxentry * idxe,
 
     fs_dent->fsi = fs->inode_lookup(fs, fs_dent->inode);
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "ntfs_dent_copy: error looking up inode: %" PRIuINUM "\n",
 	    fs_dent->inode);
 
-    if (getu64(fs, fname->flags) & NTFS_FNAME_FLAGS_DIR)
+    if (getu64(fs->endian, fname->flags) & NTFS_FNAME_FLAGS_DIR)
 	fs_dent->ent_type = FS_DENT_DIR;
     else
 	fs_dent->ent_type = FS_DENT_REG;
@@ -162,7 +169,7 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
     }
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "ntfs_dent_idxentry: Processing entry: %" PRIu64
 	    "  Size: %" PRIu32 "  Len: %" PRIu32 "\n",
 	    (uint64_t) ((uintptr_t) idxe), size, len);
@@ -181,32 +188,33 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"ntfs_dent_idxentry: New IdxEnt: %" PRIu64
 		" $FILE_NAME Entry: %" PRIu64 "  File Ref: %" PRIu64
 		"  IdxEnt Len: %" PRIu16 "  StrLen: %" PRIu16 "\n",
 		(uint64_t) ((uintptr_t) idxe),
-		(uint64_t) ((uintptr_t) fname), (uint64_t) getu48(fs,
-		    idxe->
-		    file_ref),
-		getu16(fs, idxe->idxlen), getu16(fs, idxe->strlen));
+		(uint64_t) ((uintptr_t) fname),
+		(uint64_t) getu48(fs->endian, idxe->file_ref),
+		getu16(fs->endian, idxe->idxlen), getu16(fs->endian,
+		    idxe->strlen));
 
 	/* perform some sanity checks on index buffer head
 	 * and advance by 4-bytes if invalid
 	 */
-	if ((getu48(fs, idxe->file_ref) > fs->last_inum) ||
-	    (getu48(fs, idxe->file_ref) < fs->first_inum) ||
-	    (getu16(fs, idxe->idxlen) <= getu16(fs, idxe->strlen)) ||
-	    (getu16(fs, idxe->idxlen) % 4) ||
-	    (getu16(fs, idxe->idxlen) > size)) {
+	if ((getu48(fs->endian, idxe->file_ref) > fs->last_inum) ||
+	    (getu48(fs->endian, idxe->file_ref) < fs->first_inum) ||
+	    (getu16(fs->endian, idxe->idxlen) <= getu16(fs->endian,
+		    idxe->strlen))
+	    || (getu16(fs->endian, idxe->idxlen) % 4)
+	    || (getu16(fs->endian, idxe->idxlen) > size)) {
 	    idxe = (ntfs_idxentry *) ((uintptr_t) idxe + 4);
 	    continue;
 	}
 
 	/* do some sanity checks on the deleted entries
 	 */
-	if ((getu16(fs, idxe->strlen) == 0) ||
-	    (((uintptr_t) idxe + getu16(fs, idxe->idxlen)) >
+	if ((getu16(fs->endian, idxe->strlen) == 0) ||
+	    (((uintptr_t) idxe + getu16(fs->endian, idxe->idxlen)) >
 		endaddr_alloc)) {
 
 	    /* name space checks */
@@ -218,17 +226,18 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 		continue;
 	    }
 
-	    if ((getu64(fs, fname->alloc_fsize) <
-		    getu64(fs, fname->real_fsize)) || (fname->nlen == 0)
+	    if ((getu64(fs->endian, fname->alloc_fsize) <
+		    getu64(fs->endian, fname->real_fsize))
+		|| (fname->nlen == 0)
 		|| (*(uint8_t *) & fname->name == 0)) {
 
 		idxe = (ntfs_idxentry *) ((uintptr_t) idxe + 4);
 		continue;
 	    }
 
-	    if ((is_time(getu64(fs, fname->crtime)) == 0) ||
-		(is_time(getu64(fs, fname->atime)) == 0) ||
-		(is_time(getu64(fs, fname->mtime)) == 0)) {
+	    if ((is_time(getu64(fs->endian, fname->crtime)) == 0) ||
+		(is_time(getu64(fs->endian, fname->atime)) == 0) ||
+		(is_time(getu64(fs->endian, fname->mtime)) == 0)) {
 
 		idxe = (ntfs_idxentry *) ((uintptr_t) idxe + 4);
 		continue;
@@ -252,7 +261,7 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 
 	if (fname->nspace == NTFS_FNAME_DOS) {
 	    if (verbose)
-		fprintf(stderr,
+		tsk_fprintf(stderr,
 		    "ntfs_dent_idxentry: Skipping because of name space: %d\n",
 		    fname->nspace);
 
@@ -263,12 +272,12 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 	ntfs_dent_copy(ntfs, dinfo, idxe, fs_dent);
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"ntfs_dent_idxentry: Deletion Check Details of %s: Str Len: %"
 		PRIu16 "  Len to end after current: %" PRIu64 "\n",
-		fs_dent->name, getu16(fs, idxe->strlen),
+		fs_dent->name, getu16(fs->endian, idxe->strlen),
 		(uint64_t) (endaddr_alloc - (uintptr_t) idxe -
-		    getu16(fs, idxe->idxlen)));
+		    getu16(fs->endian, idxe->idxlen)));
 
 	/* 
 	 * Check if this entry is deleted
@@ -276,15 +285,15 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 	 * The final check is to see if the end of this entry is 
 	 * within the space that the idxallocbuf claimed was valid
 	 */
-	if ((getu16(fs, idxe->strlen) == 0) ||
-	    (((uintptr_t) idxe + getu16(fs, idxe->idxlen)) >
+	if ((getu16(fs->endian, idxe->strlen) == 0) ||
+	    (((uintptr_t) idxe + getu16(fs->endian, idxe->idxlen)) >
 		endaddr_alloc)) {
 
 	    /* we know deleted entries with an inode of 0 are not legit because
 	     * that is the MFT value.  Free it so it does not confuse
 	     * people with invalid data
 	     */
-	    if (fs_dent->inode == 0) {
+	    if ((fs_dent->inode == 0) && (fs_dent->fsi)) {
 		fs_inode_free(fs_dent->fsi);
 		fs_dent->fsi = NULL;
 	    }
@@ -314,25 +323,30 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 	    (fs_dent->fsi) &&
 	    ((fs_dent->fsi->mode & FS_INODE_FMT) == FS_INODE_DIR) &&
 	    (fs_dent->inode)) {
+	    int depth_added = 0;
 
-	    if (dinfo->depth < MAX_DEPTH) {
+	    if ((dinfo->depth < MAX_DEPTH) &&
+		(DIR_STRSZ >
+		    strlen(dinfo->dirs) + strlen(fs_dent->name))) {
 		dinfo->didx[dinfo->depth] =
 		    &dinfo->dirs[strlen(dinfo->dirs)];
 		strncpy(dinfo->didx[dinfo->depth], fs_dent->name,
 		    DIR_STRSZ - strlen(dinfo->dirs));
 		strncat(dinfo->dirs, "/", DIR_STRSZ);
+		depth_added = 1;
 	    }
 	    dinfo->depth++;
 
 	    if (ntfs_dent_walk_lcl(&(ntfs->fs_info), dinfo, fs_dent->inode,
 		    flags, action, ptr)) {
 		if (verbose)
-		    fprintf(stderr, "Error recursing into directory\n");
+		    tsk_fprintf(stderr,
+			"Error recursing into directory\n");
 		tsk_error_reset();
 	    }
 
 	    dinfo->depth--;
-	    if (dinfo->depth < MAX_DEPTH)
+	    if (depth_added)
 		*dinfo->didx[dinfo->depth] = '\0';
 
 	}			/* end of recurse */
@@ -350,7 +364,7 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 	 * 66: size of fname before name
 	 * 2*nlen: size of name (in unicode)
 	 */
-	if (getu16(fs, idxe->strlen) == 0) {
+	if (getu16(fs->endian, idxe->strlen) == 0) {
 	    idxe =
 		(ntfs_idxentry
 		*) ((((uintptr_t) idxe + 16 + 66 + 2 * fname->nlen +
@@ -359,7 +373,7 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 	else {
 	    idxe =
 		(ntfs_idxentry *) ((uintptr_t) idxe +
-		getu16(fs, idxe->idxlen));
+		getu16(fs->endian, idxe->idxlen));
 	}
 
     }				/* end of loop of index entries */
@@ -386,12 +400,12 @@ ntfs_fix_idxrec(NTFS_INFO * ntfs, ntfs_idxrec * idxrec, uint32_t len)
     ntfs_upd *upd;
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "ntfs_fix_idxrec: Fixing idxrec: %" PRIu64 "  Len: %"
 	    PRIu32 "\n", (uint64_t) ((uintptr_t) idxrec), len);
 
     /* sanity check so we don't run over in the next loop */
-    if ((unsigned int) ((getu16(fs, idxrec->upd_cnt) - 1) *
+    if ((unsigned int) ((getu16(fs->endian, idxrec->upd_cnt) - 1) *
 	    ntfs->ssize_b) > len) {
 	tsk_errno = TSK_ERR_FS_INODE_INT;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
@@ -400,24 +414,27 @@ ntfs_fix_idxrec(NTFS_INFO * ntfs, ntfs_idxrec * idxrec, uint32_t len)
     }
 
     /* Apply the update sequence structure template */
-    upd = (ntfs_upd *) ((uintptr_t) idxrec + getu16(fs, idxrec->upd_off));
+    upd =
+	(ntfs_upd *) ((uintptr_t) idxrec + getu16(fs->endian,
+	    idxrec->upd_off));
 
     /* Get the sequence value that each 16-bit value should be */
-    orig_seq = getu16(fs, upd->upd_val);
+    orig_seq = getu16(fs->endian, upd->upd_val);
 
     /* cycle through each sector */
-    for (i = 1; i < getu16(fs, idxrec->upd_cnt); i++) {
+    for (i = 1; i < getu16(fs->endian, idxrec->upd_cnt); i++) {
 
 	/* The offset into the buffer of the value to analyze */
 	int offset = i * ntfs->ssize_b - 2;
 	uint8_t *new_val, *old_val;
 
 	/* get the current sequence value */
-	uint16_t cur_seq = getu16(fs, (uintptr_t) idxrec + offset);
+	uint16_t cur_seq = getu16(fs->endian, (uintptr_t) idxrec + offset);
 
 	if (cur_seq != orig_seq) {
 	    /* get the replacement value */
-	    uint16_t cur_repl = getu16(fs, &upd->upd_seq + (i - 1) * 2);
+	    uint16_t cur_repl =
+		getu16(fs->endian, &upd->upd_seq + (i - 1) * 2);
 
 	    tsk_errno = TSK_ERR_FS_INODE_INT;
 	    snprintf(tsk_errstr, TSK_ERRSTR_L,
@@ -433,10 +450,10 @@ ntfs_fix_idxrec(NTFS_INFO * ntfs, ntfs_idxrec * idxrec, uint32_t len)
 	old_val = (uint8_t *) ((uintptr_t) idxrec + offset);
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"ntfs_fix_idxrec: upd_seq %i   Replacing: %.4" PRIx16
-		"   With: %.4" PRIx16 "\n", i, getu16(fs, old_val),
-		getu16(fs, new_val));
+		"   With: %.4" PRIx16 "\n", i, getu16(fs->endian, old_val),
+		getu16(fs->endian, new_val));
 
 	*old_val++ = *new_val++;
 	*old_val = *new_val;
@@ -469,7 +486,6 @@ static uint8_t
 ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
     int flags, FS_DENT_WALK_FN action, void *ptr)
 {
-
     NTFS_INFO *ntfs = (NTFS_INFO *) fs;
     FS_INODE *fs_inode;
     FS_DATA *fs_data_root, *fs_data_alloc;
@@ -478,7 +494,8 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
     ntfs_idxroot *idxroot;
     ntfs_idxelist *idxelist;
     ntfs_idxrec *idxrec_p, *idxrec;
-    int off, idxalloc_len;
+    int off;
+    OFF_T idxalloc_len;
     FS_LOAD_FILE load_file;
     int retval;
 
@@ -491,7 +508,7 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
     }
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "ntfs_dent_walk: Processing directory %" PRIuINUM "\n", inum);
 
     /* Get the inode and verify it has attributes */
@@ -533,18 +550,18 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
     idxroot = (ntfs_idxroot *) fs_data_root->buf;
 
     /* Verify that the attribute type is $FILE_NAME */
-    if (getu32(fs, idxroot->type) == 0) {
+    if (getu32(fs->endian, idxroot->type) == 0) {
 	tsk_errno = TSK_ERR_FS_INODE_INT;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
 	    "dent_walk: Attribute type in index root is 0");
 	fs_inode_free(fs_inode);
 	return 1;
     }
-    else if (getu32(fs, idxroot->type) != NTFS_ATYPE_FNAME) {
+    else if (getu32(fs->endian, idxroot->type) != NTFS_ATYPE_FNAME) {
 	tsk_errno = TSK_ERR_FS_INODE_INT;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
 	    "ERROR: Directory index is sorted by type: %" PRIu32
-	    ".\nOnly $FNAME is currently supported", getu32(fs,
+	    ".\nOnly $FNAME is currently supported", getu32(fs->endian,
 		idxroot->type));
 	return 1;
     }
@@ -554,7 +571,7 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 
     /* Get the offset to the start of the index entry list */
     idxe = (ntfs_idxentry *) ((uintptr_t) idxelist +
-	getu32(fs, idxelist->begin_off));
+	getu32(fs->endian, idxelist->begin_off));
 
     /* 
      * NTFS does not have "." and ".." entries in the index trees
@@ -569,7 +586,8 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	int myflags = FS_FLAG_NAME_ALLOC;
 
 	if (verbose)
-	    fprintf(stderr, "ntfs_dent_walk: Creating . and .. entries\n");
+	    tsk_fprintf(stderr,
+		"ntfs_dent_walk: Creating . and .. entries\n");
 
 	if ((fs_dent = fs_dent_alloc(16, 0)) == NULL) {
 	    fs_inode_free(fs_inode);
@@ -606,12 +624,11 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	}
 	else {
 	    if (verbose)
-		fprintf(stderr, "Error reading . entry: %" PRIuINUM,
+		tsk_fprintf(stderr, "Error reading . entry: %" PRIuINUM,
 		    fs_dent->inode);
 	}
 
 
-
 	/*
 	 * ".."
 	 */
@@ -645,7 +662,7 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	    }
 	    else {
 		if (verbose)
-		    fprintf(stderr,
+		    tsk_fprintf(stderr,
 			"dent_walk: Error reading .. inode: %"
 			PRIuINUM, fs_dent->inode);
 	    }
@@ -656,16 +673,14 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	fs_dent = NULL;
     }
 
-
-
     /* Now we return to processing the Index Root Attribute */
     retval = ntfs_dent_idxentry(ntfs, dinfo, idxe,
-	getu32(fs,
+	getu32(fs->endian,
 	    idxelist->buf_off) -
-	getu32(fs, idxelist->begin_off),
-	getu32(fs,
+	getu32(fs->endian, idxelist->begin_off),
+	getu32(fs->endian,
 	    idxelist->end_off) -
-	getu32(fs, idxelist->begin_off), flags, action, ptr);
+	getu32(fs->endian, idxelist->begin_off), flags, action, ptr);
 
     if (retval != 0) {
 	fs_inode_free(fs_inode);
@@ -684,17 +699,18 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
      * all of the entries 
      */
     if (!fs_data_alloc) {
-	fs_inode_free(fs_inode);
-	if (getu32(fs, idxelist->flags) & NTFS_IDXELIST_CHILD) {
+	int retval;
+	if (getu32(fs->endian, idxelist->flags) & NTFS_IDXELIST_CHILD) {
 	    tsk_errno = TSK_ERR_FS_INODE_INT;
 	    snprintf(tsk_errstr, TSK_ERRSTR_L,
 		"Error: $IDX_ROOT says there should be children, but there isn't");
-
-	    return 1;
+	    retval = 1;
 	}
 	else {
-	    return 0;
+	    retval = 0;
 	}
+	fs_inode_free(fs_inode);
+	return retval;
     }
 
 
@@ -709,19 +725,18 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
     /* 
      * Copy the index allocation run into a big buffer
      */
-
     idxalloc_len = fs_data_alloc->runlen;
-    if ((idxalloc = mymalloc(idxalloc_len)) == NULL) {
+    if ((idxalloc = mymalloc((size_t) idxalloc_len)) == NULL) {
 	fs_inode_free(fs_inode);
 	return 1;
     }
 
     /* Fill in the loading data structure */
-    load_file.total = load_file.left = idxalloc_len;
+    load_file.total = load_file.left = (size_t) idxalloc_len;
     load_file.cur = load_file.base = idxalloc;
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "ntfs_dent_walk: Copying $IDX_ALLOC into buffer\n");
 
     if (ntfs_data_walk(ntfs, fs_inode->addr, fs_data_alloc,
@@ -767,12 +782,12 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	idxrec = (ntfs_idxrec *) & idxalloc[off];
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"ntfs_dent_walk: Index Buffer Offset: %d  Magic: %"
-		PRIx32 "\n", off, getu32(fs, idxrec->magic));
+		PRIx32 "\n", off, getu32(fs->endian, idxrec->magic));
 
 	/* Is this the begining of an index record? */
-	if (getu32(fs, idxrec->magic) != NTFS_IDXREC_MAGIC)
+	if (getu32(fs->endian, idxrec->magic) != NTFS_IDXREC_MAGIC)
 	    continue;
 
 
@@ -788,10 +803,10 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	/* idxrec points to the next idxrec structure, idxrec_p
 	 * points to the one we are going to process
 	 */
-	rec_len = ((uintptr_t) idxrec - (uintptr_t) idxrec_p);
+	rec_len = (uint32_t) ((uintptr_t) idxrec - (uintptr_t) idxrec_p);
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"ntfs_dent_walk: Processing previous index record (len: %"
 		PRIu32 ")\n", rec_len);
 
@@ -805,20 +820,20 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	/* Locate the start of the index entry list */
 	idxelist = &idxrec_p->list;
 	idxe = (ntfs_idxentry *) ((uintptr_t) idxelist +
-	    getu32(fs, idxelist->begin_off));
+	    getu32(fs->endian, idxelist->begin_off));
 
 	/* the length from the start of the next record to where our
 	 * list starts.
 	 * This should be the same as buf_off in idxelist, but we don't
 	 * trust it.
 	 */
-	list_len = (uintptr_t) idxrec - (uintptr_t) idxe;
+	list_len = (uint32_t) ((uintptr_t) idxrec - (uintptr_t) idxe);
 
 	/* process the list of index entries */
 	retval = ntfs_dent_idxentry(ntfs, dinfo, idxe, list_len,
-	    getu32(fs,
+	    getu32(fs->endian,
 		idxelist->end_off) -
-	    getu32(fs, idxelist->begin_off), flags, action, ptr);
+	    getu32(fs->endian, idxelist->begin_off), flags, action, ptr);
 	if (retval != 0) {
 	    fs_inode_free(fs_inode);
 	    free(idxalloc);
@@ -837,10 +852,11 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 
 	/* Length from end of attribute to start of this */
 	rec_len =
-	    idxalloc_len - ((uintptr_t) idxrec_p - (uintptr_t) idxalloc);
+	    (uint32_t) (idxalloc_len - (uintptr_t) idxrec_p -
+	    (uintptr_t) idxalloc);
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"ntfs_dent_walk: Processing final index record (len: %"
 		PRIu32 ")\n", rec_len);
 
@@ -853,17 +869,18 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 
 	idxelist = &idxrec_p->list;
 	idxe = (ntfs_idxentry *) ((uintptr_t) idxelist +
-	    getu32(fs, idxelist->begin_off));
+	    getu32(fs->endian, idxelist->begin_off));
 
 	/* This is the length of the idx entries */
 	list_len =
-	    ((uintptr_t) idxalloc + idxalloc_len) - (uintptr_t) idxe;
+	    (uint32_t) ((uintptr_t) idxalloc + idxalloc_len) -
+	    (uintptr_t) idxe;
 
 	/* process the list of index entries */
 	retval = ntfs_dent_idxentry(ntfs, dinfo, idxe, list_len,
-	    getu32(fs,
+	    getu32(fs->endian,
 		idxelist->end_off) -
-	    getu32(fs, idxelist->begin_off), flags, action, ptr);
+	    getu32(fs->endian, idxelist->begin_off), flags, action, ptr);
 	if (retval != 0) {
 	    fs_inode_free(fs_inode);
 	    free(idxalloc);
@@ -903,7 +920,7 @@ ntfs_find_file_rec(FS_INFO * fs, NTFS_DINFO * dinfo, FS_DENT * fs_dent,
     FS_INODE *fs_inode_par;
     FS_NAME *fs_name_par;
     uint8_t decrem = 0;
-    int len = 0, i;
+    size_t len = 0, i;
     char *begin = NULL;
     int retval;
 
@@ -1043,7 +1060,6 @@ ntfs_find_file(FS_INFO * fs, INUM_T inode_toid, uint32_t type_toid,
     char *attr = NULL;
     NTFS_DINFO dinfo;
 
-
     /* sanity check */
     if (inode_toid < fs->first_inum || inode_toid > fs->last_inum) {
 	tsk_errno = TSK_ERR_FS_ARG;
@@ -1081,13 +1097,17 @@ ntfs_find_file(FS_INFO * fs, INUM_T inode_toid, uint32_t type_toid,
 	fs_dent_free(fs_dent);
 	return 1;
     }
-    myflags = ((getu16(fs, ntfs->mft->flags) & NTFS_MFT_INUSE) ?
+    myflags = ((getu16(fs->endian, ntfs->mft->flags) & NTFS_MFT_INUSE) ?
 	FS_FLAG_NAME_ALLOC : FS_FLAG_NAME_UNALLOC);
 
     /* Get the name for the attribute - if specified */
     if (type_toid != 0) {
-	FS_DATA *fs_data =
-	    fs_data_lookup(fs_dent->fsi->attr, type_toid, id_toid);
+	FS_DATA *fs_data;
+	if (flags & FS_FLAG_FILE_NOID)
+	    fs_data = fs_data_lookup_noid(fs_dent->fsi->attr, type_toid);
+	else
+	    fs_data =
+		fs_data_lookup(fs_dent->fsi->attr, type_toid, id_toid);
 	if (!fs_data) {
 	    tsk_errno = TSK_ERR_FS_INODE_INT;
 	    snprintf(tsk_errstr, TSK_ERRSTR_L,
