@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit
 **
-** $Date: 2006/06/19 22:21:07 $
+** $Date: 2006/08/29 17:13:20 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -12,7 +12,7 @@
 ** 
 */
 
-#include "fs_tools.h"
+#include "fs_tools_i.h"
 
 
 
@@ -175,9 +175,10 @@ rawfs_dent_walk(FS_INFO * fs, INUM_T inode, int flags,
 static uint8_t
 rawfs_fsstat(FS_INFO * fs, FILE * hFile)
 {
-    fprintf(hFile, "Raw Data\n");
-    fprintf(hFile, "Block Size: %d\n", fs->block_size);
-    fprintf(hFile, "Block Range: 0 - %" PRIuDADDR "\n", fs->last_block);
+    tsk_fprintf(hFile, "Raw Data\n");
+    tsk_fprintf(hFile, "Block Size: %d\n", fs->block_size);
+    tsk_fprintf(hFile, "Block Range: 0 - %" PRIuDADDR "\n",
+	fs->last_block);
     return 0;
 }
 
@@ -188,7 +189,7 @@ rawfs_fsstat(FS_INFO * fs, FILE * hFile)
  * return 1 on error and 0 on success
  */
 static uint8_t
-rawfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
+rawfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, DADDR_T numblock,
     int32_t sec_skew)
 {
     tsk_errno = TSK_ERR_FS_FUNC;
