@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2006/06/19 22:21:07 $
+** $Date: 2006/08/29 17:13:20 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -12,7 +12,7 @@
 **
 */
 
-#include "fs_tools.h"
+#include "fs_tools_i.h"
 
 
 /**************************************************************************
@@ -175,9 +175,9 @@ swapfs_dent_walk(FS_INFO * fs, INUM_T inode, int flags,
 static uint8_t
 swapfs_fsstat(FS_INFO * fs, FILE * hFile)
 {
-    fprintf(hFile, "Swap Space\n");
-    fprintf(hFile, "Page Size: %d\n", fs->block_size);
-    fprintf(hFile, "Page Range: 0 - %" PRIuDADDR "\n", fs->last_block);
+    tsk_fprintf(hFile, "Swap Space\n");
+    tsk_fprintf(hFile, "Page Size: %d\n", fs->block_size);
+    tsk_fprintf(hFile, "Page Range: 0 - %" PRIuDADDR "\n", fs->last_block);
     return 0;
 }
 
@@ -186,7 +186,7 @@ swapfs_fsstat(FS_INFO * fs, FILE * hFile)
 
 /* Return 1 on error and 0 on success */
 static uint8_t
-swapfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
+swapfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, DADDR_T numblock,
     int32_t sec_skew)
 {
     tsk_errno = TSK_ERR_FS_FUNC;
