@@ -1,4 +1,7 @@
 /* GLOBAL.H - RSAREF types and constants
+ *
+ * Modified for The Sleuth Kit to use uintX values
+ *
  */
 
 /* PROTOTYPES should be set to one if and only if the compiler supports
@@ -14,14 +17,19 @@ The following makes PROTOTYPES default to 0 if it has not already
 typedef unsigned char *POINTER;
 
 /* UINT2 defines a two byte word */
-typedef unsigned short int UINT2;
+//typedef unsigned short int UINT2;
+typedef uint16_t    UINT2;
 
 /* UINT4 defines a four byte word */
+typedef uint32_t    UINT4;
+
+/*
 #ifdef __alpha
 typedef unsigned int UINT4;
 #else
 typedef unsigned long int UINT4;
 #endif
+*/
 
 /* PROTO_LIST is defined depending on how PROTOTYPES is defined above.
 If using PROTOTYPES, then PROTO_LIST returns the list, otherwise it
@@ -36,7 +44,7 @@ If using PROTOTYPES, then PROTO_LIST returns the list, otherwise it
 
 /* Added for sha1 */
 /* BYTE defines a unsigned character */
-typedef unsigned char BYTE;
+typedef uint8_t BYTE;
 
 #ifndef TRUE
 #define FALSE 0
