@@ -24,8 +24,7 @@
 *--*/
 
 #include <stdio.h>
-#include "tsk_os.h"
-#include "tsk_types.h"
+#include "aux_tools.h"
 #include "global.h"
 #include "hash.h"
 
