@@ -31,8 +31,7 @@ effort (for example the reengineering of a great many Capstone chips).
 
 #include <stdio.h>
 #include <string.h>
-#include "tsk_os.h"
-#include "tsk_types.h"
+#include "aux_tools.h"
 #include "global.h"
 #include "hash.h"
 
