@@ -1,5 +1,5 @@
 /*
- * $Date: 2006/06/20 22:35:40 $
+ * $Date: 2006/08/25 18:28:31 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All rights reserved
@@ -23,7 +23,7 @@ aff_read_random(IMG_INFO * img_info, OFF_T vol_offset, char *buf,
     off_t tot_offset = offset + vol_offset;
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "aff_read_random: byte offset: %" PRIuOFF " len: %" PRIuOFF
 	    "\n", offset, len);
 
@@ -72,49 +72,49 @@ aff_imgstat(IMG_INFO * img_info, FILE * hFile)
     size_t buf_len = 512;
 
 
-    fprintf(hFile, "IMAGE FILE INFORMATION\n");
-    fprintf(hFile, "--------------------------------------------\n");
-    fprintf(hFile, "Image Type: ");
+    tsk_fprintf(hFile, "IMAGE FILE INFORMATION\n");
+    tsk_fprintf(hFile, "--------------------------------------------\n");
+    tsk_fprintf(hFile, "Image Type: ");
     switch (aff_info->type) {
     case AF_IDENTIFY_AFF:
-	fprintf(hFile, "AFF\n");
+	tsk_fprintf(hFile, "AFF\n");
 	break;
     case AF_IDENTIFY_AFD:
-	fprintf(hFile, "AFD\n");
+	tsk_fprintf(hFile, "AFD\n");
 	break;
     case AF_IDENTIFY_AFM:
-	fprintf(hFile, "AFM\n");
+	tsk_fprintf(hFile, "AFM\n");
 	break;
     default:
-	fprintf(hFile, "?\n");
+	tsk_fprintf(hFile, "?\n");
 	break;
     }
 
-    fprintf(hFile, "\nSize in bytes: %" PRIuOFF "\n", img_info->size);
+    tsk_fprintf(hFile, "\nSize in bytes: %" PRIuOFF "\n", img_info->size);
 
-    fprintf(hFile, "\nMD5: ");
+    tsk_fprintf(hFile, "\nMD5: ");
     if (af_get_seg(aff_info->af_file, AF_MD5, NULL, buf, &buf_len) == 0) {
 	int i;
 	for (i = 0; i < 16; i++) {
-	    fprintf(hFile, "%x", buf[i]);
+	    tsk_fprintf(hFile, "%x", buf[i]);
 	}
-	fprintf(hFile, "\n");
+	tsk_fprintf(hFile, "\n");
     }
     else {
-	fprintf(hFile, "Segment not found\n");
+	tsk_fprintf(hFile, "Segment not found\n");
     }
 
     buf_len = 512;
-    fprintf(hFile, "SHA1: ");
+    tsk_fprintf(hFile, "SHA1: ");
     if (af_get_seg(aff_info->af_file, AF_SHA1, NULL, buf, &buf_len) == 0) {
 	int i;
 	for (i = 0; i < 20; i++) {
-	    fprintf(hFile, "%x", buf[i]);
+	    tsk_fprintf(hFile, "%x", buf[i]);
 	}
-	fprintf(hFile, "\n");
+	tsk_fprintf(hFile, "\n");
     }
     else {
-	fprintf(hFile, "Segment not found\n");
+	tsk_fprintf(hFile, "Segment not found\n");
     }
 
     /* Creator segment */
@@ -122,74 +122,74 @@ aff_imgstat(IMG_INFO * img_info, FILE * hFile)
     if (af_get_seg(aff_info->af_file, AF_CREATOR, NULL, buf,
 	    &buf_len) == 0) {
 	buf[buf_len] = '\0';
-	fprintf(hFile, "Creator: %s\n", buf);
+	tsk_fprintf(hFile, "Creator: %s\n", buf);
     }
 
     buf_len = 512;
     if (af_get_seg(aff_info->af_file, AF_CASE_NUM, NULL, buf,
 	    &buf_len) == 0) {
 	buf[buf_len] = '\0';
-	fprintf(hFile, "Case Number: %s\n", buf);
+	tsk_fprintf(hFile, "Case Number: %s\n", buf);
     }
 
     buf_len = 512;
     if (af_get_seg(aff_info->af_file, AF_IMAGE_GID, NULL, buf,
 	    &buf_len) == 0) {
 	unsigned int i;
-	fprintf(hFile, "Image GID: ");
+	tsk_fprintf(hFile, "Image GID: ");
 	for (i = 0; i < buf_len; i++) {
-	    fprintf(hFile, "%X", buf[i]);
+	    tsk_fprintf(hFile, "%X", buf[i]);
 	}
-	fprintf(hFile, "\n");
+	tsk_fprintf(hFile, "\n");
     }
 
     buf_len = 512;
     if (af_get_seg(aff_info->af_file, AF_ACQUISITION_DATE, NULL, buf,
 	    &buf_len) == 0) {
 	buf[buf_len] = '\0';
-	fprintf(hFile, "Acquisition Date: %s\n", buf);
+	tsk_fprintf(hFile, "Acquisition Date: %s\n", buf);
     }
 
     buf_len = 512;
     if (af_get_seg(aff_info->af_file, AF_ACQUISITION_NOTES, NULL, buf,
 	    &buf_len) == 0) {
 	buf[buf_len] = '\0';
-	fprintf(hFile, "Acquisition Notes: %s\n", buf);
+	tsk_fprintf(hFile, "Acquisition Notes: %s\n", buf);
     }
 
     buf_len = 512;
     if (af_get_seg(aff_info->af_file, AF_ACQUISITION_DEVICE, NULL, buf,
 	    &buf_len) == 0) {
 	buf[buf_len] = '\0';
-	fprintf(hFile, "Acquisition Device: %s\n", buf);
+	tsk_fprintf(hFile, "Acquisition Device: %s\n", buf);
     }
 
     buf_len = 512;
     if (af_get_seg(aff_info->af_file, AF_AFFLIB_VERSION, NULL, buf,
 	    &buf_len) == 0) {
 	buf[buf_len] = '\0';
-	fprintf(hFile, "AFFLib Version: %s\n", buf);
+	tsk_fprintf(hFile, "AFFLib Version: %s\n", buf);
     }
 
     buf_len = 512;
     if (af_get_seg(aff_info->af_file, AF_DEVICE_MANUFACTURER, NULL, buf,
 	    &buf_len) == 0) {
 	buf[buf_len] = '\0';
-	fprintf(hFile, "Device Manufacturer: %s\n", buf);
+	tsk_fprintf(hFile, "Device Manufacturer: %s\n", buf);
     }
 
     buf_len = 512;
     if (af_get_seg(aff_info->af_file, AF_DEVICE_MODEL, NULL, buf,
 	    &buf_len) == 0) {
 	buf[buf_len] = '\0';
-	fprintf(hFile, "Device Model: %s\n", buf);
+	tsk_fprintf(hFile, "Device Model: %s\n", buf);
     }
 
     buf_len = 512;
     if (af_get_seg(aff_info->af_file, AF_DEVICE_SN, NULL, buf,
 	    &buf_len) == 0) {
 	buf[buf_len] = '\0';
-	fprintf(hFile, "Device SN: %s\n", buf);
+	tsk_fprintf(hFile, "Device SN: %s\n", buf);
     }
 
     return;
@@ -234,7 +234,7 @@ aff_open(const char **images, IMG_INFO * next)
     type = af_identify_type(images[0]);
     if ((type == AF_IDENTIFY_ERR) || (type == AF_IDENTIFY_NOEXIST)) {
 	if (verbose) {
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"aff_open: Error determining type of file: %s\n",
 		images[0]);
 	    perror("aff_open");
@@ -265,7 +265,7 @@ aff_open(const char **images, IMG_INFO * next)
 	tsk_errstr2[0] = '\0';
 	free(aff_info);
 	if (verbose)
-	    fprintf(stderr, "Not an AFF/AFD/AFM file\n");
+	    tsk_fprintf(stderr, "Not an AFF/AFD/AFM file\n");
 
 	return NULL;
     }
@@ -279,7 +279,7 @@ aff_open(const char **images, IMG_INFO * next)
 	tsk_errstr2[0] = '\0';
 	free(aff_info);
 	if (verbose) {
-	    fprintf(stderr, "Error opening AFF/AFD/AFM file\n");
+	    tsk_fprintf(stderr, "Error opening AFF/AFD/AFM file\n");
 	    perror("aff_open");
 	}
 	return NULL;
