@@ -1,5 +1,5 @@
 /*
- * $Date: 2006/06/20 22:35:40 $
+ * $Date: 2006/08/25 18:28:31 $
  *
  * Joachim Metz <forensics@hoffmannbv.nl>, Hoffmann Investigations
  * Copyright (c) 2006 Joachim Metz.  All rights reserved 
@@ -24,7 +24,7 @@ ewf_image_read_random(IMG_INFO * img_info, OFF_T vol_offset, char *buf,
     OFF_T tot_offset = offset + vol_offset;
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "ewf_read_random: byte offset: %" PRIuOFF " len: %" PRIuOFF
 	    "\n", offset, len);
 
@@ -53,14 +53,14 @@ ewf_image_imgstat(IMG_INFO * img_info, FILE * hFile)
 {
     IMG_EWF_INFO *ewf_info = (IMG_EWF_INFO *) img_info;
 
-    fprintf(hFile, "IMAGE FILE INFORMATION\n");
-    fprintf(hFile, "--------------------------------------------\n");
-    fprintf(hFile, "Image Type:\t\tewf\n");
-    fprintf(hFile, "\nSize of data in bytes:\t%" PRIuOFF "\n",
+    tsk_fprintf(hFile, "IMAGE FILE INFORMATION\n");
+    tsk_fprintf(hFile, "--------------------------------------------\n");
+    tsk_fprintf(hFile, "Image Type:\t\tewf\n");
+    tsk_fprintf(hFile, "\nSize of data in bytes:\t%" PRIuOFF "\n",
 	img_info->size);
 
     if (ewf_info->md5hash != NULL) {
-	fprintf(hFile, "MD5 hash of data:\t%s\n", ewf_info->md5hash);
+	tsk_fprintf(hFile, "MD5 hash of data:\t%s\n", ewf_info->md5hash);
     }
     return;
 }
@@ -150,7 +150,7 @@ ewf_open(int num_img, const char **images, IMG_INFO * next)
 	tsk_errstr2[0] = '\0';
 	free(ewf_info);
 	if (verbose)
-	    fprintf(stderr, "Not an EWF file\n");
+	    tsk_fprintf(stderr, "Not an EWF file\n");
 
 	return NULL;
     }
