@@ -2,7 +2,7 @@
  * img_cat
  * The Sleuth Kit 
  *
- * $Date: 2006/07/10 13:26:20 $
+ * $Date: 2006/09/01 15:23:03 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All rights reserved 
@@ -12,50 +12,51 @@
  */
 #include "img_tools.h"
 
+static TCHAR *progname;
+
 static void
 usage()
 {
-    fprintf(stderr, "usage: %s [-vV] [-i imgtype] image\n", progname);
-    fprintf(stderr,
+    TFPRINTF(stderr, _T("usage: %s [-vV] [-i imgtype] image\n"), progname);
+    tsk_fprintf(stderr,
 	"\t-i imgtype: The format of the image file (use 'i list' for supported types)\n");
-    fprintf(stderr, "\t-v: verbose output to stderr\n");
-    fprintf(stderr, "\t-V: Print version\n");
+    tsk_fprintf(stderr, "\t-v: verbose output to stderr\n");
+    tsk_fprintf(stderr, "\t-V: Print version\n");
 
     exit(1);
 }
 
 
 int
-main(int argc, char **argv)
+MAIN(int argc, TCHAR ** argv)
 {
     IMG_INFO *img;
-    char *imgtype = NULL;
+    TCHAR *imgtype = NULL;
     int ch;
     SSIZE_T cnt, done;
 
     progname = argv[0];
 
-    while ((ch = getopt(argc, argv, "i:vV")) > 0) {
+    while ((ch = getopt(argc, argv, _T("i:vV"))) > 0) {
 	switch (ch) {
-	case '?':
+	case _T('?'):
 	default:
-	    fprintf(stderr, "Invalid argument: %s\n", argv[optind]);
+	    TFPRINTF(stderr, _T("Invalid argument: %s\n"), argv[optind]);
 	    usage();
 
-	case 'i':
+	case _T('i'):
 	    imgtype = optarg;
-	    if (strcmp(imgtype, "list") == 0) {
+	    if (TSTRCMP(imgtype, _T("list")) == 0) {
 		img_print_types(stderr);
 		exit(1);
 	    }
-
 	    break;
 
-	case 'v':
+	case _T('v'):
 	    verbose++;
 	    break;
 
-	case 'V':
+	case _T('V'):
 	    print_version(stdout);
 	    exit(0);
 	}
@@ -63,22 +64,31 @@ main(int argc, char **argv)
 
     /* We need at least one more argument */
     if (optind >= argc) {
-	fprintf(stderr, "Missing image name\n");
+	tsk_fprintf(stderr, "Missing image name\n");
 	usage();
     }
 
     if ((img =
 	    img_open(imgtype, argc - optind,
-		(const char **) &argv[optind])) == NULL) {
+		(const TCHAR **) &argv[optind])) == NULL) {
 	tsk_error_print(stderr);
 	exit(1);
     }
 
+#ifdef TSK_WIN32
+    if (-1 == _setmode(_fileno(stdout), _O_BINARY)) {
+	tsk_errno = TSK_ERR_FS_WRITE;
+	snprintf(tsk_errstr, TSK_ERRSTR_L,
+	    "dls_lib: error setting stdout to binary: %s",
+	    strerror(errno));
+	return 1;
+    }
+#endif
+
     for (done = 0; done < img->size; done += cnt) {
 	char buf[16 * 1024];
 	OFF_T len;
 
-
 	if (done + sizeof(buf) > img->size) {
 	    len = img->size - done;
 	}
@@ -89,7 +99,7 @@ main(int argc, char **argv)
 	cnt = img->read_random(img, 0, buf, len, done);
 	if (cnt != len) {
 	    if (cnt != -1) {
-		fprintf(stderr,
+		tsk_fprintf(stderr,
 		    "img_cat: Error reading image file at offset: %"
 		    PRIuOFF ", len: %" PRIuOFF ", return: %" PRIuOFF "\n",
 		    done, len, cnt);
