@@ -1,5 +1,5 @@
 /*
- * $Date: 2006/07/05 18:24:09 $
+ * $Date: 2006/09/01 15:23:03 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All Rights reserved
@@ -36,14 +36,14 @@
  * The highest layer is returned or NULL if an error occurs
  */
 IMG_INFO *
-img_open(const char *type, const int num_img, const char **images)
+img_open(const TCHAR * type, const int num_img, const TCHAR ** images)
 {
     IMG_INFO *img_info = NULL;
-    char *tp, type_lcl[128], *type_lcl_p, *next;
-    const char **img_tmp;
+    TCHAR *tp, *next;
+    TCHAR type_lcl[128], *type_lcl_p;
+    const TCHAR **img_tmp;
     int num_img_tmp = num_img;
 
-
     if ((num_img == 0) || (images[0] == NULL)) {
 	tsk_errno = TSK_ERR_IMG_NOFILE;
 	snprintf(tsk_errstr, TSK_ERRSTR_L, "img_open");
@@ -52,9 +52,9 @@ img_open(const char *type, const int num_img, const char **images)
     }
 
     if (verbose)
-	fprintf(stderr,
-	    "img_open: Type: %s   NumImg: %d  Img1: %s\n",
-	    (type ? type : "n/a"), num_img, images[0]);
+	TFPRINTF(stderr,
+	    _T("img_open: Type: %s   NumImg: %d  Img1: %s\n"),
+	    (type ? type : _T("n/a")), num_img, images[0]);
 
     // only the first in list (lowest) layer gets the files
     img_tmp = images;
@@ -67,15 +67,30 @@ img_open(const char *type, const int num_img, const char **images)
     if (type == NULL) {
 	IMG_INFO *img_set = NULL;
 	char *set = NULL;
-	struct stat stat_buf;
+	struct STAT_STR stat_buf;
 
 	/* First verify that the image file exists */
-	if (stat(images[0], &stat_buf) == -1) {
-	    tsk_errno = TSK_ERR_IMG_STAT;
-	    snprintf(tsk_errstr, TSK_ERRSTR_L, "%s : %s", images[0],
-		strerror(errno));
-	    tsk_errstr2[0] = '\0';
-	    return NULL;
+	if (TSTAT(images[0], &stat_buf) == -1) {
+	    // special case to handle windows objects
+#ifdef TSK_WIN32
+	    if ((images[0][0] == _T('\\')) && (images[0][1] == _T('\\')) &&
+		(images[0][2] == _T('.')) && (images[0][3] == _T('\\'))) {
+		if (verbose)
+		    TFPRINTF(stderr,
+			_T
+			("img_open: Ignoring stat error because of windows object: %s\n"),
+			images[0]);
+	    }
+	    else {
+#endif
+		tsk_errno = TSK_ERR_IMG_STAT;
+		snprintf(tsk_errstr, TSK_ERRSTR_L, "%s : %s", images[0],
+		    strerror(errno));
+		tsk_errstr2[0] = '\0';
+		return NULL;
+#ifdef TSK_WIN32
+	    }
+#endif
 	}
 
 	// we rely on tsk_errno, so make sure it is 0
@@ -111,11 +126,9 @@ img_open(const char *type, const int num_img, const char **images)
 	    tsk_error_reset();
 	}
 #endif
-
 	if (img_set != NULL)
 	    return img_set;
 
-
 	/* We'll use the raw format */
 	if (num_img == 1) {
 	    if ((img_info = raw_open(images, NULL)) != NULL) {
@@ -143,15 +156,15 @@ img_open(const char *type, const int num_img, const char **images)
      * Type values
      * Make a local copy that we can modify the string as we parse it
      */
-    strncpy(type_lcl, type, 128);
+    TSTRNCPY(type_lcl, type, 128);
     type_lcl_p = type_lcl;
 
     /* We parse this and go up in the layers */
-    tp = strtok(type_lcl, ",");
+    tp = TSTRTOK(type_lcl, _T(","));
     while (tp != NULL) {
 	uint8_t imgtype;
 
-	next = strtok(NULL, ",");
+	next = TSTRTOK(NULL, _T(","));
 
 	imgtype = img_parse_type(type);
 	switch (imgtype) {
