@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/06/20 22:35:41 $
+ * $Date: 2006/08/25 18:28:32 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2005 Brian Carrier.  All rights reserved 
@@ -19,18 +19,12 @@ extern "C" {
 #include <fcntl.h>
 #include <errno.h>
 
-#include "tsk_os.h"
+#include "aux_tools.h"
 
 #ifdef HAVE_UNISTD
 #include <unistd.h>
 #endif
 
-#include "tsk_types.h"
-
-#include "img_types.h"
-
-#include "libauxtools.h"
-
     typedef struct IMG_INFO IMG_INFO;
 
     struct IMG_INFO {
@@ -50,7 +44,40 @@ extern "C" {
     };
 
 
-    extern IMG_INFO *img_open(const char *, const int, const char **);
+    extern IMG_INFO *img_open(const TCHAR *, const int, const TCHAR **);
+
+
+/********* TYPES *******/
+    extern uint8_t img_parse_type(const TCHAR *);
+    extern void img_print_types(FILE *);
+    extern char *img_get_type(uint8_t);
+
+/*
+** the most-sig-nibble is the image type, which indicates which
+** _open function to call.  The least-sig-nibble is the specific type
+** of implementation.  
+*/
+#define IMGMASK			0xf0
+#define OSMASK			0x0f
+
+#define UNSUPP_IMG		0x00
+
+/* RAW */
+#define RAW_TYPE		0x10
+#define RAW_SING		0x11
+#define RAW_SPLIT		0x12
+
+/* AFF */
+#define AFF_TYPE		0x20
+#define AFF_AFF			0x21
+#define AFF_AFD			0x22
+#define AFF_AFM			0x23
+
+/* EWF */
+#define EWF_TYPE		0x30
+#define EWF_EWF			0x31
+
+
 
 #ifdef __cplusplus
 }
