@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/06/20 22:35:41 $
+ * $Date: 2006/08/25 18:28:33 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2005 Brian Carrier.  All rights reserved 
@@ -13,7 +13,7 @@
 extern "C" {
 #endif
 
-    extern IMG_INFO *raw_open(const char **, IMG_INFO *);
+    extern IMG_INFO *raw_open(const TCHAR **, IMG_INFO *);
 
     typedef struct IMG_RAW_INFO IMG_RAW_INFO;
     struct IMG_RAW_INFO {
