@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/06/19 22:21:28 $
+ * $Date: 2006/09/01 15:23:03 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All rights reserved
@@ -99,8 +99,8 @@ bsd_load_table(MM_INFO * mm)
     DADDR_T max_addr = (mm->img_info->size - mm->offset) / mm->block_size;	// max sector
 
     if (verbose)
-	fprintf(stderr, "bsd_load_table: Table Sector: %" PRIuDADDR "\n",
-	    laddr);
+	tsk_fprintf(stderr,
+	    "bsd_load_table: Table Sector: %" PRIuDADDR "\n", laddr);
 
     /* read the block */
     cnt = mm_read_block_nobuf
@@ -120,32 +120,34 @@ bsd_load_table(MM_INFO * mm)
 	tsk_errno = TSK_ERR_MM_MAGIC;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
 	    "BSD partition table (magic #1) (Sector: %"
-	    PRIuDADDR ") %" PRIx32, laddr, getu32(mm, dlabel.magic));
+	    PRIuDADDR ") %" PRIx32, laddr, getu32(mm->endian,
+		dlabel.magic));
 	tsk_errstr2[0] = '\0';
 	return 1;
     }
 
     /* Check the second magic value */
-    if (getu32(mm, dlabel.magic2) != BSD_MAGIC) {
+    if (getu32(mm->endian, dlabel.magic2) != BSD_MAGIC) {
 	tsk_errno = TSK_ERR_MM_MAGIC;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
 	    "BSD disk label (magic #2) (Sector: %"
-	    PRIuDADDR ")  %" PRIx32, laddr, getu32(mm, dlabel.magic2));
+	    PRIuDADDR ")  %" PRIx32, laddr, getu32(mm->endian,
+		dlabel.magic2));
 	tsk_errstr2[0] = '\0';
 	return 1;
     }
 
     /* Cycle through the partitions, there are either 8 or 16 */
-    for (idx = 0; idx < getu16(mm, dlabel.num_parts); idx++) {
+    for (idx = 0; idx < getu16(mm->endian, dlabel.num_parts); idx++) {
 
 	uint32_t part_start;
 	uint32_t part_size;
 
-	part_start = getu32(mm, dlabel.part[idx].start_sec);
-	part_size = getu32(mm, dlabel.part[idx].size_sec);
+	part_start = getu32(mm->endian, dlabel.part[idx].start_sec);
+	part_size = getu32(mm->endian, dlabel.part[idx].size_sec);
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"load_table: %" PRIu32 "  Starting Sector: %" PRIu32
 		"  Size: %" PRIu32 "  Type: %d\n", idx, part_start,
 		part_size, dlabel.part[idx].fstype);
@@ -181,7 +183,7 @@ bsd_load_table(MM_INFO * mm)
  */
 uint8_t
 bsd_part_walk(MM_INFO * mm, PNUM_T start, PNUM_T last, int flags,
-    MM_PART_WALK_FN action, char *ptr)
+    MM_PART_WALK_FN action, void *ptr)
 {
     MM_PART *part;
     PNUM_T cnt = 0;
