@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/07/05 19:16:34 $
+ * $Date: 2006/08/25 18:28:42 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All rights reserved
@@ -682,7 +682,7 @@ dos_load_ext_table(MM_INFO * mm, DADDR_T sect_cur, DADDR_T sect_ext_base,
     DADDR_T max_addr = (mm->img_info->size - mm->offset) / mm->block_size;	// max sector
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "dos_load_ext: Table Sector: %" PRIuDADDR
 	    ", Primary Base Sector: %" PRIuDADDR "\n", sect_cur,
 	    sect_ext_base);
@@ -701,7 +701,7 @@ dos_load_ext_table(MM_INFO * mm, DADDR_T sect_cur, DADDR_T sect_ext_base,
     }
 
     /* Sanity Check */
-    if (getu16(mm, sect.magic) != DOS_MAGIC) {
+    if (getu16(mm->endian, sect.magic) != DOS_MAGIC) {
 	tsk_errno = TSK_ERR_MM_MAGIC;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
 	    "Extended DOS partition table in sector %"
@@ -730,11 +730,11 @@ dos_load_ext_table(MM_INFO * mm, DADDR_T sect_cur, DADDR_T sect_ext_base,
 
 	/* Get the starting sector and size, we currently
 	 * ignore CHS */
-	uint32_t part_start = getu32(mm, part->start_sec);
-	uint32_t part_size = getu32(mm, part->size_sec);
+	uint32_t part_start = getu32(mm->endian, part->start_sec);
+	uint32_t part_size = getu32(mm->endian, part->size_sec);
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"load_ext: %d:%d    Start: %" PRIu32 "   Size: %"
 		PRIu32 "  Type: %d\n", table, i, part_start, part_size,
 		part->ptype);
@@ -756,7 +756,7 @@ dos_load_ext_table(MM_INFO * mm, DADDR_T sect_cur, DADDR_T sect_ext_base,
 		    "dos_load_ext_table: Starting sector too large for image");
 		tsk_errstr2[0] = '\0';
 		if (verbose)
-		    fprintf(stderr,
+		    tsk_fprintf(stderr,
 			"Starting sector %" PRIuDADDR
 			" too large for image\n",
 			sect_ext_base + part_start);
@@ -787,7 +787,7 @@ dos_load_ext_table(MM_INFO * mm, DADDR_T sect_cur, DADDR_T sect_ext_base,
 		    "dos_load_ext_table: Starting sector too large for image");
 		tsk_errstr2[0] = '\0';
 		if (verbose)
-		    fprintf(stderr,
+		    tsk_fprintf(stderr,
 			"Starting sector %" PRIuDADDR
 			" too large for image\n", sect_cur + part_start);
 		return 1;
@@ -825,7 +825,7 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
     DADDR_T max_addr = (mm->img_info->size - mm->offset) / mm->block_size;	// max sector
 
     if (verbose)
-	fprintf(stderr,
+	tsk_fprintf(stderr,
 	    "dos_load_prim: Table Sector: %" PRIuDADDR "\n", taddr);
 
     /* Read the table */
@@ -860,7 +860,7 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
     if (test) {
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"dos_load_prim_table: Testing FAT/NTFS conditions\n");
 
 	if (strncmp("MSDOS", sect.oemname, 5) == 0) {
@@ -907,11 +907,11 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
 	dos_part *part = &sect.ptable[i];
 
 	/* We currently ignore CHS */
-	uint32_t part_start = getu32(mm, part->start_sec);
-	uint32_t part_size = getu32(mm, part->size_sec);
+	uint32_t part_start = getu32(mm->endian, part->start_sec);
+	uint32_t part_size = getu32(mm->endian, part->size_sec);
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"load_pri:0:%d    Start: %" PRIu32 "   Size: %" PRIu32
 		"  Type: %d\n", i, part_start, part_size, part->ptype);
 
@@ -924,8 +924,8 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
 		"dos_load_prim_table: Starting sector too large for image");
 	    tsk_errstr2[0] = '\0';
 	    if (verbose)
-		fprintf(stderr,
-		    "Starting sector %" PRIuDADDR " too large for image\n",
+		tsk_fprintf(stderr,
+		    "Starting sector %" PRIu32 " too large for image\n",
 		    part_start);
 
 	    return 1;
@@ -963,7 +963,7 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
     }
     if (added == 0) {
 	if (verbose)
-	    fprintf(stderr, "dos_load_prim: No valid entries\n");
+	    tsk_fprintf(stderr, "dos_load_prim: No valid entries\n");
 
 	tsk_errno = TSK_ERR_MM_MAGIC;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
@@ -983,7 +983,7 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
  */
 uint8_t
 dos_part_walk(MM_INFO * mm, PNUM_T start, PNUM_T last, int flags,
-    MM_PART_WALK_FN action, char *ptr)
+    MM_PART_WALK_FN action, void *ptr)
 {
     MM_PART *part;
     PNUM_T cnt = 0;
