@@ -1,7 +1,7 @@
 /* 
  * The Sleuth Kit
  *
- * $Date: 2005/09/02 23:34:04 $
+ * $Date: 2006/04/06 01:15:57 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -37,7 +37,7 @@ extern "C" {
     } dos_sect;
 
 #define DOS_MAGIC	0xaa55
-#define DOS_PART_OFFSET 0
+#define DOS_PART_SOFFSET 0
 
 #ifdef __cplusplus
 }
