@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/05/22 15:55:46 $
+ * $Date: 2006/09/01 15:23:03 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All rights reserved
@@ -38,7 +38,8 @@ gpt_load_table(MM_INFO * mm)
     DADDR_T max_addr = (mm->img_info->size - mm->offset) / mm->block_size;	// max sector
 
     if (verbose)
-	fprintf(stderr, "gpt_load_table: Sector: %" PRIuDADDR "\n", taddr);
+	tsk_fprintf(stderr, "gpt_load_table: Sector: %" PRIuDADDR "\n",
+	    taddr);
 
     cnt = mm_read_block_nobuf
 	(mm, (char *) &dos_part, sizeof(dos_part), GPT_PART_SOFFSET);
@@ -96,10 +97,10 @@ gpt_load_table(MM_INFO * mm)
     }
 
 
-    if (getu64(mm, &head.signature) != GPT_HEAD_SIG) {
+    if (getu64(mm->endian, &head.signature) != GPT_HEAD_SIG) {
 	tsk_errno = TSK_ERR_MM_MAGIC;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
-	    "GPT Header: %" PRIx64, getu64(mm, &head.signature));
+	    "GPT Header: %" PRIx64, getu64(mm->endian, &head.signature));
 	tsk_errstr2[0] = '\0';
 	return 1;
     }
@@ -109,12 +110,13 @@ gpt_load_table(MM_INFO * mm)
 
     snprintf(head_str, 16, "GPT Header");
     if (NULL == mm_part_add(mm, (DADDR_T) 1,
-	    (DADDR_T) ((getu32(mm, &head.head_size_b) + 511) / 512),
-	    MM_TYPE_DESC, head_str, -1, -1))
+	    (DADDR_T) ((getu32(mm->endian,
+			&head.head_size_b) + 511) / 512), MM_TYPE_DESC,
+	    head_str, -1, -1))
 	return 1;
 
     /* Allocate a buffer for each table entry */
-    ent_size = getu32(mm, &head.tab_size_b);
+    ent_size = getu32(mm->endian, &head.tab_size_b);
     if (ent_size < sizeof(gpt_entry)) {
 	tsk_errno = TSK_ERR_MM_MAGIC;
 	snprintf(tsk_errstr, TSK_ERRSTR_L,
@@ -128,9 +130,11 @@ gpt_load_table(MM_INFO * mm)
 	return 1;
 
     snprintf(tab_str, 20, "Partition Table");
-    if (NULL == mm_part_add(mm, (DADDR_T) getu64(mm, &head.tab_start_lba),
-	    (DADDR_T) ((ent_size * getu32(mm, &head.tab_num_ent) +
-		    511) / 512), MM_TYPE_DESC, tab_str, -1, -1))
+    if (NULL == mm_part_add(mm, (DADDR_T) getu64(mm->endian,
+		&head.tab_start_lba),
+	    (DADDR_T) ((ent_size * getu32(mm->endian,
+			&head.tab_num_ent) + 511) / 512), MM_TYPE_DESC,
+	    tab_str, -1, -1))
 	return 1;
 
 
@@ -139,12 +143,12 @@ gpt_load_table(MM_INFO * mm)
 	return 1;
 
     i = 0;
-    for (a = 0; i < getu32(mm, &head.tab_num_ent); a++) {
+    for (a = 0; i < getu32(mm->endian, &head.tab_num_ent); a++) {
 	char *name;
 
 	/* Read a sector */
 	cnt = mm_read_block_nobuf(mm, ent_buf, mm->block_size,
-	    getu64(mm, &head.tab_start_lba) + a);
+	    getu64(mm->endian, &head.tab_start_lba) + a);
 	if (cnt != mm->block_size) {
 	    if (cnt != -1) {
 		tsk_errno = TSK_ERR_MM_READ;
@@ -152,27 +156,31 @@ gpt_load_table(MM_INFO * mm)
 	    }
 	    snprintf(tsk_errstr2, TSK_ERRSTR_L,
 		"Error reading GPT partition table sector : %"
-		PRIuDADDR, getu64(mm, &head.tab_start_lba) + a);
+		PRIuDADDR, getu64(mm->endian, &head.tab_start_lba) + a);
 	    return 1;
 	}
 
 	/* Process the sector */
 	ent = (gpt_entry *) ent_buf;
 	for (; (uintptr_t) ent < (uintptr_t) ent_buf + mm->block_size &&
-	    i < getu32(mm, &head.tab_num_ent); ent++ && i++) {
+	    i < getu32(mm->endian, &head.tab_num_ent); ent++ && i++) {
+
+	    UTF16 *name16;
+	    UTF8 *name8;
+	    int retVal;
 
 	    if (verbose)
-		fprintf(stderr,
+		tsk_fprintf(stderr,
 		    "gpt_load: %d  Starting Sector: %" PRIu64
 		    "  End: %" PRIu64 " Flag: %" PRIx64 "\n", i,
-		    getu64(mm, ent->start_lba), getu64(mm,
-			ent->end_lba), getu64(mm, ent->flags));
+		    getu64(mm->endian, ent->start_lba), getu64(mm->endian,
+			ent->end_lba), getu64(mm->endian, ent->flags));
 
 
-	    if (getu64(mm, ent->start_lba) == 0)
+	    if (getu64(mm->endian, ent->start_lba) == 0)
 		continue;
 
-	    if (getu64(mm, ent->start_lba) > max_addr) {
+	    if (getu64(mm->endian, ent->start_lba) > max_addr) {
 		tsk_errno = TSK_ERR_MM_BLK_NUM;
 		snprintf(tsk_errstr, TSK_ERRSTR_L,
 		    "gpt_load_table: Starting sector too large for image");
@@ -181,13 +189,29 @@ gpt_load_table(MM_INFO * mm)
 	    }
 
 
-	    if ((name = mymalloc(72)) == NULL)
+	    if ((name = mymalloc(256)) == NULL)
 		return 1;
 
-	    uni2ascii((char *) ent->name, 72, name, 72);
-	    if (NULL == mm_part_add(mm, (DADDR_T) getu64(mm,
-			ent->start_lba), (DADDR_T) (getu64(mm,
-			    ent->end_lba) - getu64(mm,
+	    name16 = (UTF16 *) ((uintptr_t) ent->name);
+	    name8 = (UTF8 *) name;
+
+	    retVal =
+		tsk_UTF16toUTF8(mm->endian, (const UTF16 **) &name16,
+		(UTF16 *) ((uintptr_t) name16 + sizeof(ent->name)),
+		&name8,
+		(UTF8 *) ((uintptr_t) name8 + 256), lenientConversion);
+
+	    if (retVal != conversionOK) {
+		if (verbose)
+		    tsk_fprintf(stderr,
+			"gpt_load_table: Error converting name to UTF8: %d\n",
+			retVal);
+		*name = '\0';
+	    }
+
+	    if (NULL == mm_part_add(mm, (DADDR_T) getu64(mm->endian,
+			ent->start_lba), (DADDR_T) (getu64(mm->endian,
+			    ent->end_lba) - getu64(mm->endian,
 			    ent->start_lba) + 1), MM_TYPE_VOL, name, -1,
 		    i))
 		return 1;
@@ -205,7 +229,7 @@ gpt_load_table(MM_INFO * mm)
  */
 uint8_t
 gpt_part_walk(MM_INFO * mm, PNUM_T start, PNUM_T last, int flags,
-    MM_PART_WALK_FN action, char *ptr)
+    MM_PART_WALK_FN action, void *ptr)
 {
     MM_PART *part;
     unsigned int cnt = 0;
