@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/06/19 22:21:28 $
+ * $Date: 2006/09/01 15:23:03 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2006 Brian Carrier, Basis Technology.  All rights reserved
@@ -35,7 +35,8 @@ mac_load_table(MM_INFO * mm)
     DADDR_T max_addr = (mm->img_info->size - mm->offset) / mm->block_size;	// max sector
 
     if (verbose)
-	fprintf(stderr, "mac_load_table: Sector: %" PRIuDADDR "\n", taddr);
+	tsk_fprintf(stderr, "mac_load_table: Sector: %" PRIuDADDR "\n",
+	    taddr);
 
     /* The table can be variable length, so we loop on it 
      * The idx variable shows which round it is
@@ -74,30 +75,30 @@ mac_load_table(MM_INFO * mm)
 		snprintf(tsk_errstr, TSK_ERRSTR_L,
 		    "Mac partition table entry (Sector: %"
 		    PRIuDADDR ") %" PRIx16,
-		    (taddr + idx), getu16(mm, part.magic));
+		    (taddr + idx), getu16(mm->endian, part.magic));
 		tsk_errstr2[0] = '\0';
 		return 1;
 	    }
 
 	    /* Get the number of partitions */
-	    max_part = getu32(mm, part.pmap_size);
+	    max_part = getu32(mm->endian, part.pmap_size);
 	}
-	else if (getu16(mm, part.magic) != MAC_MAGIC) {
+	else if (getu16(mm->endian, part.magic) != MAC_MAGIC) {
 	    tsk_errno = TSK_ERR_MM_MAGIC;
 	    snprintf(tsk_errstr, TSK_ERRSTR_L,
 		"Mac partition table entry (Sector: %"
 		PRIuDADDR ") %" PRIx16, (taddr + idx),
-		getu16(mm, part.magic));
+		getu16(mm->endian, part.magic));
 	    tsk_errstr2[0] = '\0';
 	    return 1;
 	}
 
 
-	part_start = getu32(mm, part.start_sec);
-	part_size = getu32(mm, part.size_sec);
+	part_start = getu32(mm->endian, part.start_sec);
+	part_size = getu32(mm->endian, part.size_sec);
 
 	if (verbose)
-	    fprintf(stderr,
+	    tsk_fprintf(stderr,
 		"mac_load: %" PRIu32 "  Starting Sector: %" PRIu32
 		"  Size: %" PRIu32 " Type: %s\n", idx, part_start,
 		part_size, part.type);
@@ -144,7 +145,7 @@ mac_load_table(MM_INFO * mm)
  */
 uint8_t
 mac_part_walk(MM_INFO * mm, PNUM_T start, PNUM_T last, int flags,
-    MM_PART_WALK_FN action, char *ptr)
+    MM_PART_WALK_FN action, void *ptr)
 {
     MM_PART *part;
     unsigned int cnt = 0;
