@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2005/09/02 23:34:04 $
+ * $Date: 2006/04/06 01:15:57 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -38,7 +38,7 @@ extern "C" {
     } mac_part;
 
 #define MAC_MAGIC	0x504d
-#define MAC_PART_OFFSET	1
+#define MAC_PART_SOFFSET	1
 
 #define MAC_STAT_VALID		0x00
 #define MAC_STAT_ALLOC		0x01
