@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/07/05 18:24:09 $
+ * $Date: 2006/09/01 15:23:03 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -22,7 +22,7 @@
  * Offset is the byte offset to the start of the volume system
  */
 MM_INFO *
-mm_open(IMG_INFO * img_info, DADDR_T offset, const char *type)
+mm_open(IMG_INFO * img_info, DADDR_T offset, const TCHAR * type)
 {
     /* Autodetect mode 
      * We need to try all of them in case there are multiple 
