@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2006/07/10 13:26:20 $
+ * $Date: 2006/09/01 15:23:03 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2005 Brian Carrier.  All rights reserved
@@ -15,72 +15,69 @@
 
 #include "mm_tools.h"
 
-
-extern char *progname;
-
+static TCHAR *progname;
 
 void
 usage()
 {
-    fprintf(stderr,
-	"%s [-i imgtype] [-o imgoffset] [-vV] [-t mmtype] image [images]\n",
+    TFPRINTF(stderr,
+	_T
+	("%s [-i imgtype] [-o imgoffset] [-vV] [-t mmtype] image [images]\n"),
 	progname);
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-t mmtype: The type of partition system (use '-t list' for list of supported types)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-i imgtype: The format of the image file (use '-i list' for list of supported types)\n");
-    fprintf(stderr,
+    tsk_fprintf(stderr,
 	"\t-o imgoffset: Offset to the start of the volume that contains the partition system (in sectors)\n");
-    fprintf(stderr, "\t-v: verbose output\n");
-    fprintf(stderr, "\t-V: print the version\n");
+    tsk_fprintf(stderr, "\t-v: verbose output\n");
+    tsk_fprintf(stderr, "\t-V: print the version\n");
     exit(1);
 }
 
 static void
 print_stats(MM_INFO * mm)
 {
-    printf("%s\n", mm_get_type(mm->mmtype));
-    //printf("Type: %s\n", mm->str_type);
+    tsk_printf("%s\n", mm_get_type(mm->mmtype));
+    //tsk_printf("Type: %s\n", mm->str_type);
     return;
 }
 
 int
-main(int argc, char **argv)
+MAIN(int argc, TCHAR ** argv)
 {
     MM_INFO *mm;
-    char *mmtype = NULL;
+    TCHAR *imgtype = NULL;
+    TCHAR *mmtype = NULL;
     int ch;
     SSIZE_T imgoff = 0;
-    char *imgtype = NULL;
     IMG_INFO *img;
 
     progname = argv[0];
 
-    while ((ch = getopt(argc, argv, "i:o:t:vV")) > 0) {
+    while ((ch = getopt(argc, argv, _T("i:o:t:vV"))) > 0) {
 	switch (ch) {
-	case 'i':
+	case _T('i'):
 	    imgtype = optarg;
-	    if (strcmp(imgtype, "list") == 0) {
+	    if (TSTRCMP(imgtype, _T("list")) == 0) {
 		img_print_types(stderr);
 		exit(1);
 	    }
 
 	    break;
 
-	case 'o':
+	case _T('o'):
 	    if ((imgoff = parse_offset(optarg)) == -1) {
 		tsk_error_print(stderr);
 		exit(1);
 	    }
-
 	    break;
-	case 't':
+	case _T('t'):
 	    mmtype = optarg;
-	    if (strcmp(mmtype, "list") == 0) {
+	    if (TSTRCMP(mmtype, _T("list")) == 0) {
 		mm_print_types(stderr);
 		exit(1);
 	    }
-
 	    break;
 	case 'v':
 	    verbose++;
@@ -90,21 +87,21 @@ main(int argc, char **argv)
 	    exit(0);
 	case '?':
 	default:
-	    fprintf(stderr, "Unknown argument\n");
+	    tsk_fprintf(stderr, "Unknown argument\n");
 	    usage();
 	}
     }
 
     /* We need at least one more argument */
     if (optind >= argc) {
-	fprintf(stderr, "Missing image name\n");
+	tsk_fprintf(stderr, "Missing image name\n");
 	usage();
     }
 
     /* open the image */
     if ((img =
 	    img_open(imgtype, argc - optind,
-		(const char **) &argv[optind])) == NULL) {
+		(const TCHAR **) &argv[optind])) == NULL) {
 	tsk_error_print(stderr);
 	exit(1);
     }
