@@ -60,8 +60,7 @@
 #include <unistd.h>
 #include <string.h>
 
-#include "tsk_os.h"
-#include "libauxtools.h"
+#include "aux_tools.h"
 
 
 /* Some platforms need to put stdin into binary mode, to read
